{
    "!BT": "BitTorrent Incomplete Download File",
    "!UT": "uTorrent Incomplete Download",
    "$$$": "Temporary File",
    "$DB": "dBASE Temporary File",
    "$ER": "GroupWise Database",
    "0": "M3 DS Real Save File",
    "000": "Indexing Service Data File",
    "001": "Fax File",
    "002": "Split Archive Part 2 File",
    "003": "Split Archive Part 3 File",
    "0XE": "F-Secure Renamed Virus File",
    "1": "Unix Section 1 Man Page",
    "113": "Iomega Backup File",
    "123": "Lotus 1-2-3 Spreadsheet",
    "123C": "Autodesk 123C Drawing",
    "123D": "Autodesk 123D Drawing",
    "123DX": "123D Design Model File",
    "12M": "Lotus 1-2-3 SmartMaster File",
    "1ST": "Readme File",
    "208": "ASUS Notebook BIOS 208 Update File",
    "264": "Ripped Video Data File",
    "2BP": "Pocket PC Bitmap Image File",
    "2D": "VersaCAD 2D Drawing File",
    "2FS": "Puppy Linux Save State File",
    "2MG": "Apple IIGS Disk Image",
    "360": "360desktop Panorama File",
    "386": "Windows Virtual Device Driver",
    "3D": "Stereo CAD-3D Image File",
    "3D2": "Stereo CAD-3D 2.0 Image File",
    "3D4": "Stereo CAD-3D 2.0 Image File",
    "3DA": "3D Assembly File",
    "3DC": "3DCT 3D Image",
    "3DD": "ArcGlobe Document",
    "3DF": "3D Format",
    "3DL": "LightConverse 3D Model File",
    "3DM": "Rhino 3D Model",
    "3DMF": "QuickDraw 3D Metafile",
    "3DMK": "123D Make Project File",
    "3DON": "Scrutinize 3D Mesh File",
    "3DP": "123D Catch Photo Scene Data File",
    "3DR": "3DMark Results File",
    "3DS": "3D Studio Scene",
    "3DSX": "Homebrew Launcher File",
    "3DV": "3D VRML World",
    "3DW": "3D World Studio File",
    "3DX": "Rhino 3D Model File",
    "3DXML": "Dassault Systemes 3D XML File",
    "3FR": "Hasselblad 3F RAW Image",
    "3FS": "Puppy Linux Save State File",
    "3G2": "3GPP2 Multimedia File",
    "3GA": "3GPP Audio File",
    "3GP": "3GPP Multimedia File",
    "3GP2": "3GPP Multimedia File",
    "3GPP": "3GPP Media File",
    "3GPP2": "3GPP2 Multimedia File",
    "3MF": "3D Manufacturing File",
    "3MM": "3D Movie Maker Movie Project",
    "3P2": "3GPP Multimedia File",
    "3W": "XYZprinting Sliced Model File",
    "411": "Mavica Thumbnail Image",
    "477": "MNS Shape Definition Companion File",
    "4DB": "4th Dimension Database Structure File",
    "4DD": "4th Dimension Database Data File",
    "4DL": "4th Dimension Database Log File",
    "4DV": "4D View Ultrasound File",
    "4MP": "4-MP3 Database File",
    "4TH": "Forth Language File",
    "4UI": "ForeUI Plot File",
    "5XB": "Line 6 POD HD500X Edit Bundle",
    "5XE": "Line 6 POD HD500X Edit Preset File",
    "5XS": "Line 6 POD HD500X Edit Setlist File",
    "602": "Text602 Document",
    "60D": "CCTV Video Clip",
    "669": "UNIS Composer 669 Module",
    "68K": "SEGA Mega Drive & Genesis Classics ROM File",
    "73B": "TI-73 Backup File",
    "73I": "TI-73 Screenshot File",
    "73K": "TI-73 Application",
    "73U": "TI-73 Explorer Operating System File",
    "787": "AVTECH CCTV Video File",
    "7Z": "7-Zip Compressed File",
    "7Z.001": "7-Zip Split Archive Part 1 File",
    "7Z.002": "7-Zip Split Archive Part 2 File",
    "83P": "TI-83 Calculator File",
    "890": "Cavena Subtitles File",
    "89K": "TI-89 Application",
    "8BA": "Photoshop Plug-in",
    "8BC": "Photoshop 5.0 Plug-in",
    "8BE": "PhotoDeluxe Plug-in",
    "8BF": "Filter Factory Image Filter",
    "8BI": "Photoshop Plug-in",
    "8BI8": "Photoshop Plug-in",
    "8BL": "Photoshop Plug-in",
    "8BS": "Photoshop 5.0 Selection Plug-in",
    "8BX": "PhotoDeluxe Plug-in",
    "8BY": "PhotoDeluxe Plug-in",
    "8CA": "TI-84 Plus C Image Var Format",
    "8CI": "TI-84 Plus C Pic Vars Format",
    "8CK": "TI-84 Plus C Silver Edition Application File",
    "8CU": "TI-84 Plus C Operating System File",
    "8LI": "Photoshop Scripting Plug-in",
    "8PBS": "Adobe Photoshop Macintosh File",
    "8SVX": "Amiga 8-Bit Sound File",
    "8XI": "TI-83/84 Plus Picture File",
    "8XP": "TI-83 Plus Calculator File",
    "8XU": "TI-83 and TI-84 Plus Operating System File",
    "9.PNG": "NinePatchDrawable Image",
    "A": "Static Library",
    "A00": "ALZip Second Split Archive File",
    "A01": "ALZip Third Split Archive File",
    "A02": "ALZip Fourth Split Archive File",
    "A2B": "Adlib Tracker II Instrument Bank",
    "A2C": "Alice Object File",
    "A2I": "Adlib Tracker II Instrument File",
    "A2L": "ASAP2 ECU Description File",
    "A2M": "Adlib Tracker II File",
    "A2THEME": "Aston 2 Theme File",
    "A2W": "Alice World",
    "A3D": "Alternativa Player 3D Export File",
    "A4P": "A4Desk Pro Project File",
    "A5W": "Alpha Five Webpage File",
    "A6P": "Authorware 6 Program",
    "A7P": "Authorware 7 Project",
    "A7R": "Authorware 7 Runtime File",
    "A8S": "Anim8or Script",
    "AA": "Audible Audio Book File",
    "AA3": "ATRAC Audio File",
    "AAC": "Advanced Audio Coding File",
    "AAF": "Advanced Authoring Format File",
    "AAM": "Authorware Map File",
    "AAO": "America's Army Map File",
    "AAUI": "Acrobat User Interface File",
    "AAWDEF": "Ad-Aware Definitions File",
    "AAX": "Audible Enhanced Audiobook File",
    "AAXPLUGIN": "Avid Audio eXtension Plugin File",
    "AB": "Ambling BookPlayer MP3 File",
    "AB3": "PhotoImpact 3 Album File",
    "ABA": "Avant Browser Add-on File",
    "ABBU": "Address Book Backup",
    "ABC": "ABC Music Notation",
    "ABCD": "AudioVisual Book Data File",
    "ABCDDB": "Apple Address Book Contact List ",
    "ABF": "Adobe Binary Screen Font File",
    "ABI": "AbiWord Plug-in",
    "ABK": "Automatic Backup File",
    "ABM": "Music Album",
    "ABP": "AVS Barcode Profile",
    "ABR": "Adobe Photoshop Brushes File",
    "ABS": "Absolute Database File",
    "ABU": "Asus App Backup File",
    "ABU1": "ASUS Backup File",
    "ABW": "AbiWord Document",
    "ABX": "WordPerfect Address Book",
    "ABY": "AOL Address Book File",
    "AC": "Autoconf Script",
    "AC$": "AutoCAD Temporary File",
    "AC3": "Audio Codec 3 File",
    "AC5": "ArtCut 5 Document",
    "AC6": "ArtCut 6 Document",
    "ACB": "Adobe Photoshop Color Book File",
    "ACC": "Graphics Accounts Data File",
    "ACCDA": "Access Add-in File",
    "ACCDB": "Access 2007 Database File",
    "ACCDC": "Microsoft Access Signed Package",
    "ACCDE": "Access Execute Only Database",
    "ACCDR": "Access Runtime Application",
    "ACCDT": "Microsoft Access Database Template",
    "ACCDU": "Access Add-in File",
    "ACCDW": "Microsoft Access Database Link File",
    "ACCFT": "Microsoft Access Data Type Template",
    "ACCOUNTPICTURE-MS": "Windows 8 Account Picture File",
    "ACD": "ACID Project File",
    "ACD-BAK": "MAGIX ACID Project Backup File",
    "ACD-ZIP": "Sony ACID Project With Embedded Media File",
    "ACE": "WinAce Compressed File",
    "ACF": "Steam Application Cache File",
    "ACFM": "Adobe Composite Font Metrics File",
    "ACID": "ACID Encrypted File",
    "ACL": "AutoCorrect List File",
    "ACM": "Interplay Audio File",
    "ACO": "Adobe Photoshop Color Swatch File",
    "ACORN": "Acorn Image",
    "ACP": "aacPlus Audio File",
    "ACR": "American College of Radiology File",
    "ACROBATSECURITYSETTINGS": "Adobe Acrobat Security Settings File",
    "ACROPLUGIN": "Adobe Acrobat Plug-in",
    "ACS": "Agent Character File",
    "ACSM": "Adobe Content Server Message File",
    "ACT": "FoxPro Documenting Wizard Action Diagram",
    "ACTC": "Action(s) Collection File",
    "ACTION": "Automator Action",
    "ACTM": "AutoCAD Action Macro File",
    "ACV": "Photoshop Curves File",
    "ACW": "Windows Accessibility Wizard File",
    "ACWW": "Animal Crossing Wild World Pattern File",
    "ADADOWNLOAD": "Adobe Download Assistant Partial Download File",
    "ADAME": "Adame Ransomware Encrypted File",
    "ADB": "Now Contact Address Book Template",
    "ADC": "Scanstudio 16 Color Image",
    "ADCP": "Adobe Device Central Project File",
    "ADD": "Dynamics AX Developer Documentation File",
    "ADDIN": "Visual Studio Add-in Definition File",
    "ADDON": "CFS Console Add-on File",
    "ADE": "Access Project Extension",
    "ADF": "ARIS Express Document",
    "ADG": "Ableton Device Group",
    "ADI": "AutoCAD Device-Independent Binary Plotter File",
    "ADM": "Administrative Template File",
    "ADML": "Group Policy Language-Specific Administrative Template",
    "ADMX": "Group Policy Administrative Template File",
    "ADN": "Access Blank Project Template",
    "ADOBE": "Dharma Ransomware Encrypted File",
    "ADOC": "AsciiDoc File",
    "ADP": "Access Project",
    "ADPP": "Adobe Device Profile Package",
    "ADR": "Opera Bookmarks File",
    "ADS": "Ada Specification File",
    "ADT": "ACT! Document Template",
    "ADTS": "Audio Data Transport Stream File",
    "ADV": "Ableton Device Preset File",
    "ADX": "Approach Index File",
    "ADZ": "Compressed Amiga Disk File",
    "AEA": "AdWords Editor Archive",
    "AEC": "Cinema 4D After Effects Composition",
    "AECAP": "After Effects Text Template",
    "AEGRAPHIC": "Adobe After Effects Graphic",
    "AEP": "After Effects Project",
    "AEPKEY": "Advanced Encryption Package Key File",
    "AEPX": "After Effects XML Project",
    "AES": "AES Crypt Encrypted File",
    "AET": "After Effects Project Template",
    "AETX": "After Effects XML Project Template",
    "AEX": "Alpha Five Compiled Global Functions File",
    "AF2": "Micrografx ABC FlowCharter 2 File",
    "AF3": "Micrografx ABC FlowCharter 3/4 File",
    "AFC": "Mass Effect 2 Audio File",
    "AFD": "Alphacam Flame Drawing",
    "AFDESIGN": "Affinity Design Document",
    "AFF": "AFF Disk Image",
    "AFI": "AOMEI Backupper File Backup File",
    "AFM": "Adobe Font Metrics File",
    "AFP": "Advanced Function Presentation File",
    "AFPHOTO": "Affinity Photo Document",
    "AFPLOC": "Apple Filing Protocol Location",
    "AFS": "STAAD.foundation Project File",
    "AFT": "Ancestry.com Family Tree Database",
    "AFX": "Auto FX PhotoGraphic Edges Image",
    "AFZPLUG": "AfterShot Pro Plugin Archive",
    "AGE3REC": "Age of Empires 3 Recording",
    "AGE3SAV": "Age of Empires 3 Save File",
    "AGE3SCN": "Age of Empires 3 Scenario File",
    "AGE3XREC": "Age of Empires 3: The WarChiefs Recording",
    "AGE3XSAV": "Age of Empires 3: The WarChiefs Save File",
    "AGE3YREC": "Age of Empires 3: The Asian Dynasties Recording",
    "AGE3YSAV": "Age of Empires 3: The Asian Dynasties Save File",
    "AGG": "Bulk Data File",
    "AGI": "Asterisk Gateway Interface File",
    "AGIF": "Active GIF Creator Project",
    "AGM": "DTS Multi-channel Pro Packer File",
    "AGMODULE": "Adobe Lightroom Module",
    "AGP": "ArtGem Project File",
    "AGR": "Ableton Groove File",
    "AHD": "Dynamics AX Online Help Data File",
    "AHI": "Dynamics AX Online Help Index File",
    "AHK": "AutoHotkey Script",
    "AHL": "eMule Metadata File",
    "AHS": "Adobe Halftone Screen File",
    "AHU": "Adobe Photoshop HSL File",
    "AI": "Adobe Illustrator File",
    "AIA": "Adobe Illustrator Action File",
    "AIC": "Advanced Image Coding File",
    "AIF": "Audio Interchange File Format",
    "AIFB": "AIF Builder Project File",
    "AIFC": "Compressed Audio Interchange File",
    "AIFF": "Audio Interchange File Format",
    "AIM": "AIMMS ASCII Model File",
    "AIMPPL": "AIMP Playlist File",
    "AIN": "Source Engine Compiled AI Nodegraph File",
    "AIP": "Adobe Illustrator Plug-in",
    "AIR": "Adobe AIR Installation Package",
    "AIS": "ACDSee Image Sequence File",
    "AIT": "Adobe Illustrator Template",
    "AIU": "Advanced Installer Updates Configuration File",
    "AJP": "CCTV Video File",
    "AKP": "Akai Sampler File",
    "ALB": "Alpha Five Library",
    "ALBM": "HP Photo Printing Software Album File",
    "ALBUM": "GLC_Player Album File",
    "ALC": "Ableton Live Clip File",
    "ALD": "Dynamics AX Application Label Data File",
    "ALE": "Avid Log Exchange File",
    "ALF": "ACT! Lookup File",
    "ALI": "Dynamics AX Label Index File",
    "ALL": "Cubasis Project File",
    "ALP": "Ableton Live Pack File",
    "ALS": "Ableton Live Set File",
    "ALT": "Dynamics AX Temporary File",
    "ALV": "Adobe Photoshop Levels File",
    "ALX": "ActiveX Layout Control File",
    "ALZ": "ALZip Archive",
    "AM": "Anark Media File",
    "AM1": "Adventure Maker ",
    "AM4": "AutoPlay Media Studio 4 Project File",
    "AM5": "AutoPlay Media Studio 5 Project File",
    "AM6": "AutoPlay Media Studio 6 Project",
    "AM7": "AutoPlay Media Studio 7 Project",
    "AMC": "AMC Video File",
    "AMDN": "Amadine Drawing",
    "AMF": "Advanced Module File",
    "AMFM": "Adobe Multiple Font Metrics File",
    "AML": "ACPI Machine Language File",
    "AMR": "Adaptive Multi-Rate Codec File",
    "AMS": "Extreme Tracker Module",
    "AMV": "Anime Music Video File",
    "AMX": "Adobe Motion Exchange File",
    "AMXD": "Ableton Max Patch File",
    "AMXX": "AMX Mod X Plugin File",
    "AMZ": "Amazon MP3 Downloader File",
    "AN": "Adobe Edge Animate Project File",
    "AN8": "Anim8or File",
    "ANE": "Adobe AIR Native Extension",
    "ANG": "Anghami Audio File",
    "ANH": "Project ROME File",
    "ANI": "Windows Animated Cursor",
    "ANIM": "Amiga Animation File",
    "ANIMSET": "FaceFX Animation Set File",
    "ANIMSET_INGAME": "FaceFX In-Game Animation Set File",
    "ANM": "3D Animation File",
    "ANME": "Anime Studio Document",
    "ANN": "Help Annotations",
    "ANS": "ANSI Text File",
    "ANTMPL": "Adobe Edge Animate Template File",
    "ANX": "Annodex Exchange Format File",
    "ANY": "AnyRail Layout Plan",
    "AO": "ActionOutline Outline File",
    "AOB": "DVD-Audio Audio Object File",
    "AOD": "Dynamics AX Object Data File",
    "AOF": "Artlantis Object File",
    "AOI": "Art of Illusion 3D Scene",
    "AOM": "After Effects Output Module",
    "AOS": "ARCHOS PCtablet Firmware File",
    "AP": "ArtPro File",
    "APA": "RSView Development Project Archive",
    "APD": "ACDSee Photo Document",
    "APE": "Monkey's Audio Lossless Audio File",
    "APEX": "Android Pony Express Package File",
    "APF": "Adobe Profile File",
    "API": "Acrobat Plug-in",
    "APK": "Android Package File",
    "APKG": "Exported Anki Flashcard Deck",
    "APL": "Monkey's Audio Track Information File",
    "APLG": "Audials Plug-in",
    "APLP": "Audials Plug-in Package",
    "APM": "Aldus Placeable Metafile Image",
    "APNG": "Animated Portable Network Graphic",
    "APNX": "Amazon Page Number Index File",
    "APP": "macOS Application",
    "APPCACHE": "HTML5 Cache Manifest File",
    "APPDOWNLOAD": "Mac App Store Partially Downloaded App",
    "APPLESCRIPT": "AppleScript File",
    "APPLICATION": "ClickOnce Deployment Manifest File",
    "APPREF-MS": "Microsoft Application Reference File",
    "APPUP": "Erlang Application Upgrade File",
    "APPX": "Windows 8 App Package ",
    "APPXUPLOAD": "Windows 8 App Upload Package",
    "APR": "ArcView Project File",
    "APS": "Greeting Card Studio Project File",
    "APT": "Almost Plain Text File",
    "APX": "Ability Photopaint Studio Image",
    "APZ": "Autoplay Media Studio Exported Project",
    "AP_": "ADT Android Developer Package",
    "AQM": "AlpineQuest Map File",
    "AQT": "AQTitle Subtitles File",
    "AR": "Unix Static Library",
    "ARC": "Compressed File Archive",
    "ARCH00": "F.E.A.R. Game Archive",
    "ARCHIVER": "Archiver Compressed File Archive",
    "ARCUT": "Prelude Rough Cut File",
    "ARD": "ArtiosCAD Workspace File",
    "ARDUBOY": "Arduboy Game Package",
    "ARF": "WebEx Advanced Recording File",
    "ARG": "AutoCAD Profile",
    "ARH": "ProTool Compressed Project File",
    "ARI": "ARRIRAW Image",
    "ARIA": "Chipsounds Sound File",
    "ARIA2": "aria2 Control File",
    "ARIAX": "Chipsounds XML Sound File",
    "ARJ": "ARJ Compressed File Archive",
    "ARK": "PowerDesk Pro Archive",
    "ARO": "SteelArrow Web Application File",
    "ARP": "Audition Replay File",
    "ARPACK": "ArtRage Package",
    "ARR": "Amber Graphic File",
    "ARS": "After Effects Render Settings File",
    "ARSC": "Android Package Resource File",
    "ARSCRIPT": "ArtRage Script",
    "ART": "AOL Compressed Image File",
    "ARTB": "Artboard Document",
    "ARTICLE": "Twixl Publisher Article",
    "ARTPROJ": "Artifacts Project",
    "ARTWORK": "ArtStudio Image",
    "ARW": "ArtStudio Image",
    "ARX": "AutoCAD Runtime Extension File",
    "AS": "ActionScript File",
    "AS2PROJ": "FlashDevelop ActionScript 2 Project File",
    "AS3PROJ": "FlashDevelop ActionScript 3 Project File",
    "AS4": "askSam Backup File",
    "ASA": "ASP Configuration File",
    "ASAT": "Assemble SAT 3D Model File",
    "ASAX": "ASP.NET Server Application File",
    "ASB": "Alphacam Stone VB Macro File",
    "ASC": "ASCII Text File",
    "ASCII": "ASCII Text File",
    "ASCX": "ASP.NET User Control File",
    "ASD": "Ableton Live Sample Analysis File",
    "ASE": "Autodesk ASCII Scene Export File",
    "ASEC": "Android Secure Application File",
    "ASEF": "Adobe Swatch Exchange File",
    "ASEPRITE": "Aseprite Sprite File",
    "ASF": "Advanced Systems Format File",
    "ASHBAK": "Ashampoo Backup Archive",
    "ASHDISC": "Ashampoo Burning Studio Image",
    "ASHX": "ASP.NET Web Handler File",
    "ASI": "Grand Theft Auto Mod Library",
    "ASK": "askSam Database",
    "ASL": "Photoshop Style",
    "ASM": "Solid Edge Assembly File",
    "ASMX": "ASP.NET Web Service File",
    "ASP": "Active Server Page",
    "ASPX": "Active Server Page Extended File",
    "ASR": "ActionScript Remote Document",
    "ASS": "Aegisub Advanced Substation Alpha File",
    "ASSETPROJ": "Camtasia Studio Asset Information File",
    "AST": "Ability Spreadsheet Template",
    "ASV": "Finale Auto-save File",
    "ASVF": "Asphyre Sphinx Archive File",
    "ASVX": "Finale Auto-save File",
    "ASW": "ACDSee Slideshow Wizard File",
    "ASX": "Microsoft ASF Redirector File",
    "ASY": "Asymptote Module",
    "AT3": "ATRAC3 Audio File",
    "AT5": "Lowrance Map File",
    "ATAHD": "ATA Hard Drive Flag File",
    "ATC": "AutoCAD Tool Catalog File",
    "ATE": "Office Accounting Compressed Backup File",
    "ATF": "Alternativa Texture File",
    "ATH": "Alienware AlienFX Theme File",
    "ATI": "Office Accounting Updated Company File",
    "ATL": "Artlantis 3D Scene File",
    "ATM": "Vue Atmospheres File",
    "ATN": "Photoshop Actions File",
    "ATOM": "Atom Syndication Format",
    "ATR": "Atari Disk Image",
    "ATSOFTS": "LetEncrypt Encrypted File",
    "ATT": "Alphacam Lathe Tool File",
    "ATX": "ArcGIS Attribute Index File",
    "ATY": "Association Type Placeholder",
    "ATZ": "Aston Compiled Theme",
    "AU": "Audio File",
    "AU3": "AutoIt v3 Script",
    "AUD": "Video Game Compressed Audio File",
    "AUP": "Audacity Project File",
    "AURORA": "Aurora Ransomware Encrypted File",
    "AUTOMATICDESTINATIONS-MS": "Windows Jump List File",
    "AUTOPLAY": "AutoPlay Media Studio Project File",
    "AUX": "Auxiliary File",
    "AUZ": "Ableton Authorization File",
    "AV": "Video Surveillance File",
    "AV3": "Arbitrator Video Surveillance File",
    "AVA": "AvaaBook eBook",
    "AVASTLIC": "Avast License File",
    "AVASTSOUNDS": "Avast Soundpack File",
    "AVATAR": "Google Talk Avatar File",
    "AVB": "Avid Bin File",
    "AVC": "Avid Media Composer Script",
    "AVCHD": "High Definition Video File",
    "AVD": "Movie Edit Pro Video Information File",
    "AVE": "Avigilon Native Video Export File",
    "AVERY": "Avery Design & Print Label File",
    "AVGDX": "AVG Diagnostics File",
    "AVHD": "Hyper-V SnapShot File",
    "AVI": "Audio Video Interleave File",
    "AVL": "ArcView Legend File",
    "AVM": "Anime Music Video",
    "AVP": "Avid Project File",
    "AVR": "EverFocus Recording File",
    "AVS": "AviSynth Script File",
    "AVV": "Avid Volume Bin File",
    "AVX": "ArcView Extension File",
    "AW": "Answer Wizard File",
    "AWCAV": "ActiveWorlds Custom Avatar File",
    "AWD": "Microsoft Fax Document",
    "AWG": "Ability Draw Document",
    "AWK": "AWK Script",
    "AWLIVE": "Active Webcam Video File",
    "AWM": "AllWebMenus Project File",
    "AWP": "Ability Write Template",
    "AWS": "Ability Spreadsheet File",
    "AWT": "AbiWord Template",
    "AWW": "Ability Write Document",
    "AX": "DirectShow Filter",
    "AXD": "ASP.NET Web Handler File",
    "AXE": "AutoRoute Map File",
    "AXM": "AXMEDIS Object",
    "AXT": "Microsoft AutoRoute Template",
    "AXV": "Annodex Video File",
    "AXX": "AxCrypt Encrypted File",
    "AY": "AY Chiptune File",
    "AZ!": "Vuze Partial Download File",
    "AZF": "AirZip FileSECURE File",
    "AZS": "AirZip FileSECURE File",
    "AZW": "Amazon Kindle eBook File",
    "AZW1": "Amazon Topaz eBook",
    "AZW2": "Kindle Active Content App File",
    "AZW3": "Amazon KF8 eBook File",
    "AZW4": "Amazon Print Replica eBook",
    "B": "Grand Theft Auto 3 Saved Game File",
    "B1": "B1 Compressed Archive",
    "B2A": "Btoa Encoded File",
    "B3D": "Blitz3D Entity Model File",
    "B4S": "Winamp Playlist File",
    "B5I": "BlindWrite 5 Disk Image",
    "B5T": "BlindWrite 5 Disc Track Information File",
    "B64": "Base64 MIME-Encoded File",
    "B6I": "BlindWrite 6 Disc Image",
    "B6T": "BlindWrite 6 Track Information File",
    "B6Z": "B6Z Archive",
    "BA": "Scifer External Header Archive",
    "BA2": "Bethesda Softworks Archive",
    "BA6": "TaxAct 2016 Tax Return Backup File",
    "BA7": "TaxAct 2017 Tax Return Backup File",
    "BA8": "TaxAct 2018 Tax Return Backup File",
    "BAC": "Backup File",
    "BACKUP": "Android Backup File",
    "BACKUPDB": "Time Machine Backup Folder",
    "BAD": "Exchange Badmail File",
    "BAK": "Backup File",
    "BAK2": "Backup File",
    "BAK3": "Backup File",
    "BAKX": "Finale Backup File",
    "BAK~": "AbiWord Auto-Saved Document",
    "BAND": "GarageBand Project File",
    "BAP": "Blaze Audio Wave Information File",
    "BAR": "Age of Empires 3 Data File",
    "BAS": "BASIC Source Code File",
    "BASHRC": "Bash Non-Interactive Login Shell File",
    "BASH_HISTORY": "Bash History File",
    "BASH_PROFILE": "Bash Interactive Login Shell File",
    "BAT": "DOS Batch File",
    "BAU": "Apache OpenOffice AutoText File",
    "BAV": "AVG AntiVirus The Bat! Plugin File",
    "BAY": "Casio RAW Image",
    "BA_": "Renamed BAT File",
    "BB": "Blitz Source Code File",
    "BBB": "BlackBerry Mobile Phone Backup File",
    "BBC": "BBC BASIC Data File",
    "BBCD": "BobCAD-CAM Document",
    "BBL": "BibTeX Generated Bibliography File",
    "BBLM": "BBEdit Language Module",
    "BBPROJECT": "BBEdit Project File",
    "BBPROJECTD": "BBEdit Project Document",
    "BBS": "Bulletin Board System Text",
    "BBZ": "BerryBuzz Backup File",
    "BC": "BitComet Partially Downloaded File",
    "BC!": "BitComet Incomplete File",
    "BC5B": "Ransomware Encrypted File",
    "BCD": "RealView Debugger Board Chip Definition File",
    "BCF": "Business Card Designer Pro File",
    "BCI": "Belarc Advisor Report File",
    "BCK": "VMX Backup File",
    "BCKP": "Ad-Aware Quarantined File",
    "BCM": "Business Contact Manager File",
    "BCMX": "Business Contact Manager Customization",
    "BCP": "Business Card Designer Plus File",
    "BCS": "Batch Compiler Specification File",
    "BDAE": "Gameloft Game Data File",
    "BDB": "Microsoft Works Database Backup File",
    "BDC": "West Point Bridge Designer Design File",
    "BDD": "CARA Sound Radiation Data File",
    "BDF": "Glyph Bitmap Distribution Format",
    "BDIC": "Chrome Dictionary File",
    "BDL": "CoCreate Bundle File",
    "BDM": "AVCHD Information File",
    "BDMV": "Blu-ray Disc Movie Information File",
    "BDOC": "Binary DigiDoc Signature File",
    "BDP": "Exchange Diagnostic Message",
    "BDR": "Exchange Non-Delivery Report Body File",
    "BDSPROJ": "Borland Developer Studio Project",
    "BDT2": "BEEDOCS Timeline 3D 2 Document",
    "BDT3": "BEEDOCS Timeline 3D 3 Document",
    "BEAM": "Compiled Erlang File",
    "BEAN": "Bean Rich Text Document",
    "BEJEWELED2DELUXESAVEDGAME": "Bejeweled 2 Deluxe Saved Game",
    "BET": "BETA Source File",
    "BFA": "Blowfish Encrypted File",
    "BFC": "Windows Briefcase File",
    "BFF": "Backup File Format",
    "BFG": "Big Fish Games Application File",
    "BFS": "FlatOut Game Data File",
    "BGI": "BgInfo Configuration File",
    "BGL": "Babylon Glossary File",
    "BGT": "Graphics Accounts Data File",
    "BH": "BlakHole Archive",
    "BHX": "BinHex Encoded File",
    "BIB": "BibTeX Bibliography Database",
    "BIBTEX": "BibTeX Bibliography Database",
    "BIDULE": "Bidule Layout File",
    "BIF": "BioWare Infinity Engine File",
    "BIFX": "Get Backup Project",
    "BIG": "Electronic Arts Game Data File",
    "BIK": "Bink Video File",
    "BIK2": "Bink Video 2 File",
    "BIL": "ESRI BIL File",
    "BIMX": "BIM Explorer File",
    "BIN": "Binary Disc Image",
    "BIO": "Mudbox Bio 3D File",
    "BIP": "Character Studio Biped File",
    "BIT": "Xilinx Bitstream File",
    "BITPIM": "BitPim Configuration File",
    "BIX": "Kodicom Video File",
    "BIZ": "Broderbund Business Card File",
    "BJO": "TabRite Tablature File",
    "BK": "FrameMaker Book File",
    "BK1": "Windows Indexing Service File",
    "BK2": "Bink Video 2 File",
    "BKC": "Backup4all Backup Catalog",
    "BKF": "Windows Backup Utility File",
    "BKK": "BookBuddi eBook File",
    "BKMK": "Yummy FTP Bookmark File",
    "BKP": "Backup File",
    "BKS": "Microsoft Works Spreadsheet Backup File",
    "BKUP": "Backup File",
    "BKZ": "BaKoMa TeX Installation Module",
    "BLACKHAWKSTRIKER2": "Blackhawk Striker 2 Saved Game",
    "BLASTERBALL3SAVEDGAME": "BlasterBall 3 Saved Game",
    "BLB": "Blob Data File",
    "BLD": "Envisioneer Building Project File",
    "BLEND": "Blender 3D Data File",
    "BLEND1": "Blender Document Backup File",
    "BLEND2": "Blender Document Backup 2 File",
    "BLF": "CLFS Base Log File",
    "BLG": "Windows Binary Performance Log File",
    "BLK": "BLK360 Data File",
    "BLKRT": "Block Artist Image File",
    "BLOB": "Valve Steam Archive",
    "BLORB": "Interactive Fiction Package Game File",
    "BLOWER": "Blower Ransomware Encrypted File",
    "BLP": "Blizzard Texture File",
    "BLS": "Blockland Saved Game File",
    "BLT": "AIM Buddy List",
    "BLU": "FileMaker Pro Runtime Extension",
    "BLUEJ": "BlueJ Package File",
    "BLW": "Adobe Photoshop Black and White Presets File",
    "BLZ": "TeamViewer Blizz Session File",
    "BM2": "Subspace Bitmap File",
    "BM3": "Sony Ericsson Backup File",
    "BMC": "Bolide Movie Creator Project File",
    "BMD": "MU Online Game Data File",
    "BME": "BeatMania 7-Key Song File",
    "BMF": "Binary Material File",
    "BMI": "3ds Max Plug-in",
    "BMK": "PowerDVD MovieMark File",
    "BML": "Braille 2000 Braille File",
    "BMML": "Balsamiq Mockups Markup Language File",
    "BMP": "Bitmap Image File",
    "BMQ": "Re-Volt Mipmap File",
    "BMS": "BeatMania Song File",
    "BMX": "Siemens Mobile Animations File",
    "BMZ": "Compressed Bitmap Image",
    "BNA": "Barna Word Processor Document",
    "BND": "DB2 CLI Bind File",
    "BNDL": "Game Data Bundle File",
    "BNK": "Adlib Instrument Bank",
    "BNP": "Sony Camcorder Video Data File",
    "BNS": "Portal Bonus Map Script",
    "BO2": "Minecraft BO2 Object File",
    "BO3": "Minecraft BO3 Object File",
    "BOC": "EasyWord Big Document",
    "BOK": "ProStores Dynamic Web Page",
    "BOM": "Mac OS X Bill of Materials File",
    "BOO": "Booasm Compressed Archive",
    "BOOK": "FrameMaker Book File",
    "BOOKEXPORT": "BookSmart Backup Book File",
    "BOOKTEMPLATE": "BookSmart Template",
    "BOOKWORMDELUXESAVEDGAME": "Bookworm Deluxe Saved Game",
    "BOOT": "InstallShield Boot File",
    "BOOTSKIN": "Stardock Bootskin File",
    "BOX": "E-mail Mailbox",
    "BP2": "AutoCAD Batch Plot File",
    "BP3": "AutoCAD Batch Plot File",
    "BPA": "StorageSync Backup Archive",
    "BPB": "PowerDesigner Business Process Backup File",
    "BPDX": "Acrobat Batch PDX File",
    "BPF": "Baan ERP Document",
    "BPG": "BPG Image",
    "BPK": "Nero SecurDisc Public Key File",
    "BPL": "Borland Package Library",
    "BPM": "Bizagi Process Modeler",
    "BPMC": "Bizagi Process Modeler Collaboration",
    "BPN": "ArchiCAD Project Backup File",
    "BPNUEB": "PNU eBook File",
    "BPS": "BPS Patch File",
    "BPW": "Bitmap World File",
    "BPZ": "Easy Blue Print Symbol Library",
    "BQY": "Brio Query File",
    "BR": "Brotli Compressed File",
    "BR3": "Bryce 3 Scene File",
    "BR4": "Bryce 4 Scene File",
    "BR5": "Bryce 5 Scene File",
    "BR6": "Bryce 6 Scene File",
    "BR7": "Bryce 7 Scene File",
    "BRD": "Cadence Allegro PCB Design File",
    "BRG": "Age of Mythology Model File",
    "BRI": "Bryce Plug-in File",
    "BRK": "Brooktrout Fax Document",
    "BRM": "Bryce Plug-in File",
    "BRN": "Cube Graphics File",
    "BRO": "Broadleaf Tree Model",
    "BROWSER": "ASP.NET Browser Definition File",
    "BRRES": "Wii BRRES Resource Package",
    "BRSTM": "BRSTM Audio Stream File",
    "BRT": "Bryce Textures File",
    "BRW": "Calyx Point Borrower File",
    "BRX": "Beam Report Document",
    "BS2": "BASIC Stamp 2 Code File",
    "BS4": "Mikogo Session Video Recording",
    "BS7": "Windows 7 Boot Updater Skin",
    "BSA": "Bethesda Softworks Archive",
    "BSB": "BioShock Saved Game File",
    "BSC": "Visual Studio Source Browser Information File",
    "BSF": "Blu-ray AVC Video File",
    "BSK": "Bryce Skies File",
    "BSP": "Quake Engine Game Map File",
    "BSS": "Resident Evil Background Images File",
    "BST": "BibTeX Style Document",
    "BSW": "StruWalker 3D Model",
    "BSWX": "BIMReview 3D Model",
    "BT": "Binary Terrain File",
    "BT!": "BitSpirit Incomplete Download File",
    "BTAPP": "uTorrent App",
    "BTD": "Business-in-a-Box Document",
    "BTI": "Nintendo Texture File",
    "BTM": "BizTalk Map File",
    "BTO": "Bryce Tree File",
    "BTOA": "Binary-to-ASCII Encoded File",
    "BTR": "Btrieve Database File",
    "BTSEARCH": "BitTorrent Search Engine File",
    "BTW": "BarTender Label",
    "BU": "Samsung CCTV Video File",
    "BUD": "Binary Printer Description File",
    "BUN": "Cakewalk Bundle File",
    "BUNDLE": "Mac OS X Application Bundle",
    "BUP": "DVD IFO Backup File",
    "BUS": "OMSI Bus Configuration File",
    "BVD": "Bitdefender Vault File",
    "BVH": "Biovision Hierarchy Animation File",
    "BVP": "VodaHost BlueVoda Project File",
    "BVR": "Blue Iris Video",
    "BW": "Black and White SGI Image File",
    "BWA": "BlindWrite Disk Information File",
    "BWF": "Broadcast Wave File",
    "BWG": "BrainWave Generator Audio File",
    "BWI": "BlindWrite CD/DVD Disc Image",
    "BWP": "BuRg3r Web Page",
    "BWS": "BlindWrite Sub Code File",
    "BWT": "BlindWrite 4 Track Information FIle",
    "BWW": "Bagpipe Player File",
    "BWZ": "WinImage Batch Configuration File",
    "BXL": "Accelerated Designs PCB Library File",
    "BYU": "Brigham Young University Movie File",
    "BZ": "Bzip Compressed File",
    "BZ2": "Bzip2 Compressed File",
    "BZA": "IZArc BGA Archive",
    "BZABW": "Compressed AbiWord Document",
    "BZIP": "Bzip Compressed Archive",
    "BZIP2": "Bzip2 Compressed Archive",
    "BZPLUG": "AfterShot Pro Plugin Bundle",
    "BZW": "BZFlag World File",
    "C": "C/C++ Source Code File",
    "C00": "WinAce Split Archive File",
    "C01": "WinAce Split Archive Part 1 File",
    "C02": "WinAce Split Archive Part 1 File",
    "C10": "WinAce Split Archive Part 10",
    "C2D": "WinOnCD Disc Image",
    "C2R": "Windows Media Center Click-To-Record File",
    "C32": "Syslinux COM32 Module",
    "C3D": "C3D Model File",
    "C3Z": "OpenQwaq 3D Model File",
    "C4": "JEDMICS Image File",
    "C4D": "Cinema 4D Model File",
    "C4K": "Clonk Key File",
    "CAA": "CleanApp Archive",
    "CAB": "Windows Cabinet File",
    "CACHE": "Cache File",
    "CACTION": "Automator Converter Action",
    "CAD": "BobCAD-CAM File",
    "CADOC": "Clicker App Document",
    "CAF": "Core Audio File",
    "CAFF": "Core Audio File",
    "CAG": "ClipArt Gallery Package",
    "CAJ": "Chinese Academic Journal File",
    "CAL": "3ds Max Pose Adjustment File",
    "CALCA": "Calca Document",
    "CALIBRE": "Calibre Device Data File",
    "CALS": "CALS Raster Graphic File",
    "CAM": "CASIO Digital Camera Picture File",
    "CAMP": "WCS Color Appearance Model Profile File",
    "CAMPROJ": "Camtasia Studio Project",
    "CAMREC": "Camtasia Studio Screen Recording",
    "CAMV": "Camtasia Video File",
    "CAN": "Canon Navigator Fax Document",
    "CANNEDSEARCH": "Apple Predefined Search",
    "CAP": "Packet Capture File",
    "CAPROJ": "Construct Project File",
    "CAPT": "Capito Data File",
    "CAPX": "Construct Compressed Project File",
    "CAR": "CAR Archive",
    "CARC": "Nintendo Compressed Archive File",
    "CAROTE": "Carote Ransomware Encrypted File",
    "CAS": "Total War Model File",
    "CAT": "Advanced Disk Catalog Database",
    "CATDRAWING": "CATIA V5 Drawing",
    "CATPART": "CATIA V5 Part File",
    "CATPRODUCT": "CATIA V5 Assembly File",
    "CB7": "Comic Book 7-Zip Archive",
    "CBA": "Comic Book ACE Archive",
    "CBC": "Comic Book Collection",
    "CBDS": "Comic Book DS File",
    "CBF": "Calendar Builder File",
    "CBH": "ChessBase Database Header File",
    "CBK": "Backup Configuration File",
    "CBL": "COBOL Source Code File",
    "CBP": "Code::Blocks Project File",
    "CBR": "Comic Book RAR Archive",
    "CBS": "Comodo Backup Script",
    "CBT": "Comic Book TAR File",
    "CBU": "Comodo Backup File",
    "CBV": "ChessBase Database File",
    "CBZ": "Comic Book Zip Archive",
    "CC": "C++ Source Code File",
    "CCB": "CopperCube 3D Scene",
    "CCBJS": "CopperCube JavaScript File",
    "CCD": "CloneCD Disc Image",
    "CCF": "CryptLoad Container File",
    "CCGAME": "XNA Creators Club Game Package",
    "CCH": ".NET Security Resolution Cache File",
    "CCIP": "Curse Client Install Package",
    "CCN": "Compressed Multimedia Fusion File",
    "CCP": "CopperCube JavaScript File",
    "CCX": "Corel Clipart File",
    "CD": "CD-i OptImage",
    "CD2": "Click'N Design 3D File",
    "CD5": "Chasys Draw Image File",
    "CDA": "CD Audio Track Shortcut",
    "CDB": "Symbian Phonebook Database",
    "CDC": "AutoCAD DesignCenter Preview Cache File",
    "CDD": "ConceptDraw PRO Document",
    "CDDA": "CD Digital Audio File",
    "CDDX": "Circuit Diagram Document",
    "CDDZ": "ConceptDraw PRO Document",
    "CDF": "Common Data Format",
    "CDF-MS": "ClickOnce Compiled Manifest File",
    "CDG": "Compact Disc Plus Graphics Image",
    "CDI": "DiscJuggler Disc Image",
    "CDL": "CADKEY Wireframe Design File",
    "CDLX": "Audition CD Layout File",
    "CDM": "NTI CD-Maker Image",
    "CDML": "Creately Diagram File",
    "CDMM": "ConceptDraw MINDMAP Document",
    "CDMP": "WCS Device Model Profile",
    "CDMT": "ConceptDraw MINDMAP Template",
    "CDMTZ": "Compressed ConceptDraw MINDMAP Template",
    "CDMZ": "Compressed ConceptDraw MINDMAP Document",
    "CDO": "Crescendo Music Notation File",
    "CDOC": "Clicker Document",
    "CDP": "Trainz Simulator Content Dispatcher Pack",
    "CDP2": "Trainz Classics Content Dispatcher Pack 2",
    "CDR": "Raw Audio CD Data",
    "CDRAPP": "CorelDRAW.app Image File",
    "CDRT": "CorelDRAW Image Template",
    "CDS": "ConceptDraw SlideShow",
    "CDSX": "ConceptDraw PRO XML SlideShow File",
    "CDT": "ConceptDraw PRO Template",
    "CDTX": "ConceptDraw PRO XML Template",
    "CDW": "KOMPAS Document",
    "CDX": "ChemDraw Exchange File",
    "CDZ": "Compressed CD Image File",
    "CE": "ComputerEyes Image",
    "CEB": "Apabi eBook File",
    "CEBX": "Apabi XML eBook File",
    "CED": "JVC Camera Video Data File",
    "CEDPRJ": "Ashampoo CoverEditor Project",
    "CEF": "CenturionMail Encrypted Package",
    "CEL": "Affymetrix Probe Results File",
    "CELL": "Thinkfree Office NEO Cell Workbook",
    "CELTX": "Celtx Project File",
    "CELX": "Celestia Script",
    "CENON~": "Cenon Backup File",
    "CER": "Internet Security Certificate",
    "CERBER": "Cerber Ransomware Encrypted File",
    "CERBER2": "Cerber2 Ransomware Encrypted File",
    "CERBER3": "Cerber Ransomware Virus File",
    "CEX": "SolidWorks Enterprise PDM Vault Export File",
    "CF2": "Common File Format File",
    "CFA": "Adobe Conformed Audio File",
    "CFC": "ColdFusion Component File",
    "CFF": "Common File Format",
    "CFG": "Configuration File",
    "CFL": "IMVU Product File",
    "CFM": "ColdFusion Markup File",
    "CFML": "ColdFusion Markup Language File",
    "CFS": "Compact File Set Archive",
    "CG": "Cg Program",
    "CG3": "Cabri 3D Document",
    "CGA": "Crytek Geometry Animation File",
    "CGF": "Crytek Geometry Format File",
    "CGFX": "CgFX Shader File",
    "CGI": "Common Gateway Interface Script",
    "CGM": "Computer Graphics Metafile",
    "CGP": "PixelCryptor Encrypted File",
    "CGR": "CATIA Graphical Representation File",
    "CGRP": "Pro Tools Clip Group File",
    "CGZ": "Cube Map File",
    "CH3": "Harvard Graphics DOS Chart File",
    "CHA": "IRC Chat Configuration File",
    "CHAI": "Chaimera Artwork File",
    "CHAIT": "Chaimera Artwork Template",
    "CHARSET": "Character Set",
    "CHAT": "IRC Chat Configuration File",
    "CHD": "MAME Hard Disk Image",
    "CHG": "Windows Net Logon File",
    "CHK": "StarCraft Chunk File",
    "CHL": "WinFast PVR2 Channel List",
    "CHM": "Compiled HTML Help File",
    "CHML": "Chameleon Encrypted Database File",
    "CHORD": "Song Chords File",
    "CHR": "3ds Max Characters File",
    "CHRPARAMS": "CryENGINE Character Parameters File",
    "CHS": "Windows Chinese Noise-Word List File",
    "CHT": "Windows Chinese Traditional Noise-Word List File",
    "CHUNK001": "File Splitter Split Archive Part 1",
    "CHW": "Compiled Help Index File",
    "CHX": "AutoCAD Standards Check File",
    "CI": "Windows Content Indexer Catalog File",
    "CIB": "Luminaire Data File",
    "CID": "Navigator Chart Image Description File",
    "CIDB": "iTunes CD Information File",
    "CIF": "Easy CD Creator Disk Image",
    "CIL": "Clip Gallery Packaged File",
    "CIMG": "CImg Image File",
    "CIN": "Kodak Cineon Bitmap File",
    "CINE": "Phantom Digital Video File",
    "CIP": "Cavena Subtitles File",
    "CIRCUIT": "KTechlab Circuit Design File",
    "CISO": "Compact ISO File",
    "CIT": "Intergraph Bitmap Image File",
    "CK9": "Cook'n Cookbook Backup File",
    "CKB": "Cricket Audio Bank File",
    "CKD": "Kubotek Design Container",
    "CKF": "Casio Keyboard File",
    "CKP": "SQL Server Checkpoint File",
    "CKT": "CircuitMaker File",
    "CL": "Cursor Library",
    "CL2ARC": "Comic Life 2 Document Archive",
    "CL2DOC": "Comic Life 2 Document",
    "CL2LYT": "Comic Life 2 Layout File",
    "CL2TPL": "Comic Life 2 Template",
    "CL5": "Easy CD Creator 5 Saved Project",
    "CLARIFY": "Clarify Document",
    "CLASS": "Java Class File",
    "CLB": "COM+ Catalog File",
    "CLD": "Canon CD Label Template",
    "CLEO": "CLEO Grand Theft Auto Mod File",
    "CLG": "Windows Catalog File",
    "CLIP": "Clip Studio Format File",
    "CLIPS": "Coda Clips File",
    "CLK": "ClickView Video File",
    "CLKB": "Clicker Books File",
    "CLKBD": "Clicker Board Set",
    "CLKC": "Clicker Connect Set File",
    "CLKD": "Clicker Docs File",
    "CLKK": "Clicker Keyboard",
    "CLKT": "Clicker Template",
    "CLKW": "Clicker Word Bank",
    "CLKX": "Clicker Grid Set",
    "CLM": "MagicJack Call Log File",
    "CLP": "CrazyTalk Clip File",
    "CLPI": "Blu-ray Clip Information File",
    "CLR": "CryptLoad Router Information File",
    "CLS": "Program Class File",
    "CLT": "Clarity Legal Transcript File",
    "CLW": "Visual C++ ClassWizard File",
    "CLX": "Ceelox SecureMail Secure Message",
    "CM0013": "Samsung Smart TV Index File",
    "CM2": "Poser Camera Set File",
    "CMA": "Coach Activity File",
    "CMATE": "ControllerMate File",
    "CMD": "Windows Command File",
    "CME": "Command Multimedia Evidence File",
    "CMF": "Cal3D Binary Mesh File",
    "CML": "OGC Web Map Context Document",
    "CMM": "Corel Multimedia Manager Album",
    "CMMP": "Camtasia MenuMaker Project",
    "CMMTPL": "Camtasia MenuMaker Template",
    "CMO": "ASUS BIOS File",
    "CMOD": "Celestia Model",
    "CMP": "Solid Edge Wire Harness File",
    "CMPROJ": "Camtasia Project File",
    "CMR": "U.S. Sectional Chart Map File",
    "CMREC": "Camtasia Recording",
    "CMS": "Car Mechanic Simulator 3D Car Model File",
    "CMV": "CorelMOVE Animation",
    "CMX": "Corel Metafile Exchange Image File",
    "CMZ": "Compressed Poser Camera Set File",
    "CNA": "Catena Project File",
    "CNC": "PartMaster CNC File",
    "CND": "Melco Condensed Embroidery File",
    "CNDX": "Avery DesignPro for Mac Label File",
    "CNF": "MySQL Configuration File",
    "CNG": "CryptoNG Encrypted Archive",
    "CNM": "NoteMap Outline File",
    "CNT": "Help Contents File",
    "CNV": "Canvas 6-8 Drawing File",
    "COB": "COBOL Source Code File",
    "COD": "Atlantis Word Processor Encrypted Document",
    "CODAPLUGIN": "Coda Plug-in",
    "CODASITE": "Coda Site File",
    "COF": "MPLAB COFF File",
    "COFFEE": "CoffeeScript JavaScript File",
    "COLORPICKER": "Color Picker Plugin",
    "COLZ": "Adobe Collage File",
    "COM": "DOS Command File",
    "COMIC": "Comic Life Comic",
    "COMICDOC": "Comic Life Document",
    "COMICLIFE": "Comic Life Document",
    "COMMAND": "Terminal Command File",
    "COMP": "Fusion Composition File",
    "COMPILED": "Compiled Game Resource File",
    "COMPONENT": "Mac OS X System Component",
    "COMPOSITEFONT": "Windows Composite Font File",
    "COMPOSITIONTEMPLATE": "Invantive Composition Template",
    "COMPPKG.HAUPTWERK.RAR": "Hauptwerk Component Package",
    "COMPPKG_HAUPTWERK_RAR": "Hauptwerk Component Package",
    "COMPRESSED": "WordCompress Compacted Web File",
    "CON": "Concept Application Source File",
    "CONF": "Unix Configuration File",
    "CONFIG": "Configuration File",
    "CONFIGPROFILE": "Apple Configuration Profile",
    "CONFORM": "Conformalizer Change List File",
    "CONSIS": "Sciral Consistency Document",
    "CONTACT": "Windows Contact File",
    "CONTOUR": "Contour Screenplay File",
    "COOT": "Coot Ransomware Encrypted File",
    "COPRESET": "Capture One Preset File",
    "COPY": "Sony Ericsson Protected Content File",
    "COR": "CorelDRAW Drawing",
    "COS": "Capture One Settings File",
    "COS2": "Pinnacle Studio Cache File",
    "COSTYLE": "Capture One Style File",
    "COURSE": "Super Mario ReMaker Course File",
    "COV": "Fax Cover Page File",
    "COX": "Click & Create Extension",
    "CP": "Xcode C++ Source File",
    "CP3": "Grand Prix 3 Cockpit Shape File",
    "CP9": "ChoicePoint Encrypted File",
    "CPA": "CADSTAR PCB Archive File",
    "CPBITMAP": "iOS Wallpaper Image",
    "CPC": "CPC Compressed Image File",
    "CPD": "Compressed PhotoDefiner Image File",
    "CPDX": "Adobe Captivate Storyboard Project",
    "CPE": "Fax Cover Page File",
    "CPF": "Cab Provisioning Format File",
    "CPG": "Manga Studio Page File",
    "CPGZ": "Compressed CPIO Archive",
    "CPH": "Corel Print House File",
    "CPHD": "CloudChan Pre-processed Hypertext Document",
    "CPI": "AVCHD Video Clip Information File",
    "CPIO": "Unix CPIO Archive",
    "CPL": "Windows Control Panel Item",
    "CPN": "Age of Mythology Campaign File",
    "CPP": "C++ Source Code File",
    "CPQ": "Compaq OEM Disc Configuration File",
    "CPR": "Cubase Project",
    "CPS": "Corel Photo House File",
    "CPT": "DTS Compact Audio File",
    "CPTM": "Captivate Theme File",
    "CPVC": "Adobe Captivate Video Composition",
    "CPX": "Corel CMX Compressed File",
    "CPY": "3ds Max Copy Track File",
    "CR2": "Poser Character Rigging File",
    "CR3": "Canon Raw 3 Image File",
    "CRASH": "Mac OS X Crash Log File",
    "CRASHED": "AbiWord Crash-Saved Document",
    "CRC": "Total Commander Checksum File",
    "CRD": "Windows CardSpace File",
    "CRDOWNLOAD": "Chrome Partially Downloaded File",
    "CRDS": "Windows CardSpace Backup File",
    "CREC": "Lync Video File",
    "CRF": "Cal3D Binary Materials File",
    "CRL": "Certificate Revocation List File",
    "CRP": "Cities: Skylines Colossal Raw Asset Package",
    "CRT": "Security Certificate",
    "CRTR": "MultiAd Creator Pro Document",
    "CRTX": "Office 2007 Chart Template File",
    "CRV": "VCarve Pro Design File",
    "CRW": "Canon Raw CIFF Image File",
    "CRWL": "Windows Crawl File",
    "CRX": "Chrome Extension",
    "CRYPT": "WhatsApp Encrypted Database File",
    "CRYPT1": "UltraCrypter Ransomware Encrypted File",
    "CRYPT12": "WhatsApp Encrypted Database File",
    "CRYPT5": "WhatsApp Encrypted Database File",
    "CRYPT6": "WhatsApp Encrypted Database File",
    "CRYPT7": "WhatsApp Encrypted Database File",
    "CRYPT8": "WhatsApp Encrypted Database File",
    "CRYPT9": "WhatsApp Encrypted Database File",
    "CRYPTED": "WinOptimizer Encrypted File",
    "CRYPTRA": "Cryptra Encrypted File",
    "CRZ": "Compressed Poser Character Rigging File",
    "CS": "C# Source Code File",
    "CS1": "CaptureShop 1-shot Raw Image",
    "CSA": "PNA Code Calset File",
    "CSAPLAN": "SPSS Analysis Plan File",
    "CSD": "Manga Studio Scene File",
    "CSF": "Cal3D Binary Skeleton File",
    "CSH": "Cubase Waveform File",
    "CSHTML": "ASP.NET Razor Web Page",
    "CSI": "ContentServ Include File",
    "CSKIN": "CD Art Display Skin File",
    "CSM": "Character Studio Marker File",
    "CSN": "Adobe Code Snippet Document",
    "CSO": "Compiled Shader Object File",
    "CSP": "Concept Server Page",
    "CSPLAN": "SPSS Sampling Plan File",
    "CSPROJ": "Visual Studio C# Project",
    "CSR": "Certificate Signing Request File",
    "CSS": "Cascading Style Sheet",
    "CST": "Director External Cast File",
    "CSV": "Comma Separated Values File",
    "CSX": "Visual C# Script",
    "CSY": "Canvas Symbol File",
    "CT": "Scitex Continuous Tone File",
    "CTB": "AutoCAD Color-Based Plot Style File",
    "CTBODYFITTING": "CrazyTalk Animator Actor Fitting File",
    "CTF": "WhereIsIt Catalog File",
    "CTG": "Canon Digital Camera Catalog File",
    "CTL": "Visual Basic UserControl Object File",
    "CTP": "CakePHP Template",
    "CTS": "CrazyTalk Script File",
    "CTX": "Valve ICE Encoded Script",
    "CTXT": "BlueJ Context File",
    "CTY": "SimCity City File",
    "CTZ": "Cherrytree Password-protected XML Document",
    "CU": "CUDA Source Code File",
    "CUB": "Analysis Services Cube File",
    "CUE": "Cue Sheet File",
    "CUI": "Autodesk Custom Workspace File",
    "CUIX": "AutoCAD Custom User Interface File",
    "CUL": "Windows Cursor Library",
    "CUR": "Windows Cursor",
    "CUSTOMDESTINATIONS-MS": "Windows 7 Jump List File",
    "CUT": "Dr. Halo Bitmap Image File",
    "CV5": "Canvas 5 Drawing File",
    "CVA": "HP System Software Manager Information File",
    "CVC": "cVideo",
    "CVD": "ClamAV Virus Definitions File",
    "CVF": "CPU-Z Validation File",
    "CVG": "Calamus Vector Graphic File",
    "CVI": "Canvas Image File",
    "CVN": "CineVision Encoding Session",
    "CVR": "Microsoft Crash Report File",
    "CVS": "Canvas 3 Drawing File",
    "CVSRC": "CVS Command File",
    "CVT": "Canvas External Tool File",
    "CVW": "CaseView Document",
    "CVX": "Canvas Drawing File",
    "CW": "CardWorks Template",
    "CWB": "Cakewalk Bundle",
    "CWP": "Cakewalk SONAR Project",
    "CWS": "Claris Works Template",
    "CWT": "Cakewalk SONAR Template",
    "CX3": "CMS Recorded Video File",
    "CXARCHIVE": "CrossOver Bottle Archive",
    "CXF": "Coordinates Export Format",
    "CXI": "FMAT RAW Image",
    "CXP": "CX-Programmer Project File",
    "CXX": "C++ Source Code File",
    "CYBERDUCKLICENSE": "Cyberduck Donation Key",
    "CYBERDUCKPROFILE": "Cyberduck Connection Profile",
    "CYI": "Clustify Input File",
    "CYP": "Home Designer Pro Project File",
    "CYW": "Rbot.CYW Worm File",
    "CZD": "CAD Zone Drawing",
    "CZIP": "ZipGenius CryptoZip File",
    "D": "D Source Code File",
    "D00": "VirtualDrive Disc Image Part File",
    "D01": "VirtualDrive Disc Image Part 2 File",
    "D2V": "DVD2AVI File",
    "D3D": "Game Maker 3D File",
    "D3V": "Datel Video File",
    "D64": "Commodore 64 Disk Image",
    "D88": "Toshiba Pasopia 7 Disk File",
    "DA0": "Windows Registry Backup File",
    "DA2": "Ad-Aware License File",
    "DAA": "PowerISO Direct-Access-Archive",
    "DACONNECTIONS": "RemObjects Data Abstract Connections File",
    "DACPAC": "SQL Server Data Tier Application Package",
    "DAD": "IMS200 Video Record File",
    "DADIAGRAMS": "RemObjects Data Abstract Data Diagrams File",
    "DAE": "Digital Asset Exchange File",
    "DAF": "DupArchive Format File",
    "DAL": "DVD-lab Project File",
    "DAM": "DeltaMaster Analysis Model",
    "DAO": "Disk at Once CD/DVD Image",
    "DAP": "Access Data Access Page",
    "DAR": "DVD Architect Project",
    "DAS": "DeltaMaster Analysis Session",
    "DASCHEMA": "RemObjects Data Abstract Schema File",
    "DASH": "MPEG-DASH Video File",
    "DAT": "Data File",
    "DAT_NEW": "Minecraft World Level File",
    "DAV": "DVR365 Video File",
    "DAX": "PSP Compressed ISO Disc Image",
    "DAZ": "DAZ Studio 3D Scene",
    "DAZIP": "Dragon Age: Origins Game File",
    "DB": "Database File",
    "DB-JOURNAL": "SQLite Rollback Journal File",
    "DB-SHM": "SQLite Database Shared Memory File",
    "DB-WAL": "SQLite Database Write-Ahead Log File",
    "DB.CRYPT": "WhatsApp Encrypted Database File",
    "DB.CRYPT12": "WhatsApp Encrypted Database File",
    "DB.CRYPT8": "WhatsApp Encrypted Database File",
    "DB1": "Tekla Structures Model File",
    "DB2": "Samsung CCTV Video Information File",
    "DB3": "SQLite Database File",
    "DBA": "CryENGINE Animation Database File",
    "DBB": "Skype User Information File",
    "DBC": "DAZ Brick Camera File",
    "DBD": "DemoShield Project",
    "DBF": "Database File",
    "DBG": "Visual FoxPro Debugger Configuration File",
    "DBK": "Sony Ericsson Mobile Phone Backup File",
    "DBL": "DAZ Brick Light File",
    "DBM": "DAZ Brick Material File",
    "DBML": "Visual Studio OR Design File",
    "DBO": "DarkBASIC Object",
    "DBPRO": "DarkBASIC Professional Project File",
    "DBPROJ": "Visual Studio Database Project File",
    "DBQ": "AutoCAD Query Set",
    "DBR": "DeepBurner Disc Project",
    "DBS": "GAMBIT Mesh File",
    "DBT": "Database Text File",
    "DBV": "Database Variable Field",
    "DBX": "Dropbox Encrypted Database File",
    "DC": "DesignCAD Design File",
    "DC1": "DevCad Document",
    "DC2": "Kodak Photo-Enhancer File",
    "DC3": "DesignCAD 3D ASCII Drawing",
    "DC4": "ViaThinkSoft (De)Coder 4 File",
    "DCA": "DisplayWrite Document",
    "DCB": "Concordance Database File",
    "DCD": "DesignCAD Drawing",
    "DCE": "DriveCam Video File",
    "DCF": "Document Computation Format",
    "DCK": "Resolume Deck File",
    "DCL": "AutoCAD Dialog Definition File",
    "DCM": "DiskCatalogMaker Catalog File",
    "DCMD": "DiskCatalogMaker Thumbnail-Enabled Catalog",
    "DCO": "Safetica Free Encrypted Virtual Disk Archive",
    "DCOVER": "Disc Cover File",
    "DCP": "Adobe DNG Camera Profile",
    "DCPROJ": "Dashcode Project",
    "DCR": "Shockwave Media File",
    "DCS": "Desktop Color Separation File",
    "DCST": "Adobe InDesign Document Presets File",
    "DCT": "Dictation Audio File",
    "DCTMP": "DC++ Partially Downloaded File",
    "DCU": "Delphi Compiled Unit",
    "DCUIL": "Delphi .NET Compiled Unit File",
    "DCX": "Zsoft Multi-Page Paintbrush File",
    "DD": "DiskDoubler Archive",
    "DDAT": "DivX Temporary Video File",
    "DDB": "Device Dependent Bitmap",
    "DDC": "DivX Descriptor File",
    "DDCX": "DivX Descriptor 2 File",
    "DDD": "GLBasic 3D Data File",
    "DDF": "Diamond Directive File",
    "DDL": "Data Definition Language File",
    "DDOC": "DigiDoc Signature File",
    "DDRW": "ClarisDraw Drawing",
    "DDS": "DirectDraw Surface",
    "DDT": "Age of Mythology Textures File",
    "DE": "DrawExpress Diagram File",
    "DEB": "Debian Software Package",
    "DEC": "Magic: The Gathering Online Deck File",
    "DECRYPT": "Decrypted Microsoft ESD File",
    "DED": "Dr. Engrave Document",
    "DEF": "SmartWare II Data File",
    "DEFT": "Juice Grinder Defaults File",
    "DEK": "Eavesdropper Batch File",
    "DEM": "Video Game Demo File",
    "DER": "DER Certificate File",
    "DES": "Corel Designer File",
    "DESIGN": "Microsoft Expression Design Drawing",
    "DESKLINK": "Desktop Shortcut",
    "DESKTHEMEPACK": "Windows 8 Desktop Theme Pack File",
    "DESKTOP": "Desktop Entry File",
    "DEV": "Windows Device Driver File",
    "DEVICEIDS": "Device Identification FIle",
    "DEVICEMETADATA-MS": "Device Metadata Package",
    "DEWF": "SoundEdit Recorded Instrument",
    "DEX": "Excel Spreadsheet",
    "DF1": "Omnis Native Datafile",
    "DF2": "Defractor 2 Instrument",
    "DFC": "Defractor Instrument",
    "DFF": "DSD Audio File",
    "DFG": "Data Flask Grid File",
    "DFM": "Delphi Form",
    "DFONT": "Mac OS X Data Fork Font",
    "DFP": "Fusion Plugin File",
    "DFS": "BrainSuite Surface File",
    "DFT": "Solid Edge Draft Document",
    "DFTI": "FlexiWrite Document",
    "DFU": "iOS DFU File",
    "DFX": "Drafix CAD File",
    "DGB": "FlashCAD Drawing Database",
    "DGC": "DGCA File Archive",
    "DGK": "Delcam 3D Model File",
    "DGML": "Visual Studio Directed Graph Document",
    "DGN": "MicroStation Design File",
    "DGS": "Dagesh Pro Document",
    "DGSL": "Visual Shader Graph File",
    "DGT": "DST Thumbnail File",
    "DHS": "HyperSnap Drawing",
    "DHTML": "Dynamic HTML file",
    "DIA": "Dia Diagram File",
    "DIAGCAB": "Troubleshooting Pack Cabinet File",
    "DIAGCFG": "Troubleshooting Pack Configuration File",
    "DIAGPKG": "Troubleshooting Pack File",
    "DIB": "Device Independent Bitmap File",
    "DIC": "DICOM Image",
    "DICOM": "DICOM Image File",
    "DICPROOF": "Microsoft Dictionary Proofing File",
    "DIF": "Data Interchange Format",
    "DIFF": "Patch File",
    "DIG": "Sound Designer Audio File",
    "DII": "Summation Batch Load File",
    "DIM": "DIME File",
    "DIMAX": "DiMAX Firmware Image File",
    "DIME": "Direct Internet Message Encapsulation File",
    "DINFO": "DivX Temporary Video Info File",
    "DIR": "Adobe Director Movie",
    "DIRECTORY": "KDE Folder View Properties File",
    "DIS": "Oracle Discoverer Workbook",
    "DISABLED": "Spybot - Search & Destroy Disabled File",
    "DISC": "Toast Document",
    "DISCO": "DISCO Discovery Document",
    "DISCOMAP": "DISCO Discovery Output File",
    "DISK": "Linux Virtual Hard Disk",
    "DISKDEFINES": "Linux LiveCD Information File",
    "DIST": "Mac OS X Distribution Script",
    "DIT": "Active Directory Information Tree File",
    "DIV": "DIVA-GIS Project File",
    "DIVX": "DivX-Encoded Movie File",
    "DIX": "DIVA-GIS Export File",
    "DIY": "My Drivers Backup Setup File",
    "DIZ": "Description in Zip File",
    "DJV": "DjVu Image",
    "DJVU": "DjVu Image",
    "DL": "Zoo Tycoon 2 Data File",
    "DLC": "Download Link Container File",
    "DLD": "EdLog Compiled Program",
    "DLG": "Digital Line Graph",
    "DLIS": "DLIS Well Log Data File",
    "DLL": "Dynamic Link Library",
    "DLM": "Akamai Download Manager File",
    "DLO": "3ds Max Plug-in",
    "DLR": "finalRender Plugin",
    "DLS": "Downloadable Sounds File",
    "DLU": "3ds Max Utility Plug-in File",
    "DLV": "CATIA 4 Export File",
    "DLX": "Sony VDU Video File",
    "DL_": "Compressed DLL File",
    "DM": "DRM Delivery Message",
    "DM1": "ER/Studio Data Model File",
    "DM2": "Toad Data Modeler 2 File",
    "DM3": "DigitalMicrograph Image",
    "DMB": "Digital Multimedia Broadcasting File",
    "DMC": "DPCM Sample File",
    "DMD": "SQL Developer Data Modeler File",
    "DMF": "Delusion Digital Music File",
    "DMG": "Apple Disk Image",
    "DMGPART": "Mac OS X Disk Image Part",
    "DMI": "BYOND Dream Maker Icon File",
    "DML": "DynaScript File",
    "DMO": "Duke Nukem 3D Demo File",
    "DMP": "Windows Memory Dump",
    "DMS": "Disk Masher Image",
    "DMSA": "Music Disc Creator Project File",
    "DMSD": "Roxio MyDVD Project",
    "DMSD3D": "Roxio MyDVD 3D Project",
    "DMSE": "Sound Editor Project File",
    "DMSM": "VideoWave Movie Project File",
    "DMSM3D": "VideoWave 3D Movie Project File",
    "DMSP": "PhotoSuite Project File",
    "DMSS": "VideoWave SlideShow Project File",
    "DMT": "DeLorme Transfer File",
    "DMTEMPLATE": "Direct Mail Template",
    "DMX": "Source Filmmaker Project File",
    "DMX-INFO": "DriverMax Driver Information File",
    "DM_82": "Wolfenstein 1.00 Demo Movie File",
    "DM_83": "Wolfenstein 1.02 Demo Movie File",
    "DM_84": "Wolfenstein 2.06 Demo Movie File",
    "DN": "Adobe Dimension Document",
    "DNA": "CA Backup and Migration Backup File",
    "DNC": "Windows Dancer File",
    "DNE": "Netica Text File",
    "DNF": "Duke Nukem Forever Map File",
    "DNG": "Digital Negative Image File",
    "DNL": "DNAML eBook File",
    "DNS": "Duke Nukem Forever Save File",
    "DO": "Java Servlet",
    "DOB": "Visual Basic UserDocument",
    "DOC": "Microsoft Word Document",
    "DOC#": "LibreOffice Document Lock File",
    "DOCHTML": "Microsoft Word HTML Document",
    "DOCKZIP": "ObjectDock File",
    "DOCM": "Word Open XML Macro-Enabled Document",
    "DOCMHTML": "Microsoft Word MIME HTML Document",
    "DOCX": "Microsoft Word Open XML Document",
    "DOCXML": "Microsoft Word XML Document",
    "DOCZ": "ThinkFree Online Note Document",
    "DOK": "DesktopOK Icons Layout File",
    "DOL": "GameCube Executable File",
    "DOLPHINVIEW": "Dolphin Folder View Settings File",
    "DOT": "Word Document Template",
    "DOTHTML": "Microsoft Word HTML Document Template",
    "DOTM": "Word Open XML Macro-Enabled Document Template",
    "DOTX": "Word Open XML Document Template",
    "DOV": "Temp File",
    "DOWNLOAD": "Partially Downloaded File",
    "DOWNLOADHOST": "MSN Download Settings File",
    "DOWNLOADING": "Pando Incomplete Download File",
    "DOX": "MultiMate Document",
    "DP1": "DataPower Database File",
    "DPA": "DrawPlus Animation File",
    "DPB": "DataPilot Backup File",
    "DPD": "Ovation Pro File",
    "DPG": "Nintendo DS Movie File",
    "DPK": "Delphi Package",
    "DPKW": "Delphi Package",
    "DPL": "Delphi Package Library",
    "DPM": "Pro Tools Plugin File",
    "DPP": "DrawPlus Drawing File",
    "DPR": "Digital InterPlot File",
    "DPROJ": "Delphi Project",
    "DPX": "Digital Picture Exchange File",
    "DQY": "Excel Query File",
    "DR": "DRM Rights Object",
    "DR5": "Dramatica Story Expert Project",
    "DRA": "Nuance Dragon Voice Recording File",
    "DRAWING": "Artboard Drawing",
    "DRAWIT": "DrawIt Drawing",
    "DRC": "DRM Rights Object",
    "DREAM": "Dream Animated Wallpaper File",
    "DRF": "VIZ Render File",
    "DRG": "I-Doser Audio Drug File",
    "DRL": "Gerber Drill Rack File",
    "DRM": "Cubase Drum Map File",
    "DRMX": "Drumlin Fully Secure PDF File",
    "DRMZ": "Drumlin Fully Secure Mobile PDF File",
    "DROPBOX": "Dropbox Shared Folder Tracker",
    "DRP": "DaVinci Resolve Project",
    "DRPM": "Delta RPM File",
    "DRU": "EAGLE Design Rules File",
    "DRV": "Device Driver",
    "DRW": "Drawing File",
    "DRWDOT": "SolidWorks Drawing Template",
    "DRZ": "Draz Paint File",
    "DS": "LMMS DrumSynth File",
    "DS2": "Olympus DSS Pro Audio File",
    "DSA": "DAZ Studio 3+ Script",
    "DSB": "Wondershare DVD Slideshow Builder Project",
    "DSC": "Text Description File",
    "DSD": "DAZ Studio Object Morph File",
    "DSE": "DAZ Studio Encrypted Script",
    "DSF": "Delusion Digital Sound File",
    "DSG": "Stitch Era Design File",
    "DSGM": "DS Game Maker Project",
    "DSI": "DAZ Studio Layered Image Set",
    "DSK": "Simple IDs Database",
    "DSKIN": "DockX Skin",
    "DSM": "Digital Sound Module",
    "DSN": "Database Source Name File",
    "DSO": "DAZ Studio Object File",
    "DSP": "Visual C++ 6 Project",
    "DSS": "Digital Speech Standard File",
    "DST": "AutoCAD Sheet Set File",
    "DSTUDIO": "DownloadStudio Incomplete Download",
    "DSV": "DAZ Studio UV Mapping File",
    "DSW": "Visual C++ 6 Workspace File",
    "DSX": "DAZ Studio XML File",
    "DSY": "Directory Synchronizer Project File",
    "DSZ": "Orchida (OES) Embroidery File",
    "DS_STORE": "Mac OS X Folder Settings File",
    "DT0": "DTED Level 0 File",
    "DT1": "DTED Level 1 File",
    "DT2": "Windows Live Messenger Emoticon Image File",
    "DTAPART": "DownThemAll! Partially Downloaded File",
    "DTD": "Document Type Definition File",
    "DTF": "Domino Temporary File",
    "DTHUMB": "Android Data Thumbnail",
    "DTL": "Now Contact Detail Template",
    "DTM": "DigiTrakker Module",
    "DTP": "Publish-iT Document",
    "DTS": "DTS Encoded Audio File",
    "DTSCONFIG": "SSIS Package Configuration File",
    "DTSHD": "DTS-HD Master Audio File",
    "DTSX": "DTS Settings File",
    "DTW": "Desktop Wallpaper",
    "DTX": "Documented LaTeX File",
    "DUC": "Action Replay Max DS Save File",
    "DUCK": "Cyberduck Bookmark",
    "DUF": "DAZ User File",
    "DUN": "Dungeon Defenders Saved Game File",
    "DV": "Digital Video File",
    "DV-AVI": "Microsoft DV-AVI Video File",
    "DV2": "Divinity 2 Data File",
    "DV4": "Bosch Security Systems CCTV Video File",
    "DVC": "IDRISI Vector Definition File",
    "DVD": "DOS Device Driver",
    "DVDMEDIA": "RipIt DVD Package",
    "DVDPROJ": "iDVD Project File",
    "DVDR": "DVD/CD-R Master Image",
    "DVF": "Sony Digital Voice File",
    "DVG": "Graphic Works Vector Graphic",
    "DVI": "Device Independent Format File",
    "DVL": "Dalim Virtual Library File",
    "DVO": "Cook'n Cookbook File",
    "DVR": "Microsoft Recorded TV Show",
    "DVR-MS": "Microsoft Digital Video Recording",
    "DVTCOLORTHEME": "Xcode Color Theme File",
    "DVTPLUGIN": "Xcode DVT Plug-in",
    "DVX": "DivX Video File",
    "DWC": "Emulex DWC Firmware Update File",
    "DWD": "DavkaWriter File",
    "DWDOC": "DrawWell Document",
    "DWF": "Design Web Format File",
    "DWFX": "Design Web Format XPS File",
    "DWG": "AutoCAD Drawing Database File",
    "DWI": "Dance With Intensity Song File",
    "DWL": "TurboCAD Drawing Lock File",
    "DWLIBRARY": "Paperless Document Library",
    "DWN": "Firmware Update File",
    "DWS": "AutoCAD Drawing Standards File",
    "DWT": "AutoCAD Drawing Template",
    "DX": "DEC WPS Plus File",
    "DXB": "Duxbury Braille File",
    "DXE": "AutoCAD Data Extraction Template",
    "DXF": "Drawing Exchange Format File",
    "DXL": "Domino XML Language File",
    "DXLS": "DashXL Skin Set File",
    "DXP": "Duxbury Print File",
    "DXR": "Protected Macromedia Director Movie",
    "DXX": "AutoCAD Drawing Interchange Attribute File",
    "DYC": "Xerox Printer Driver Configuration File",
    "DZ": "Dzip File",
    "DZM": "DirectorZone Menu Template",
    "DZP": "DirectorZone Particle Effect File",
    "DZT": "DirectorZone Title File",
    "E00": "ArcInfo Coverage Export File",
    "E01": "EnCase Image File",
    "E2GM": "Pangea Enigmo 2 Custom Game File",
    "E4A": "Encrypt4all Archive",
    "E57": "LIDAR Point Cloud Data File",
    "EA": "Kindle End Actions File",
    "EAL": "Kindle End Actions File",
    "EAR": "Java Enterprise Archive File",
    "EASM": "eDrawings Assembly File",
    "EAZ": "ArcGIS Explorer Add-in File",
    "EBD": "Windows EBD System File",
    "EBK": "eBook Pro eBook File",
    "EBM": "EXTRA! Basic Macro",
    "EBN": "Philips Firmware Update File",
    "EBS": "E-Run 1.x Script",
    "EBS2": "E-Run 2.0 Script File ",
    "EBUILD": "Portage eBuild Script",
    "ECD": "Encrypted Cryptee Document",
    "ECE": "Escenic Dynamic Web Page",
    "ECF": "SageCRM Component File",
    "ECM": "ECM Disc Image",
    "ECO": "ECCO Database File",
    "ECS": "Sony Ericsson Phone Backup File",
    "ECSBX": "Error-Correcting SeqBox Container File",
    "ECW": "Enhanced Compression Wavelet Image",
    "ECX": "ECCO Corrupted Database File",
    "EDA": "Ensoniq ASR Disk Image",
    "EDB": "Exchange Information Store Database",
    "EDC": "Kryptel Lite Encrypted File",
    "EDDX": "Edraw XML FIle",
    "EDE": "Ensoniq EPS Disk Image",
    "EDF": "Edificius Project",
    "EDGE": "Adobe Edge Project File",
    "EDI": "Electronic Data Interchange File",
    "EDJ": "Enlightenment Theme File",
    "EDK": "Ensoniq KT Disk Image",
    "EDL": "Edit Decision List File",
    "EDML": "Adobe Extension Data Markup Language Document",
    "EDMX": "ADO.NET Entity Data Model Designer File",
    "EDN": "Adobe eBook Activation File",
    "EDOC": "Electronically Certified Document",
    "EDQ": "Ensoniq SQ1/SQ2/KS32 Disk Image",
    "EDRW": "SolidWorks eDrawings File",
    "EDRWX": "XPS Drawing Document",
    "EDS": "Ensoniq SQ-80 Disk Image",
    "EDV": "Ensoniq VFX-SD Disk Image",
    "EDX": "Edraw XML FIle",
    "EDXZ": "Edraw Compressed XML FIle",
    "EDZ": "EPLAN Electric P8 Data Archive Zipped File",
    "EF2": "Internet Download Manager Export File",
    "EFA": "Ensoniq ASR File",
    "EFI": "Extensible Firmware Interface File",
    "EFIRES": "EFI Image File",
    "EFK": "Ensoniq KT File",
    "EFL": "Encryptafile Encrypted File",
    "EFQ": "Ensoniq SQ1/SQ2/KS-32 File",
    "EFR": "Encryptafile Private Key File",
    "EFS": "Ensoniq SQ-80 File",
    "EFTX": "Office 2007 Theme Effect File",
    "EFU": "Encryptafile Public Key File",
    "EFV": "Ensoniq VFX-SD File",
    "EFW": "Renamed Zip or Executable File",
    "EFX": "eFax Document",
    "EGC": "EximiousSoft GIF Creator Document",
    "EGG": "Panda3D Model File",
    "EGM": "Enigmo Custom Game File",
    "EGP": "Easy Grade Pro Gradebook File",
    "EHAM": "ExtraHAM Executable File",
    "EHI": "HTTP Injector Config File",
    "EIO": "Yozo Office File",
    "EIP": "Enhanced Image Package File",
    "EIT": "Yozo Office Template File",
    "EL4": "Easy-PhotoPrint EX Calendar File",
    "ELD": "Eulumdat Formatted Luminaire Data File",
    "ELF": "Nintendo Wii Game File",
    "ELM": "Office Theme File",
    "EMB": "Wilcom Embroidery Design File",
    "EMBR": "Spatial Geodatabase File",
    "EMC": "Striata Reader Encrypted Document",
    "EMD": "ABT Extended Module",
    "EMERALD": "Emerald Theme",
    "EMF": "Jasspa MicroEmacs Macro File",
    "EML": "E-Mail Message",
    "EMLX": "Apple Mail Message",
    "EMLXPART": "Mail Message Attachment",
    "EMM": "MindMaple Map",
    "EMP": "eMusic Music Download File",
    "EMULECOLLECTION": "eMule Data File",
    "EMX": "eMusic Download File",
    "EMZ": "Windows Compressed Enhanced Metafile",
    "ENC": "Copysafe Protected PDF File",
    "ENEX": "Evernote Archive",
    "ENF": "EndNote Filter File",
    "ENG": "Chess Engine",
    "ENL": "EndNote Library",
    "ENS": "EndNote Style File",
    "ENT": "External Entity",
    "ENTITLEMENTS": "Mac App Sandboxing Entitlements File",
    "ENV": "Now Contact Envelope Template",
    "ENX": "Max PC Safe Encrypted File",
    "ENZ": "EndNote Connection File",
    "EOT": "Embedded OpenType Font",
    "EP": "Pencil Document",
    "EPF": "EAGLE Project",
    "EPI": "EclipsePackager2000 Compressed File",
    "EPIBRW": "Web File Location",
    "EPIM": "EssentialPIM Database File",
    "EPK": "LG Firmware Package",
    "EPK2": "E-Prime 2.0 Package File",
    "EPP": "EditPad Pro Project",
    "EPRT": "eDrawings File",
    "EPS": "Encapsulated PostScript File",
    "EPSF": "Encapsulated PostScript Format File",
    "EPUB": "Open eBook File",
    "EPW": "EnergyPlus Weather Data File",
    "EQF": "Winamp Equalizer Preset File",
    "EQL": "MathType Settings",
    "EQN": "GAL Equation File",
    "EQP": "MathType Preferences",
    "ER1": "ERWin Entity Relationship Diagram",
    "ERB": "Evil Genius Resource File",
    "ERF": "Epson RAW File",
    "ERL": "Erlang Source Code File",
    "ERP": "Alter Ego Game Archive",
    "ERR": "Error Log File",
    "ERS": "ER Mapper Data File",
    "ES": "SageCRM Script File",
    "ESC": "EasySignCut Pro Project",
    "ESCAPE": "Prison Architect Escape Mode Save File",
    "ESCOPY": "ES File Explorer File Manager Temporary File",
    "ESD": "Windows Electronic Software Download File",
    "ESF": "Password Manager Container File",
    "ESG": "Enigmo Saved Game File",
    "ESH": "Extended Shell Batch File",
    "ESLOCK": "ES File Explorer File Manager Encrypted File",
    "ESM": "Elder Scrolls Master File",
    "ESP": "Elder Scrolls Plugin File",
    "ESPROJ": "Espresso Project File",
    "ESPS": "ESPS Sampled Data File",
    "ESS": "EasySpreadsheet Spreadsheet",
    "EST": "Streets & Trips Map File",
    "ESX": "Xactimate Insurance Claims Estimate",
    "ETA": "Google Earth Placemark File",
    "ETD": "Adobe Reader EBX Transfer Data File",
    "ETF": "ENIGMA Transportable File",
    "ETL": "Microsoft Event Trace Log File",
    "ETX": "Structure Enhanced Text (Setext) File",
    "EUC": "Extended Unix Code File",
    "EUF": "Private Character Editor File",
    "EUI": "Ensoniq EPS Compacted Disk Image",
    "EUM": "Enterprise User Monitor Configuration File",
    "EV": "Echoview File",
    "EVENT": "Corel Cataloged Folder File",
    "EVO": "HD DVD Video File",
    "EVT": "Windows Event Viewer Log File",
    "EVTX": "Windows 7 Event Log File",
    "EWB": "Electronics Workbench Circuit Design File",
    "EWD": "EasyWOOD Design File",
    "EWP": "Ewisoft Website Project File",
    "EWPRJ": "Ultiboard Layout Project",
    "EX": "Euphoria Source Code",
    "EX01": "EnCase Evidence Image File",
    "EX4": "MetaTrader 4 Program File",
    "EX5": "MetaTrader 5 Program File",
    "EXB": "Evernote Database File",
    "EXC": "eDataSecurity Management Self-extracting File",
    "EXD": "Control Information Cache File",
    "EXE": "Windows Executable File",
    "EXE1": "Renamed EXE File",
    "EXE4J": "Exe4j Configuration File",
    "EXIF": "Exchangeable Image Information File",
    "EXO": "YouTube Video Chunk File",
    "EXOPC": "ExoPC Application",
    "EXP": "Export File",
    "EXPORTEDUI": "Microsoft Office Exported UI Customization File",
    "EXPRESSIONMAP": "Cubase Expression Map File",
    "EXR": "OpenEXR Image",
    "EXS": "EXS Instrument",
    "EXT": "Norton Commander Extension",
    "EXTR": "COW App Extractor File",
    "EXV": "Adobe Extension Script",
    "EXW": "Euphoria Source code File",
    "EXX": "IBM Linkway MsgPut File",
    "EX_": "Compressed Executable File",
    "EYB": "Microsoft Encarta Yearbook Update File",
    "EYE": "Eyemail Video Recording File",
    "EYETV": "EyeTV Recording File",
    "EZC": "AutoCAD Ecscad Components Backup File",
    "EZDRAW": "EazyDraw Graphic",
    "EZLOG": "Skype Extras Manager Log File",
    "EZP": "AutoCAD Ecscad Project Backup File",
    "EZS": "EZ-R Stats Batch Script",
    "EZT": "EZTitles Subtitles File",
    "EZW": "easyOFFER Real Estate Form File",
    "E_E": "Renamed EXE File",
    "F": "Freeze Compressed File",
    "F2R": "Farandole Linear Module File",
    "F32": "Raw 32-Bit Audio File",
    "F3D": "Fusion 3D Design",
    "F3F": "Crazy Machines Font File",
    "F3R": "Farandoyle Blocked Module File",
    "F3Z": "Fusion 360 Shared Project Archive",
    "F4A": "Adobe Flash Protected Audio File",
    "F4F": "Flash Video Fragment",
    "F4M": "Adobe Flash Media Manifest File",
    "F4P": "Adobe Flash Protected Media File",
    "F4V": "Flash MP4 Video File",
    "F64": "Raw 64-Bit Audio File",
    "F90": "Fortran 90 Source Code File",
    "FAC": "FACE Image File",
    "FACE": "FACE Graphic File",
    "FACEFX": "FaceFX Actor File",
    "FACEFX_INGAME": "FaceFX In-Game Actor File",
    "FADEIN": "Fade In Document",
    "FADEIN.TEMPLATE": "Fade In Template",
    "FAL": "Bitmap Graphic Header Information",
    "FAN": "Form\u2022Z Animation File",
    "FAQ": "Frequently Asked Questions Document",
    "FAR": "The Sims Archive File",
    "FAS": "Compiled Fast-Load AutoLISP File",
    "FAT": "Zinf Theme File",
    "FAVORITEMETADATA": "Transmit Favorites Data File",
    "FAX": "Fax Document",
    "FB!": "FlashGet Incomplete Download File",
    "FB2": "FictionBook 2.0 File",
    "FB2K-COMPONENT": "Foobar2000 Component Install File",
    "FBC": "Family Tree Maker for DOS Backup File",
    "FBF": "Free Backup Fix Backup File",
    "FBK": "Microsoft Dynamics NAV Backup File",
    "FBL": "CADfix Command Level Log File",
    "FBM": "Marine Vessel Model File",
    "FBP": "wxFormBuilder Project",
    "FBR": "FlashBack Screen Recording",
    "FBT": "ABBYY FineReader Document Options File",
    "FBU": "FEBE Firefox Backup File",
    "FBW": "HP Recovery Manager Backup File",
    "FBX": "Autodesk FBX Interchange File",
    "FBZ": "FlashBack Screen Recorder Movie",
    "FBZ7": "Compressed FinalBuilder 7 Project",
    "FC": "FirstClass Settings File",
    "FC2": "Poser Face Pose File",
    "FCARCH": "Final Cut Pro Archive",
    "FCC": "Forms Credential Collector File",
    "FCD": "First Choice Database",
    "FCDT": "FormsCentral Design Template",
    "FCF": "Final Draft Converter File",
    "FCGI": "FastCGI File",
    "FCM": "fCraft World File",
    "FCP": "Final Cut Project",
    "FCPEVENT": "Final Cut Pro Event File",
    "FCPROJECT": "Final Cut Pro X Project File",
    "FCS": "Flow Cytometry Standard File",
    "FCSTD": "FreeCAD Document",
    "FCSTD1": "FreeCAD Backup Document",
    "FCW": "FastCAD Windows Drawing",
    "FCZ": "Compressed Poser Face Pose File",
    "FD": "LaTeX Font Definition File",
    "FD2": "PictureMate Borders File",
    "FDB": "Portfolio Catalog",
    "FDD": "FormDocs Document",
    "FDF": "Acrobat Forms Data Format",
    "FDI": "Amiga Disk Image",
    "FDP": "FMOD Project File",
    "FDR": "Final Draft Document",
    "FDS": "Final Draft Secure Copy",
    "FDT": "Final Draft 5-7 Template",
    "FDX": "Final Draft Document",
    "FDXT": "Final Draft 8 Template",
    "FEA": "AFDKO Feature Definitions File",
    "FEEDBACK": "Expression SketchFlow Feedback File",
    "FETCHMIRROR": "Fetch Mirror Document",
    "FEV": "FMOD Audio Events File",
    "FEY": "FCS Express Layout File",
    "FF": "Call of Duty 4 Fast File",
    "FFA": "Find Fast Status File",
    "FFD": "ffDiaporama Project File",
    "FFF": "Hasselblad RAW Image",
    "FFIL": "Mac Font Suitcase",
    "FFL": "Find Fast Document List",
    "FFM": "FFmpeg Stream File",
    "FFO": "Find Fast Document Properties Cache",
    "FFS": "FME Desktop Feature Store File",
    "FFT": "Final Form Text File",
    "FFWP": "FormsForWeb Packet",
    "FFX": "Microsoft Find Fast Index",
    "FG": "FaceGen Project File",
    "FGC": "Greeting Card Factory Card File",
    "FGD": "Forge Game Data File",
    "FGL": "Fifth Generation Language Source File",
    "FGS": "Fig Figure Settings File",
    "FH": "Symantec Backup Exec File",
    "FH10": "FreeHand 10 Drawing File",
    "FH11": "FreeHand 11 Drawing File",
    "FH3": "FreeHand 3 Drawing File",
    "FH4": "FreeHand 4 Drawing File",
    "FH5": "FreeHand 5 Drawing File",
    "FH6": "FreeHand 6 Drawing File",
    "FH7": "FreeHand 7 Drawing File",
    "FH8": "FreeHand 8 Drawing File",
    "FH9": "FreeHand 9 Drawing File",
    "FHC": "FHC Data File",
    "FHD": "FreeHand Drawing File",
    "FHF": "Free Hide Folder Backup File",
    "FIC": "WinDev Hyper File Database",
    "FID": "Microsoft Catalog Indexing Service File",
    "FIF": "Fractal Image File",
    "FIG": "3ds Max Figure File",
    "FIL": "Files List Object File",
    "FILE": "Generic Windows File",
    "FILEBOLT": "Filebolt Encrypted File",
    "FILM": "Filmkey Player Media File",
    "FIRM": "Boot9Strap 3DS Firmware File",
    "FIT": "Garmin Activity File",
    "FITS": "Flexible Image Transport System File",
    "FKB": "Flipkart eBook File",
    "FKY": "FoxPro Macro",
    "FL": "Freelancer Saved Game File",
    "FL1": "Lenovo BIOS Update File",
    "FLA": "Adobe Animate Animation",
    "FLAC": "Free Lossless Audio Codec File",
    "FLB": "FileMaker Pro Label File",
    "FLC": "FLIC Animation",
    "FLEXOLIBRARY": "Final Cut Pro Library Database",
    "FLF": "Microsoft Dynamics NAV License File",
    "FLG": "Puppy Linux Partition Flag File",
    "FLH": "FLIC Animation File",
    "FLI": "FLIC Animation",
    "FLIC": "FLIC Animation",
    "FLIF": "Free Lossless Image Format File",
    "FLKA": "Folder Lock Portable Locker File",
    "FLKB": "Folder Lock Basic Locker File",
    "FLM": "FL Studio Mobile Song File",
    "FLO": "iGrafx FlowCharter File",
    "FLOWCHART": "PureFlow Flowchart",
    "FLP": "ActivPrimary Flipchart File",
    "FLR": "Flare Decompiled ActionScript File",
    "FLS": "ArcView GIS Windows Help Supporting File",
    "FLST": "Adobe InDesign Flattener Presets File",
    "FLT": "OpenFlight Scene Description File",
    "FLV": "Flash Video File",
    "FLW": "Kivio Flow Chart",
    "FLX": "FLIC Animation",
    "FM": "FrameMaker Document",
    "FM5": "FileMaker 5 Database",
    "FMAT": "FMAT Runfile",
    "FMC": "FormConnect Form File",
    "FME": "FME Mapping File",
    "FMELIC": "FME License File",
    "FMI": "FME Include File",
    "FML": "WWE RAW Character File",
    "FMP": "FileMaker Pro Database",
    "FMP12": "FileMaker Pro 12 Database",
    "FMPLUGIN": "FileMaker Plug-in",
    "FMPSL": "FileMaker Pro 12 Snapshot Link",
    "FMT": "FoxPro Format File",
    "FMV": "Frame Vector Metafile",
    "FMW": "FME Workbench File",
    "FMX": "FileMaker Plug-in",
    "FMZ": "Form\u2022Z Project File",
    "FNC": "Vue Functions File",
    "FND": "Windows Saved Search",
    "FNLF": "Scarlett Plug-in Suite License File",
    "FNT": "Windows Font File",
    "FOB": "Dynamics NAV Object Container File",
    "FODS": "OpenDocument Flat XML Spreadsheet",
    "FODT": "OpenDocument Flat XML Document",
    "FOL": "PFS First Choice Database File",
    "FOLIO": "Adobe Folio File",
    "FOMOD": "Fallout Mod Archive",
    "FON": "Generic Font File",
    "FOP": "InfoZoom Protected Data File",
    "FOR": "Fortran 77 Source File",
    "FORGE": "Assassin's Creed Game Data File",
    "FORM": "NetBeans Java GUI Designer Form",
    "FORTH": "Forth Language File",
    "FOS": "Fallout 3 Saved Game",
    "FOT": "Font Resource File",
    "FOTA": "Firmware Over-the-Air File",
    "FOUNTAIN": "Fountain Script File",
    "FOX": "InfoZoom Data File",
    "FP": "Fragment Program File",
    "FP3": "FloorPlan 3D Design File",
    "FP4": "FileMaker Pro 4 Database",
    "FP5": "FileMaker Pro 5 Database",
    "FP7": "FileMaker Pro 7+ Database",
    "FP8": "FP8 (= Fast PAQ8) Compressed File",
    "FPA": "Finale Performance Assessment File",
    "FPBF": "Mac OS X Burn Folder",
    "FPD": "Front Panel Designer Project",
    "FPDX": "Utilius Fairplay Project",
    "FPE": "FPS Creator Entity File",
    "FPENC": "FileProtect Encrypted File",
    "FPF": "IKEA Home Planner File",
    "FPFV": "File Protected From Virus",
    "FPG": "Fenix Graphics Collection File",
    "FPI": "FPS Creator Intelligence Script",
    "FPJ": "CryENGINE Facial Editor Project File",
    "FPM": "FPS Creator Map File",
    "FPOP": "Spider-Man: Shattered Dimensions Saved Game",
    "FPOS": "Photo Pos Pro Image",
    "FPP": "Front Panel Project",
    "FPPX": "Microsoft Fresh Paint Painting File",
    "FPS": "FPS Creator Segment File",
    "FPSX": "Nokia Firmware Format File",
    "FPT": "FoxPro Table Memo",
    "FPX": "FlashPix Bitmap Image File",
    "FR3": "FastReport Form File",
    "FRAMES": "xScope Frames File",
    "FRAMEWORK": "Mac OS X Application Framework",
    "FRDOC": "FineReader Document",
    "FREEWAY": "Freeway Document",
    "FRF": "Free Report Form File",
    "FRG": "Sound Forge Pro Project File",
    "FRM": "Painter Frame Stack File",
    "FRO": "dBASE IV Compiled Report",
    "FRS": "Flash Renamer Script",
    "FRT": "FoxPro Report Memo",
    "FRX": "Visual Basic Binary Form File",
    "FRY": "fryrender Scene File",
    "FRZ": "Snes9x Saved State",
    "FS": "FlexiSIGN Document",
    "FS2": "FreeSpace 2 Saved Mission File",
    "FSB": "FMOD Sample Bank File",
    "FSC": "Practical Scriptwriter File",
    "FSD": "Flowsheet Document",
    "FSH": "Fragment Shader File",
    "FSI": "Visual F# Signature File",
    "FSM": "Farandole Composer WaveSample File",
    "FSPROJ": "Visual F# Project File",
    "FSQ": "CryENGINE Facial Editor Sequence File",
    "FSSAVE": "Flight Simulator Save File",
    "FSSCRIPT": "Visual F# Script",
    "FST": "Crazy Machines 2 Object File",
    "FSX": "Visual F# Script File",
    "FT": "Edgecam Feature Template",
    "FT10": "FreeHand 10 Drawing Template",
    "FT11": "FreeHand 11 Drawing Template",
    "FT7": "FreeHand 7 Drawing Template",
    "FT8": "FreeHand 8 Template",
    "FT9": "FreeHand 9 Drawing Template",
    "FTC": "FluxTime Clip File",
    "FTF": "FlashTool Firmware File",
    "FTG": "Full Text Group",
    "FTH": "FileMaker Theme File",
    "FTIL": "e-Hastakshar Contract Note",
    "FTL": "FreeMarker Template File",
    "FTM": "FamiTracker Module",
    "FTMB": "Family Tree Maker Backup File",
    "FTMX": "Finale Template File",
    "FTN": "Flowton Diagram File",
    "FTP": "FlashFXP XML File",
    "FTPLOC": "FTP Location",
    "FTPQUOTA": "Ftpquota File",
    "FTS": "Full Text Search",
    "FTW": "Family Tree Maker File",
    "FUK": "Postal 2 Map File",
    "FUL": "Microsoft Backup File List",
    "FUN": "Cubify Invention File",
    "FUSE": "Adobe Fuse 3D Model",
    "FVP": "File Viewer Plus Batch Presets File",
    "FVT": "FAST Search & Transfer Video File",
    "FW": "Firmware Update File",
    "FWACTION": "Freeway Action File",
    "FWACTIONB": "Freeway Action Bundle File",
    "FWBACKUP": "Freeway Backup",
    "FWDN": "fWriter Document",
    "FWP": "Microsoft Expression Web Package",
    "FWT": "FacetWin Configuration File",
    "FWTB": "Freeway Template Bundle",
    "FWTEMPLATE": "Freeway Template",
    "FWTEMPLATEB": "Freeway Template Bundle",
    "FX": "Direct3D Effects File",
    "FXA": "OC3 Entertainment FaceFX Actor File",
    "FXC": "FilePackager Configuration",
    "FXCPROJ": "FX Composer Project File",
    "FXG": "Flash XML Graphics File",
    "FXL": "CryENGINE Facial Expression Library",
    "FXM": "messiahStudio Motion File",
    "FXML": "FXML Source Code File",
    "FXP": "Adobe Flex Project File",
    "FXPL": "Adobe Flash FXP Library",
    "FXS": "messiahStudio Scene File",
    "FXT": "FaceFX Actor Template File",
    "FZ": "Fritzing Project File",
    "FZA": "Form\u2022Z Autosave File",
    "FZB": "Fritzing Bin File",
    "FZBZ": "Fritzing Bundled Bin File",
    "FZF": "Casio FZ-1 Full Dump",
    "FZIP": "Foxit Reader Add-on",
    "FZM": "Fritzing Module File",
    "FZP": "Fritzing Part File",
    "FZPZ": "Fritzing Bundled Part File",
    "FZV": "Casio FZ-1 Voice Dump",
    "FZZ": "Fritzing Shareable Project File",
    "G": "BRL-CAD Geometry File",
    "G2M": "GoToMeeting Recording File",
    "G3": "CCITT Group 3 Fax Image",
    "G3A": "Casio Prizm Add-in File",
    "G3D": "GOM 3D File",
    "G3X": "RealFlight Content File",
    "G41": "Commodore 1541 Disk Image",
    "G64": "Genetec Video File",
    "G64X": "Genetec Video File",
    "G721": "G.721 Audio File",
    "G723": "G.723 Audio File",
    "G726": "G.726 Audio File",
    "GADGET": "Windows Gadget",
    "GALAXY": "Blizzard Galaxy File",
    "GAM": "Saved Game File",
    "GAME": "GameSalad Exported Game File",
    "GAN": "GanttProject Project File",
    "GAU": "Flight Simulator Gauge File",
    "GB": "Game Boy ROM File",
    "GB1": "Game Maker Backup File",
    "GB2": "Game Maker Backup File",
    "GBA": "Game Boy Advance ROM",
    "GBASKIN": "Game Boy Advance Controller Skin File",
    "GBC": "Game Boy Color ROM",
    "GBCSKIN": "Game Boy Color Controller Skin File",
    "GBI": "gBurner Project File",
    "GBP": "Genie Timeline Backup Index File",
    "GBPROJ": "GarageBand Project",
    "GBR": "Gerber File",
    "GBS": "GameBoy Sound File",
    "GBX": "Nadeo Game File",
    "GC": "GraphClick File",
    "GCA": "GCA File Archive",
    "GCD": "Generic CADD Drawing File",
    "GCDP": "Greeting Card Studio Design Project",
    "GCF": "Game Cache File",
    "GCH": "Precompiled Header File",
    "GCODE": "G-Code 3D Printer File",
    "GCS": "Cineform Studio Video Project",
    "GCSX": "Microsoft Office SmartArt Color File",
    "GCW": "Microsoft Mathematics Worksheet",
    "GDB": "GPS Database File",
    "GDC": "Godot Engine Compiled Script",
    "GDCB": "GandCrab Ransomware Encrypted File",
    "GDE": "The Guide Document",
    "GDG": "GDevelop Project File",
    "GDI": "Dreamcast Gigabyte Disc Image",
    "GDOC": "Google Drive Document Link File",
    "GDOCX": "Google Drive Document",
    "GDR": "Symbian OS Font File",
    "GDRAW": "Google Drive Drawing",
    "GDRIVE": "Gizmo Virtual Drive File",
    "GDS": "Graphic Data System File",
    "GDT": "gretl Datafile",
    "GED": "GEDCOM Genealogy Data File",
    "GEDCOM": "GEDCOM Genealogy File",
    "GEM": "GEM Metafile",
    "GEMSPEC": "Gem Specification File",
    "GEN": "Sega Genesis ROM",
    "GEO": "VRML Geography File",
    "GEOJSON": "GeoJSON File",
    "GF": "METAFONT Bitmap File",
    "GFAR": "Greenfoot Archive",
    "GFB": "GIFBlast Compressed Image File",
    "GFE": "Glarysoft Encrypted File",
    "GFIE": "Greenfish Icon Editor Pro Graphic",
    "GFP": "GreenForce-Player Protected Media File",
    "GFW": "GIF World File",
    "GFX": "GFx Scaleform File",
    "GG": "Google Desktop Gadget File",
    "GGB": "GeoGebra Document",
    "GGR": "GIMP Gradient File",
    "GHO": "Norton Ghost Backup File",
    "GHS": "Norton Ghost Image Segment",
    "GI": "Global Image",
    "GID": "Windows Help Global Index File",
    "GIF": "Graphical Interchange Format File",
    "GIFV": "GIF Video File",
    "GIG": "Tascam GigaSampler File",
    "GIH": "GIMP Image Hose File",
    "GIM": "PlayStation Portable Image File",
    "GIN": "GEMS Engine Control Unit File",
    "GINSPECT_PRJ": "GOM Inspect Project File",
    "GITATTRIBUTES": "Git Attributes File",
    "GITIGNORE": "Git Ignore File",
    "GKH": "Ensoniq EPS Family Disk Image",
    "GKS": "Graphics Kernel System File",
    "GL": "GRASP Animation",
    "GLB": "Binary GL Transmission Format File",
    "GLD": "MPLAB C Compiler Linker Script File",
    "GLF": "Space Engine Shader File",
    "GLIF": "Glyph Interchange Format File",
    "GLINK": "Google Drive External File Shortcut",
    "GLM": "Ghoul 2 Model File",
    "GLOX": "Microsoft Office SmartArt Graphics Layout File",
    "GLS": "Sothink SWF Easy Shape File",
    "GLTF": "GL Transmission Format File",
    "GM6": "GameMaker 6 Project File",
    "GM81": "Game Maker 8.1 Project File",
    "GMA": "Garry's Mod Addon File",
    "GMAP": "Garmin Map File",
    "GMBCK": "Game Maker Background Image File",
    "GMD": "GroupMail Message",
    "GMF": "Leadwerks Game Model File",
    "GMK": "Game Maker Project File",
    "GML": "Geography Markup Language File",
    "GMMOD": "Game Maker 3D Model File",
    "GMMP": "WCS Gamut Map Model Profile",
    "GMO": "GNU Machine Object File",
    "GMRES": "GameMaker Resource File",
    "GMS": "Garry's Mod Save File",
    "GMSPR": "Game Maker Sprite File",
    "GMT": "rFactor Model File",
    "GMW": "Global Mapper Workspace File",
    "GMX": "GameMaker File",
    "GMZ": "Compressed GameMaker File",
    "GNE": "Flickr Web Page",
    "GNM": "Gnumeric Spreadsheet",
    "GNO": "GenoPro Genealogy Tree File",
    "GNUMERIC": "Gnumeric Spreadsheet",
    "GOD": "God Configuration File",
    "GODOT": "Godot Engine Project",
    "GOFIN": "DRUKI Gofin Form File",
    "GOM": "GOM Media File",
    "GORM": "Gorm Interface Resource File",
    "GP4": "CCITT Group 4 Fax File",
    "GP5": "Guitar Pro 5 Tablature File",
    "GPBANK": "Guitar Pro Sound Bank File",
    "GPD": "Generic Printer Description File",
    "GPE": "GP2X Video Game",
    "GPF": "GRAVITY Ragnarok Online Patch File",
    "GPG": "GNU Privacy Guard Public Keyring",
    "GPI": "Garmin Point of Interest File",
    "GPK": "WaveLab Audio Peak File",
    "GPN": "GlidePlan Map Document",
    "GPRX": "Geoxa Project File",
    "GPS": "Survey Pro Coordinate File",
    "GPU": "GP2X Utility Program",
    "GPX": "GPS Exchange File",
    "GQSX": "Microsoft Office SmartArt Styles File",
    "GR2": "Granny 3D File",
    "GRADE": "GradeStat Document",
    "GRAFFLE": "OmniGraffle Drawing",
    "GRASP": "GRASP Animation",
    "GRB": "GRIB Meteorological Data File",
    "GRD": "Photoshop Gradient File",
    "GRDB": "Gramps Database File",
    "GREENFOOT": "Greenfoot Project Archive",
    "GRF": "DPlot Graph File",
    "GRK": "Gradekeeper Class Gradebook File",
    "GRL": "Windows Update Status File",
    "GRN": "Granny 3D File",
    "GRO": "Graphic Object Bitmap",
    "GROB": "Graphic Object Bitmap File",
    "GROOVE": "ACID Groove File",
    "GROOVY": "Groovy Source Code File",
    "GROUP": "Windows Contacts Group File",
    "GROUPPROJ": "Delphi Project Group File",
    "GROWLREGDICT": "Growl Temp File",
    "GROWLTICKET": "Growl Notification File",
    "GRP": "StarCraft Graphics Group File",
    "GRR": "Gradekeeper Class Roster File",
    "GRV": "Office Groove File",
    "GRY": "Grayscale Image",
    "GS": "GemStone Document",
    "GS-BCK": "Genius Scan Backup File",
    "GS3": "GameStarter File",
    "GSB": "Golden Software Boundary File",
    "GSC": "Call of Duty Game Script",
    "GSD": "General Station Description File",
    "GSF": "Game Boy Advance Sound File",
    "GSFLIB": "Game Boy Advance Song Library",
    "GSHEET": "Google Drive Spreadsheet Link File",
    "GSI": "Golden Software Interchange File",
    "GSLIDES": "Google Drive Presentation Link File",
    "GSM": "Global System for Mobile Audio File",
    "GSP": "Silhouette Studio SD Card Document",
    "GSPROJ": "GameSalad Windows Project File",
    "GSR": "Golden Software Reference File",
    "GSR2": "Golden Software Reference File",
    "GST": "MapInfo Geoset File",
    "GSTENCIL": "OmniGraffle Stencil",
    "GSZIP": "GameSalad Marketplace Asset File",
    "GTA": "Microsoft Groove Tool Archive",
    "GTEMPLATE": "OmniGraffle Template",
    "GTHR": "Gather Log File",
    "GTKRC": "GTK+ Theme File",
    "GTM": "GPS TrackMaker Data File",
    "GTP": "Guitar Pro File",
    "GTS": "CaptiveWorks PVR Video File",
    "GV": "Graphviz DOT File",
    "GVDESIGN": "Gravit Designer File",
    "GVI": "Google Video File",
    "GVIMRC": "GVim Runtime Configuration File",
    "GVP": "Google Video Pointer",
    "GVSP": "Geocortex Viewer for Silverlight Project",
    "GWB": "Interwrite Presentation File",
    "GWI": "GroupWise Database Shortcut File",
    "GWK": "GraphiCode PCB Job File",
    "GWS": "Geosoft Workspace File",
    "GXC": "General CADD Pro Component",
    "GXD": "General CADD Pro Drawing",
    "GXF": "General eXchange Format File",
    "GXH": "General CADD Pro Hatch Pattern File",
    "GXK": "Galaxkey Secured File",
    "GXM": "General CADD Pro Macro File",
    "GXT": "Grand Theft Auto Text File",
    "GZ": "Gnu Zipped Archive",
    "GZ2": "Misnamed BZ2 File",
    "GZA": "IZArc BGA Archive File",
    "GZI": "Unix Gzip File",
    "GZIP": "Gnu Zipped File",
    "GZQUAR": "Bitdefender Antivirus Quarantine File",
    "H": "C/C++/Objective-C Header File",
    "H0": "Movie Edit Pro Waveform Information File",
    "H12": "At Home Canada 2012 Tax Return",
    "H13": "H&R Block Canada 2013 Tax Return",
    "H17": "H&R Block Canada 2017 Tax Return",
    "H1S": "Windows Assistance Platform Help File",
    "H264": "H.264 Encoded Video File",
    "H3M": "Heroes 3 Map File",
    "H4B": "Line 6 POD HD400 Edit Bundle",
    "H4R": "Heroes of Might and Magic IV Data File",
    "H5B": "Line 6 POD HD500 Edit Bundle",
    "H5E": "Line 6 POD HD500 Edit Preset File",
    "H5S": "Line 6 POD HD500 Edit Setlist File",
    "H5U": "Heroes of Might and Magic V Mod File",
    "HA": "HA Compressed Archive",
    "HAL": "HansaWorld Application Language File",
    "HAM": "HAM Executable File",
    "HAML": "Haml Source Code File",
    "HAN": "Amazon Kindle eBook Data File",
    "HAR": "HTTP Archive FIle",
    "HAS": "Haskell Script",
    "HBC": "HyperBac Compressed Archive",
    "HBC2": "HyperBac Compressed File Archive",
    "HBE": "Line 6 POD HD Edit Preset File",
    "HBK": "Mathcad Handbook File",
    "HBS": "Handlebars Template",
    "HBX": "BinHex Encoded File",
    "HC": "VeraCrypt Container File",
    "HCA": "High Compression Audio File",
    "HCD": "Samsung Android Firmware File",
    "HCDT": "Thinkfree Office NEO Cell Template",
    "HCE": "HydroCAD Hydrograph Data File",
    "HCI": "HydroCAD IDF Data File",
    "HCP": "HydroCAD Project File",
    "HCR": "HydroCAD Rainfall Curve Data File",
    "HD2": "Poser Hand Pose File",
    "HD3D": "Home Design 3D Project",
    "HDA": "HotDocs Auto-Assemble File",
    "HDB": "HansaWorld Database File",
    "HDD": "Parallels Desktop Hard Disk File",
    "HDF": "Hierarchical Data Format File",
    "HDI": "Hard Disk Image",
    "HDK": "HotDocs Registration File",
    "HDM": "HDML File",
    "HDML": "Handheld Device Markup Language File",
    "HDMOV": "QuickTime HD Movie File",
    "HDMP": "Windows Heap Dump",
    "HDP": "MAGIX Hard Disk Project Audio File",
    "HDR": "High Dynamic Range Image File",
    "HDRP": "HDRtist Pro Document",
    "HDS": "Parallels Desktop Hard Disk File",
    "HDV": "High Definition Video Format",
    "HDZ": "Compressed Poser Hand Pose File",
    "HEIC": "High Efficiency Image Format",
    "HEIF": "High Efficiency Image Format",
    "HELP": "Mac OS X Help Book",
    "HEVC": "High Efficiency Video Coding File",
    "HEX": "BinHex Encoded File",
    "HF": "HF Image",
    "HFD": "HotDocs Form Document",
    "HFS": "HFS Disk Image File",
    "HFT": "HotDocs Form Template",
    "HFV": "HFS Disk Image",
    "HGL": "HP Graphics Language File",
    "HGT": "SRTM Elevation Data File",
    "HH": "C++ Header File",
    "HHC": "HTML Help Table of Contents",
    "HHK": "HTML Help Index",
    "HHT": "Help and Support Center HHT File",
    "HID": "Sony Ericsson Remote Settings File",
    "HID2": "KeepSafe File",
    "HIP": "Houdini Project File",
    "HIPNC": "Houdini Apprentice File",
    "HIS": "FindinSite Database Definition File",
    "HIT": "The Sims Sound File",
    "HIV": "Windows Registry Hive File",
    "HKI": "WinHKI Archive",
    "HKI1": "WinHKI HKI1 Archive",
    "HKI2": "WinHKI HKI2 Archive",
    "HKI3": "WinHKI HKI3 Archive",
    "HKM": "Havok Movie File",
    "HL": "HeuristicLab Storage File",
    "HLP": "Windows Help File",
    "HLSL": "High Level Shader Language File",
    "HLX": "ATI Radeon Video Driver Support File",
    "HME": "Windows Mobile Theme File",
    "HMK": "Hallmark Card Studio File",
    "HML": "HostMonitor TestList File",
    "HMS": "HostMonitor Script File",
    "HMX": "Help & Manual 4 Project",
    "HONMOD": "HON Modification Manager File",
    "HOT": "The Sims Sound File",
    "HPD": "HotDocs PDF Document",
    "HPF": "HP9100A Program File",
    "HPG": "HPGL Plot File",
    "HPGL": "HP Graphics Language Plotter File",
    "HPI": "Hemera Photo Objects Image File",
    "HPJ": "Help Project File",
    "HPK": "HPack Compressed Archive",
    "HPKG": "Haiku Package File",
    "HPL": "HP-GL Plotter File",
    "HPP": "C++ Header File",
    "HPS": "HPL Script",
    "HPT": "HotDocs PDF Template",
    "HQX": "BinHex 4.0 Encoded File",
    "HR": "TRS-80 Image",
    "HR2": "Poser Hair File",
    "HRF": "Hitachi Raster Format File",
    "HRZ": "Compressed Poser Hair File",
    "HS": "Java HelpSet File",
    "HSB": "HALion Sound Bank File",
    "HSC": "Aspen HYSYS Simulation File",
    "HSF": "HOOPS Stream Format File",
    "HSH": "Windows Catalog Search Index File",
    "HST": "History File",
    "HT": "HyperTerminal Session File",
    "HTA": "HTML Application",
    "HTACCESS": "Apache HTACCESS File",
    "HTC": "HTML Component File",
    "HTM": "Hypertext Markup Language File",
    "HTML": "Hypertext Markup Language File",
    "HTML0": "Book Designer File",
    "HTMLZ": "Zipped HTML eBook",
    "HTPASSWD": "Apache HTACCESS File",
    "HTT": "Hypertext Template File",
    "HTX": "HTML Extension File",
    "HTXT": "Hanvon eBook File",
    "HTZ4": "HyperMaker 4 Publication",
    "HTZ5": "HyperMaker 5 Publication",
    "HUH": "HydroCAD Unit Hydrograph Definitions File",
    "HUM": "OMSI Human Configuration File",
    "HUS": "Husqvarna Embroidery File",
    "HVE": "Windows Registry Hive File",
    "HVIF": "Haiku Vector Icon File",
    "HVPL": "iTunes Visual Plug-in File",
    "HWDT": "Thinkfree Office NEO Word Template",
    "HWP": "Hanword Document",
    "HXA": "Microsoft Help 2 Attribute Definition File",
    "HXC": "Microsoft Help 2 Collection Definition File",
    "HXE": "Microsoft Help 2 Sample Definition File",
    "HXK": "Microsoft Help 2 Index File",
    "HXN": "Hexagon Model File",
    "HXS": "Help 2 Compiled Help File",
    "HXX": "C++ Source Code Header File",
    "HYP": "HYPER Compressed Archive",
    "HYPE": "Hype Document",
    "HYPERESOURCES": "Hype Resources Folder",
    "HYPESYMBOL": "Hype Symbol File",
    "HYPETEMPLATE": "Hype Document Template",
    "HYV": "Team Manager Meet Event File",
    "HZ": "Chinese (Hanzi) Text",
    "I": "Visual Studio Intermediate File",
    "I00": "DVD Shrink Part 1 File",
    "I01": "DVD Shrink Part 2 File",
    "I02": "DVD Shrink Part 3 File",
    "I3D": "Houdini Image 3D File",
    "I5Z": "IUCLID 5 Import/Export File",
    "IAA": "INTUS Audio Archive",
    "IADACTION": "iAd Producer Plugin Action Template",
    "IADCLASS": "iAd Producer Plugin Class Description File",
    "IADCOMPONENT": "iAd Producer Plugin Component File",
    "IADPAGE": "iAd Producer Plugin Page Template",
    "IADPLUG": "iAd Producer Plugin",
    "IADPROJ": "iAd Producer Project",
    "IADSTYLE": "iAd Producer Plugin Style Template",
    "IAF": "Outlook Internet Account File",
    "IAM": "Inventor Assembly File",
    "IB": "InterBase Database",
    "IBA": "iBooks Author Document",
    "IBADR": "IsoBuster Address File",
    "IBB": "ImgBurn Project File",
    "IBDAT": "IsoBuster Data File",
    "IBK": "IncrediMail Account Backup File",
    "IBOOKS": "Multi-Touch iBook",
    "IBP": "IsoBuster Managed Image Information File",
    "IBPLUGIN": "Interface Builder Plug-in",
    "IBQ": "IsoBuster Managed Image File",
    "IBT": "Texture and Model File",
    "IC1": "Low Resolution Imagic Graphics File",
    "IC2": "Medium Resolution Imagic Graphics File",
    "IC3": "High Resolution Imagic Graphics File",
    "IC3D": "IC3D Scene File",
    "ICA": "Image Object Content Architecture File",
    "ICAL": "iCalendar File",
    "ICALENDAR": "iCalendar File",
    "ICAP": "InCopy Package File",
    "ICB": "Targa ICB Bitmap Image",
    "ICBU": "Calendar Backup File",
    "ICC": "ICC Profile",
    "ICD": "SafeDisc Encrypted Program",
    "ICE": "ICE File Archive",
    "ICF": "Zoom Router Configuration File",
    "ICL": "Windows Icon Library File",
    "ICM": "Image Color Matching Profile",
    "ICMA": "InCopy Assignment File",
    "ICML": "InCopy Document",
    "ICMT": "InCopy Template",
    "ICN": "Windows Icon File",
    "ICNS": "macOS Icon Resource File",
    "ICO": "Icon File",
    "ICON": "Icon Image File",
    "ICONPACKAGE": "IconPackager Theme File",
    "ICONSET": "Mac OS X Icon Set Folder",
    "ICONTAINER": "CandyBar iContainer File",
    "ICPR": "IconUtils Project File",
    "ICS": "Calendar File",
    "ICST": "InCopy Document Preset File",
    "ICURSORFX": "iCursor Effect File",
    "ID": "Lotus Notes User ID File",
    "ID2": "Windows Live Messenger Emoticon File",
    "IDAP": "Adobe InDesign Assignment Package",
    "IDB": "IDA Database File",
    "IDC": "Internet Database Connector File",
    "IDE": "Inventor iFeature File",
    "IDEA": "Adobe Ideas Document",
    "IDEPLUGIN": "Xcode IDE Plug-in",
    "IDI": "EVA Controller Event Log",
    "IDL": "Interface Definition Language File",
    "IDLK": "Adobe InDesign Lock File",
    "IDML": "Adobe InDesign Markup Language File",
    "IDMS": "Adobe InDesign Snippet",
    "IDPK": "Adobe InDesign Package for GoLive File",
    "IDPP": "Adobe InDesign Preflight Profile",
    "IDT": "Windows Installer Database Text Archive File",
    "IDV": "Inventor Design View File",
    "IDW": "Inventor Drawing",
    "IDX": "Outlook Express Mailbox Index File",
    "IDX0": "Runescape Cache Index File",
    "IDX255": "Runescape Cache File",
    "IF": "Procedimientos-Uno IFWin Project File",
    "IFC": "Industry Foundation Classes File",
    "IFCXML": "Industry Foundation Classes XML File",
    "IFCZIP": "Compessed IFC File",
    "IFD": "InForm Document",
    "IFF": "Interchange File Format",
    "IFL": "3ds Max Image File List",
    "IFO": "DVD-Video Disc Information File",
    "IFP": "GTA Animation File",
    "IFW": "INTUS Firmware File",
    "IGC": "Anime List Builder Input File",
    "IGES": "IGES Drawing File",
    "IGI": "Indigo Image File",
    "IGM": "Indigo Renderer Material File",
    "IGP": "Igor Published Music Notation File ",
    "IGR": "Igor Engraver File",
    "IGS": "Indigo Renderer Scene File",
    "IGT": "iGrafx Document Template",
    "IGX": "iGrafx Document",
    "IHW": "IN-HEH Timeline Workspace",
    "IHX": "IN-HEH Timeline Database",
    "II": "IconWorkshop Extended Information File",
    "IIF": "Intuit Interchange Format File",
    "IIL": "CleanSweep Installation Log",
    "IIM": "iMacro Macro File",
    "IIP": "Install Creator Pro Project File",
    "IIQ": "Phase One RAW Image",
    "IIT": "Install Creator Project File",
    "IK": "CryENGINE IK Animation File",
    "IKF": "INTUS Keyboard File",
    "IKMP": "IK Multimedia Preset FIle",
    "ILBM": "Interleaved Bitmap Image",
    "ILDOC": "QuickSilver Document",
    "ILK": "Incremental Linking File",
    "IM4P": "IMG4 Payload File",
    "IMA": "Sage ACT! Email Message",
    "IMAGE": "Apple Disk Image",
    "IMAPMBOX": "IMAP Mailbox",
    "IMD": "Microsoft VisioModeler File",
    "IME": "Windows Input Method Editor File",
    "IMG": "GEM Image",
    "IMG3": "iPhone IMG3 File",
    "IMI": "Magellan Map File",
    "IMJ": "JFIF Bitmap Image",
    "IML": "IntelliJ IDEA Module",
    "IMM": "iMindMap Map File",
    "IMOVIELIBRARY": "iMovie Library File",
    "IMOVIEMOBILE": "iOS iMovie Project File",
    "IMOVIEPROJ": "iMovie Project File",
    "IMOVIEPROJECT": "iMovie Project",
    "IMP": "Improv Spreadsheet",
    "IMT": "My Time Data File",
    "IMTX": "iMindMap Template File",
    "IMX": "iMindMap Map File",
    "IMY": "iMelody Ringtone File",
    "IMZ": "WinImage Compressed Disk Image",
    "IN": "Input File",
    "INC": "Include File",
    "INCA": "InCopy CS3 Assignment File",
    "INCD": "InCopy Document",
    "INCT": "InCopy Template",
    "INCX": "InCopy CS3 Interchange File",
    "IND": "Adobe InDesign Document",
    "INDB": "Adobe InDesign Book File",
    "INDD": "Adobe InDesign Document",
    "INDESIGNPLUGIN": "Adobe InDesign Plug-in",
    "INDK": "Adobe Shortcut Set File",
    "INDL": "Adobe InDesign Library",
    "INDP": "Adobe InDesign CS3 Package File",
    "INDS": "Adobe InDesign Snippet File",
    "INDT": "Adobe InDesign Template",
    "INETLOC": "Internet Location",
    "INF": "Setup Information File",
    "INFO": "ZoomBrowser Image Index File",
    "INFOPATHXML": "Microsoft InfoPath Form",
    "INFORM": "Inform Project ",
    "INF_LOC": "Windows Driver Information Cache File",
    "ING": "MasterCook Ingredients File",
    "INI": "Windows Initialization File",
    "INK": "Mimio Ink Data File",
    "INL": "C++ Inline File",
    "INLK": "Adobe InDesign Lock File",
    "INLX": "Adobe InDesign Interchange Library",
    "INO": "Arduino Sketch File",
    "INP": "Abaqus Input File",
    "INPROGRESS": "Time Machine Backup Progress File",
    "INS": "Adlib Tracker Instrument File",
    "INSP": "Insta360 Panoramic Image",
    "INSV": "Insta360 Panoramic Video",
    "INT": "Sony Camcorder Image Management File",
    "INTERNETCONNECT": "Apple Internet Connect Document",
    "INX": "Compiled Script",
    "ION": "File Description File",
    "IOPLIST": "Mac OS X IOPLIST File",
    "IP": "IconPackager Theme File",
    "IPA": "iOS Application",
    "IPCC": "iPhone Carrier Bundle ",
    "IPCH": "Intellisense Precompiled Header File",
    "IPD": "BlackBerry Backup File",
    "IPF": "OS/2 Help File",
    "IPG": "iPod Game File",
    "IPHOTOPROJECT": "iPhoto Print Project",
    "IPICK": "iPick Football Image",
    "IPJ": "Inventor Project File",
    "IPK": "Itsy Package",
    "IPL": "GTA Item Placement File",
    "IPN": "Inventor Presentation File",
    "IPOD": "Rockbox Firmware File",
    "IPR": "InstallShield Professional Project File",
    "IPS": "Internal Patching System Patch File",
    "IPSPOT": "iPhoto Spot File",
    "IPSW": "iPod and iPhone Software Update File",
    "IPT": "Inventor Part File",
    "IPTHEME": "IconPackager Raw Theme File",
    "IPX": "IPIX Image",
    "IPYNB": "Jupyter Notebook",
    "IQY": "Internet Query",
    "IRCP": "SpeedGrade IRIDAS Composite File",
    "IRF": "CCTV DVR H.264 Video File",
    "IRR": "Irrlicht 3D Scene",
    "IRRMESH": "Irrlicht Static Mesh File",
    "IRS": "Adobe Save For Web Settings",
    "ISALE": "iSale Auction",
    "ISALETEMPLATE": "iSale Template",
    "ISALLIC": "iSale License File",
    "ISD": "Flexera InstallShield Dialog Box File",
    "ISE": "Xilinx ISE Project",
    "ISF": "Inspiration Flowchart Document",
    "ISH": "ISH Compressed Archive",
    "ISM": "IIS Smooth Streaming Manifest File",
    "ISMA": "IIS Smooth Streaming Audio File",
    "ISMC": "Smooth Streaming Client Manifest File",
    "ISMCLIP": "iStopMotion Animation Clip",
    "ISMV": "IIS Smooth Streaming Video File",
    "ISN": "Installer Source File",
    "ISO": "Disc Image File",
    "ISOZ": "Compressed Arbortext IsoDraw Illustration",
    "ISP": "IIS Internet Service Provider Settings",
    "ISR": "GoMoku Game File",
    "ISS": "InstallShield Silent Response File",
    "IST": "InstallShield Project Template File",
    "ISU": "InstallShield Uninstaller Script",
    "ISX": "SimulationX Project",
    "ISZ": "Zipped ISO Disk Image",
    "ITA": "VTech InnoTab Application File",
    "ITC": "iTunes Cover Flow Data File",
    "ITC2": "iTunes Cover Flow Data File 2",
    "ITDB": "iTunes Database File",
    "ITEMDATA-MS": "Windows 8 Start Screen Item Data File",
    "ITHMB": "iPod and iPhone Photo Thumbnails File",
    "ITI": "Impulse Tracker Instrument",
    "ITL": "iTunes Library File",
    "ITLS": "iTunes Live Stream URL",
    "ITM": "iThink Model File",
    "ITMS": "iTunes Music Store Link File",
    "ITMSP": "iTunes Store Package",
    "ITPC": "iTunes Podcast Link File",
    "ITS": "Impulse Tracker Sample",
    "ITT": "IconTweaker Theme File",
    "ITW": "InTouch With Database File",
    "ITX": "ITX Form Template",
    "IUS": "InfoTMIC Firmware Update File",
    "IV": "Open Inventor Scene Graph File",
    "IV2I": "Norton Ghost Incremental Virtual Volume Image",
    "IVA": "Surveillance Video File",
    "IVE": "OpenSceneGraph Binary File",
    "IVF": "Indeo Video Format File",
    "IVR": "Internet Video Recording",
    "IVS": "Internet Streaming Video",
    "IVT": "Beyond 20/20 Table File",
    "IVUE": "Live Picture IVUE Image",
    "IWA": "iWork Archive File",
    "IWB": "IWBasic Source Code File",
    "IWD": "Call of Duty Game Data File",
    "IWDGT": "iWeb Widget File",
    "IWI": "Infinity Ward Texture File",
    "IWS": "IntelliJ IDEA Web Page",
    "IX": "dtSearch Index File",
    "IXA": "Ulead Disc Image format",
    "IXB": "Ulead Disc Image",
    "IZE": "IZArc Archive",
    "IZZ": "Isadora Media Control Project",
    "IZZY": "Isadora Project",
    "J": "JPEG Image",
    "J01": "Akeeba Multi-part Backup Archive",
    "J2C": "JPEG 2000 Code Stream",
    "J2I": "Jazz 2 Internet Link File",
    "J2K": "JPEG 2000 Image",
    "J2L": "Jazz Jackrabbit 2 Level File",
    "J3O": "jMonkeyEngine 3D Scene",
    "J6I": "Ricoh Camera Image File",
    "JAC": "JaStaCry Encrypted File",
    "JAD": "Java Application Descriptor File",
    "JAM": "Line 6 Device Recording",
    "JAP": "Nonogram Puzzle File",
    "JAR": "Java Archive File",
    "JAR.PACK": "Pack200 Packed Jar File",
    "JARVIS": "Jarvis Subscriber File",
    "JAS": "Cheetah3D Model File",
    "JASPER": "JasperReports Data File",
    "JAVA": "Java Source Code File",
    "JB2": "JBIG2 Image",
    "JBC": "Jam STAPL Byte-Code File",
    "JBF": "Paint Shop Pro Browser Cache File",
    "JBG": "Joint Bi-level Image Group File",
    "JBIG": "Joint Bi-level Image Group File",
    "JBIG2": "JBIG2",
    "JBK": "Juno Backup File",
    "JBMP": "JAmes OS Bitmap Image",
    "JBR": "Paint Shop Pro Brushes File",
    "JC": "FlashGet Partial Download",
    "JC!": "FlashGet Incomplete Download",
    "JCEKS": "JCEKS Keystore File",
    "JCL": "JCloze File",
    "JCP": "JCreator Project File",
    "JCRYPT": "JCRYPT File",
    "JCW": "JCross File",
    "JCZ": "Liquid Motion Animation",
    "JDB": "Symantec Endpoint Protection Update File",
    "JDC": "JDownloader Links File",
    "JDF": "Adobe Acrobat Job Definition File",
    "JDR": "IROAD Dash Cam Video File",
    "JEF": "Janome Embroidery Format",
    "JET": "JET Database File",
    "JFI": "JPEG File Interchange Image",
    "JFIF": "JPEG File Interchange Format",
    "JG4": "BigJig Jigsaw Puzzle",
    "JGW": "JPEG World File",
    "JGZ": "Gzipped Javascript File",
    "JHTML": "Java HTML Web Page",
    "JIA": "Digital Photo Navigator Album",
    "JIC": "Java Icon File",
    "JIF": "JPEG Interchange Format Image",
    "JIFF": "JPEG Image File Format",
    "JIS": "Japanese Industry Standard Text",
    "JKM": "JAWS Key Map File",
    "JKS": "Java Keystore File",
    "JMC": "JM-Crypt Encrypted File",
    "JMCE": "JM-Crypt Encrypted File",
    "JMCK": "JM-Crypt Key File",
    "JMCP": "JM-Crypt Encrypted File",
    "JMCR": "JM-Crypt Encrypted File",
    "JMCX": "JM-Crypt Encrypted File",
    "JMF": "Jackhammer Project",
    "JMS": "Masher Project",
    "JMT": "JMatch File",
    "JMV": "Jnes Movie File",
    "JMX": "JMix File",
    "JNG": "JPEG Network Graphic",
    "JNLP": "Java Web Start File",
    "JNP": "Java Web Start File",
    "JNR": "JoinNet Recording File",
    "JNT": "Windows Journal File",
    "JNX": "BirdsEye JNX Raster Map",
    "JOB": "MetaCAM Nest Job File",
    "JOE": "JOE Document",
    "JOINED": "HJ-Split Data File",
    "JOY": "CryENGINE Facial Editor Joystick File",
    "JP1": "Japanese (Romaji) Text File",
    "JP2": "JPEG 2000 Core Image File",
    "JPA": "Akeeba Backup Archive",
    "JPC": "JPEG 2000 Code Stream File",
    "JPD": "Joint PhotoDefiner Image",
    "JPE": "JPEG Image",
    "JPEG": "JPEG Image",
    "JPF": "JPEG 2000 Image",
    "JPG": "JPEG Image",
    "JPG-LARGE": "Large JPEG Image",
    "JPG2": "JPEG 2000 Image",
    "JPGW": "JPEG World File",
    "JPH": "JProbe Memory Snapshot",
    "JPN": "Windows Japanese Noise-Word List File",
    "JPR": "Fugawi Projection File",
    "JPS": "Stereo JPEG Image",
    "JPW": "World File for JPEG",
    "JPX": "JPEG 2000 Image File",
    "JQZ": "JQuiz File",
    "JRPRINT": "JasperReports Print File",
    "JRS": "Exchange Reserve Transaction Log File",
    "JRTF": "JAmes OS Rich Text File",
    "JRXML": "JasperReports Layout File",
    "JS": "JavaScript File",
    "JSD": "HP JetSuite Document",
    "JSE": "JScript Encoded File",
    "JSF": "Java Script Command File",
    "JSFL": "Animate JSFL Script File",
    "JSL": "Corel PaintShop Pro Shape Library",
    "JSON": "JavaScript Object Notation File",
    "JSONLZ4": "Compressed Firefox Bookmarks Backup File",
    "JSP": "Java Server Page",
    "JSPA": "Java Servlet Alias",
    "JSPF": "JSON Playlist File",
    "JSPX": "XML Java Server Page",
    "JSS": "JACOsub Subtitle File",
    "JST": "Jnes Save State",
    "JSX": "ExtendScript Script File",
    "JSXBIN": "Binary ExtendScript Script File",
    "JT": "JT Open CAD File",
    "JTD": "JustSystems Ichitaro Document",
    "JTF": "JPEG Tagged Interchange Format",
    "JTP": "Windows Journal Template",
    "JTS": "Cyberlink AVCHD Video File",
    "JTV": "JRiver TV File",
    "JTX": "XPS Document",
    "JVS": "JavaScript Proxy Autoconfig File",
    "JVSG": "Video Surveillance Project",
    "JVSGZ": "Compressed Video Surveillance Project",
    "JWL": "Roxio Jewel Case File",
    "JWPUB": "Jehovah's Witnesses Publication File",
    "JWS": "Java Web Services File",
    "JXR": "JPEG XR Image",
    "K25": "Kodak K25 Image",
    "K26": "Kurzweil K2600 File",
    "K3B": "K3b Disk Burning Project File",
    "K3G": "3GP Mobile Phone Video File",
    "KAP": "BSB Chart Image File",
    "KAR": "Karaoke MIDI File",
    "KB2": "Kleo Backup File",
    "KBD": "Keyboard Layout Script",
    "KCB": "Kindle Create Book File",
    "KDB": "Keypass Database File",
    "KDC": "Kaspersky Virus Database File",
    "KDE": "KryptoStorage Container File",
    "KDENLIVE": "Kdenlive Project File",
    "KDEVELOP": "KDevelop Project Data File",
    "KDEVPRJ": "KDevelop Project File",
    "KDI": "KD Player Skin Image File",
    "KDK": "Kodak Proprietary Decimated TIFF File",
    "KDS": "KD Player Skin File",
    "KES": "Kurzweil 3000 Document",
    "KEXI": "Kexi Database",
    "KEXIC": "Kexi Database Connection File",
    "KEXIS": "Kexi Database Shortcut File",
    "KEXT": "Mac OS X Kernel Extension",
    "KEY": "Keynote Presentation",
    "KEYCHAIN": "Mac OS X Keychain File",
    "KEYSTORE": "Java Keystore File",
    "KFM": "Gamebryo 3D Model File",
    "KFN": "KaraFun Karaoke File",
    "KFX": "Amazon KF10 eBook File",
    "KGB": "KGB Archive File",
    "KHD": "Dynamics AX Kernel Help Data File",
    "KHI": "Dynamics AX Kernel Help Index File",
    "KIC": "Kodak Compressed Image File",
    "KID": "Kidspiration Document",
    "KISMAC": "KisMAC Webservice File",
    "KIT": "20-20 Design File",
    "KIX": "KiXtart Script File",
    "KKK": "KKK Ransomware Encrypted File",
    "KLG": "Log File",
    "KLQ": "Kaspersky Quarantine File",
    "KMC": "Kinemac Animation File",
    "KMCOBJ": "Kinemac Sprite Object",
    "KML": "Keyhole Markup Language File",
    "KMM": "K-Meleon Macro Module",
    "KMP": "Korg Trinity/Triton Keymap File",
    "KMV": "Mobile DJ Video File",
    "KMZ": "Google Earth Placemark File",
    "KNT": "KeyNote Note File",
    "KO": "Linux Kernel Module File",
    "KODAK": "Kodak Photo CD File",
    "KODE": "KodeFile Encrypted File",
    "KODU": "Kodu Game File",
    "KON": "Yahoo! Widget XML File",
    "KOOB": "Koob E-Book File",
    "KOR": "Windows Korean Noise-Words List File",
    "KOZ": "Audiokoz Music File",
    "KPF": "Komodo Project File",
    "KPG": "Kai's Power Goo Graphic",
    "KPL": "Kazaa Playlist File",
    "KPP": "Kid Pix Presentation",
    "KPR": "KPresenter Presentation",
    "KPX": "Kid Pix Picture",
    "KPZ": "Komodo Template File",
    "KRA": "Krita Image Document",
    "KRAB": "GandCrab V4 Ransomware Encrypted File",
    "KRZ": "Kurzweil K2000 File",
    "KS": "Kickstart File",
    "KSC": "Korg Trinity/Triton Script File",
    "KSD": "KeepSafe File",
    "KSF": "Korg Trinity/Triton Sample File",
    "KSH": "Unix Korn Shell Script",
    "KT3": "Battery 3 Drum Kit File",
    "KTH": "Keynote Theme",
    "KTN": "KTooN Animation Project File",
    "KTZ": "Kahootz Project File",
    "KWD": "KWord Document",
    "KWM": "WebMoney Key File",
    "KWREPLAY": "Command & Conquer 3 Replay File",
    "KX": "KiXtart Tokenized Script File",
    "KXX": "Keyman Developer Encrypted Keyboard File",
    "KYR": "Lotus Domino Key Ring File",
    "KYS": "Adobe Photoshop Keyboard Shortcuts File",
    "KZ": "KuaiZip Compressed File",
    "L": "Left Audio Channel File",
    "L01": "EnCase Logical Evidence File",
    "L3B": "LEGO 3D Model File",
    "L4D": "Cinema 4D Layout File",
    "L6T": "Line 6 Tone File",
    "LA": "Lossless Audio File",
    "LAB": "WordPerfect Label Definition File",
    "LAN": "ERDAS LAN File",
    "LASSO": "Lasso Database-Driven Web Page",
    "LASTLOGIN": "Minecraft User Credential File",
    "LATEX": "LaTeX Document",
    "LAY": "DVD Studio Pro Layout File",
    "LAYOUT": "LayOut Document",
    "LB": "Lens Blur Project File",
    "LBC": "Cloaked Affiliate Link Builder Saved Link",
    "LBF": "LG Backup File",
    "LBI": "Dreamweaver Library Item",
    "LBL": "NiceLabel Template File",
    "LBM": "Deluxe Paint Bitmap Image",
    "LBR": "LU Library Archive",
    "LBS": "Omnis Library",
    "LBT": "FoxPro Label Memo",
    "LCB": "Living Cookbook Backup File",
    "LCC": "Capture One Lens Cast Correction File",
    "LCD": "CDSpace Emulated Disk Image",
    "LCF": "ArchiCAD Library Container File",
    "LCK": "Program Lock File",
    "LCM": "Lipikar Custom Map File",
    "LCN": "License File",
    "LDABAK": "Legistant Encrypted Backup File",
    "LDB": "Max Payne Level File",
    "LDIF": "LDAP Data Interchange Format File",
    "LDM": "VolumeViz Multi-Resolution Volume File",
    "LDR": "LDraw Model File",
    "LDS": "Binutils LD Linker Script",
    "LDT": "Eulumdat Formatted Luminaire Data File",
    "LDW": "Virtual Villagers Saved Game File",
    "LEMON": "LemonShare.net Download",
    "LEN": "IMAGINE Lens Flare File",
    "LESS": "LESS Style Sheet",
    "LETTER": "Undeliverable Mail File",
    "LFS": "Samsung Phone params.lfs File",
    "LGC": "SimpleK Database File",
    "LGH": "HMI Historical Log File",
    "LGI": "Multimedia Logic File",
    "LGL": "LeechGet Download List",
    "LGO": "Logo Instructions File",
    "LGP": "Final Fantasy Media Archive",
    "LH3D": "Live Home 3D Project",
    "LHA": "LHARC Compressed Archive",
    "LHS": "Literate Haskell Script",
    "LHZD": "Live Home 3D Compressed Project",
    "LI3D": "Live Interior 3D Document",
    "LIA": "P-CAD ASCII Library file ",
    "LIB": "Generic Data Library",
    "LIBRARY-MS": "Windows Library Description File",
    "LIBZIP": "Camtasia Studio Zipped Library File",
    "LIC": "Software License File",
    "LICENSEKEY": "iPartition License Key File",
    "LICENSES": "Visual Studio Licensed Classes File",
    "LICX": "Visual Studio License File",
    "LID": "Kodak EasyShare Album File",
    "LIF": "Leica Image File",
    "LIGHTKEYPROJ": "Lightkey Project",
    "LILOCKED": "Lilocked Ransomware Encrypted File",
    "LIN": "AutoCAD Linetype File",
    "LINK": "iPod Link File",
    "LINX": "iPod Links Folder",
    "LIP": "Clip Studio Paint File",
    "LIS": "SQR Output File",
    "LISP": "Lisp Source Code File",
    "LIT": "eBook File",
    "LITAR": "Litar Virus Encrypted File",
    "LITEMOD": "Minecraft LiteLoader Mod File",
    "LIVECODE": "LiveCode Stack File",
    "LIVEUPDATE": "Symantec LiveUpdate File",
    "LIX": "Logos Library System File",
    "LIZD": "Live Interior 3D Compressed Document",
    "LJP": "Lossless JPEG Image",
    "LL": "List & Label Preview File",
    "LLD": "Logo! Soft Comfort LAD File",
    "LLM": "Linden Lab Mesh File",
    "LLX": "LabVIEW VI Library Backup File",
    "LMA": "Logo! UDF File",
    "LMK": "Sothink Logo Maker Image",
    "LMP": "Quake Engine Lump File",
    "LMS": "LenMus Score File",
    "LMU": "RPG Maker Map File",
    "LMX": "Landmark Exchange File",
    "LND": "3D Landscape File",
    "LNG": "Acrobat Language Plug-in",
    "LNK": "Windows Shortcut",
    "LNT": "Laego Note Taker File",
    "LNX": "Commodore 64 Lynx Archive",
    "LO": "Interleaf Compiled Lisp File",
    "LOCK": "Lock File",
    "LOCKED": "Ransomware Encrypted File",
    "LOCKFILE": "Mac OS X PLIST Lock File",
    "LOCKY": "Locky Ransomware Encrypted File",
    "LOD": "Heroes of Might and Magic 3 Graphics File",
    "LOF": "Audacity File List",
    "LOG": "Log File",
    "LOG1": "Windows Registry Hive Log File",
    "LOG2": "Windows Registry Hive Log 2 File",
    "LOGIC": "Logic Pro Project File",
    "LOGICLY": "Logicly Circuit File",
    "LOGICX": "Logic Pro Project",
    "LOGONVISTA": "LogonStudio Windows Vista Logon Screen",
    "LOGONXP": "LogonStudio Windows XP Logon Screen",
    "LOOK": "SpeedGrade Look File",
    "LOOV": "Smadav Virus Definitions File",
    "LOP": "MasterCook Layout File",
    "LOVE": "L\u00d6VE Game File",
    "LP": "Lightscape Preparation File",
    "LP2": "iLEAP Word Processing Document",
    "LP7": "LP7 Digitally Signed File",
    "LPD": "Lookout Protocol Driver File",
    "LPDF": "Localized PDF File",
    "LPK": "ArcGIS Layer Package",
    "LPKG": "Liferay Application",
    "LPROJ": "Localized Project Folder",
    "LPS": "Bryce Leaf Shape File",
    "LQR": "SQ Compressed LBR Archive",
    "LRC": "Lyrics File",
    "LREC": "Inter-Tel Web Conference Recording",
    "LRF": "Sony Portable Reader File",
    "LRMODULE": "Adobe Lightroom Module",
    "LRPLUGIN": "Adobe Lightroom Plug-in",
    "LRPREVIEW": "Adobe Lightroom Preview File",
    "LRS": "Librie Reader Source File",
    "LRSMCOL": "Adobe Lightroom Smart Collection Settings File",
    "LRTEMPLATE": "Adobe Lightroom Template",
    "LRV": "Low Resolution Video File",
    "LRWEBENGINE": "Adobe Lightroom Web Gallery File",
    "LRX": "Sony Portable Reader File",
    "LS": "LightWave LScript File",
    "LS3": "Magic Bullet Looks Package",
    "LSC": "Logo! Soft Comfort File",
    "LSD": "RPG Maker Game Save File",
    "LSF": "Logos Library System File",
    "LSL": "LightScribe Label",
    "LSO": "Logic Audio Project",
    "LSPROJ": "Visual Studio LightSwitch Project",
    "LST": "Data List",
    "LSW": "RPG Maker Saved Game File",
    "LSX": "Streaming Media Shortcut",
    "LT2": "Poser Light Set File",
    "LTB": "LithTech Binary File",
    "LTF": "Laser App Temp Form File",
    "LTL": "Luminaire Data File",
    "LTR": "Letter File",
    "LTX": "LaTeX Document",
    "LTZ": "Compressed Poser Light Set File",
    "LUA": "Lua Source File",
    "LUCIDSNIPPET": "Lucid Snippet File",
    "LUE": "Norton LiveUpdate Log File",
    "LUF": "Lipikar Uniform Format File",
    "LUXB": "Lux Map File",
    "LVA": "Logitech Video Effects Avatar File",
    "LVF": "Logitech Video Effects File",
    "LVIVT": "Lvivtotoro Encrypted Game File",
    "LVIX": "Lightworks Video Index File",
    "LVL": "Game Level File",
    "LVM": "LabVIEW Measurement File",
    "LWFN": "Adobe Type 1 Mac Font File",
    "LWO": "LightWave 3D Object File",
    "LWP": "Lotus Word Pro Document",
    "LWS": "LightWave 3D Scene File",
    "LWTP": "LimeWire Theme Pack",
    "LWV": "Linguistically Enhanced Sound File",
    "LWX": "Lightwright Database File",
    "LX01": "EnCase Logical Evidence File",
    "LXA": "Microsoft Speech Lexicon File",
    "LXF": "LEGO Digital Designer Model File",
    "LXFML": "LEGO Digital Designer XML File",
    "LXO": "Luxology modo 3D Image",
    "LXSOPT": "Liquid XML Studio Project Options File",
    "LXSPROJ": "Liquid XML Studio Project File",
    "LYC": "bestIMAGE Compressed Design File",
    "LYR": "bestIMAGE Design File",
    "LYT": "TurboTax Install Log File",
    "LYX": "LyX Document",
    "LZ": "Lzip Compressed File",
    "LZH": "LZH Compressed File",
    "LZM": "Slax Module",
    "LZMA": "LZMA Compressed File",
    "LZO": "LZO Compressed File",
    "LZP": "LazPaint Image",
    "LZX": "Amiga LZX Compressed File",
    "M": "Objective-C Implementation File",
    "M15": "MPEG Video",
    "M1PG": "iFinish Video Clip",
    "M1V": "MPEG-1 Video File",
    "M2": "World or Warcraft Model Object",
    "M21": "MPEG-21 File",
    "M2A": "MPEG-1 Layer 2 Audio File",
    "M2P": "MPEG-2 Program Stream File",
    "M2S": "Maxthon 2 Browser Skin File",
    "M2T": "HDV Video File",
    "M2TS": "Blu-ray BDAV Video File",
    "M2V": "MPEG-2 Video",
    "M3": "Blizzard MDX3 Model File",
    "M3D": "3D Model File",
    "M3G": "Mobile 3D Graphics Program",
    "M3P": "Mach3 Plugin File",
    "M3U": "Media Playlist File",
    "M3U8": "UTF-8 M3U Playlist File",
    "M4": "Macro Processor Library",
    "M4A": "MPEG-4 Audio File",
    "M4B": "MPEG-4 Audio Book File",
    "M4E": "MPEG-4 Video File",
    "M4P": "iTunes Music Store Audio File",
    "M4R": "iPhone Ringtone File",
    "M4U": "MPEG-4 Playlist",
    "M4V": "iTunes Video File",
    "M5P": "MachFive Preset File",
    "M75": "MPEG Video",
    "MA": "Maya Project File",
    "MA1": "Monarch Audio File",
    "MAB": "Mozilla Address Book",
    "MAC": "MacPaint Image",
    "MAE": "My Avatar Editor Character File",
    "MAF": "Microsoft Access Form",
    "MAFF": "Mozilla Archive Format File",
    "MAG": "Access Diagram Shortcut File",
    "MAGIK": "Magik Source Code File",
    "MAHJONGTITANSSAVE-MS": "Mahjong Titans Saved Game",
    "MAI": "Microsoft Mail File",
    "MAILHOST": "MSN Mailhost Settings File",
    "MAILPLANELICENSE": "Mailplane License File",
    "MAILSTATIONERY": "Apple Mail Stationery File",
    "MAILTOLOC": "Mail Internet Location File",
    "MAK": "Makefile",
    "MAKERBOT": "MakerBot Print File",
    "MAL": "MadAppLauncher Configuration File",
    "MAM": "Microsoft Access Macro",
    "MAN": "Unix Manual",
    "MANI": "Mine-imator Project File",
    "MANIFEST": "Windows Application Manifest File",
    "MAP": "Quake Engine Map File",
    "MAPIMAIL": "Send To Mail Recipient",
    "MAPLET": "Maplet World File",
    "MAPX": "Mapjects Client Webparts File",
    "MAQ": "Microsoft Access Query",
    "MAR": "Mariner Calc Spreadsheet",
    "MARKDOWN": "Markdown Documentation File",
    "MARS": "Adobe MARS File",
    "MARSHAL": "Marshal Data Migration Model File",
    "MART": "MartView eBook File",
    "MAS": "Access Stored Procedures",
    "MASK": "SpeedGrade Color Mask File",
    "MASSEFFECTPROFILE": "Mass Effect Player Profile",
    "MASSEFFECTSAVE": "Mass Effect Saved Game",
    "MASTER": "ASP.NET Master Page",
    "MAT": "MATLAB MAT-File",
    "MATERIAL": "Rigs of Rods Texture Reference File",
    "MAV": "Access View File",
    "MAW": "Access Data Access Page",
    "MAX": "3ds Max Scene File",
    "MAXC": "3ds Max Container File",
    "MB": "Maya Binary Project File",
    "MBA": "Martus Bulletin Archive",
    "MBB": "Kodak EasyShare Data File",
    "MBBK": "ManaBook Book Kit File",
    "MBF": "Microsoft Money Backup File",
    "MBG": "Mailbag Assistant Mailbox File",
    "MBI": "Multi-Bootable Information File",
    "MBK": "dBASE IV Multiple Index Backup File",
    "MBM": "Multi Bitmap File",
    "MBN": "Multi Boot Image",
    "MBOX": "Email Mailbox File",
    "MBP": "Mobipocket Notes File",
    "MBR": "Zune Smooth Streaming File",
    "MBS": "Opera Mailbox File",
    "MBW": "MBRWizard Archive",
    "MBX": "Outlook Express Mailbox",
    "MBZ": "Moodle Backup FIle",
    "MC2": "MasterCook 5 Cookbook File",
    "MC5": "Poser 5 Material File",
    "MC6": "Poser Material Collection File",
    "MC9": "Mastercam 9 Geometry File",
    "MCA": "Minecraft \"Anvil\" Map File",
    "MCAPM": "Minecraft Anvil PocketMine Data File",
    "MCD": "Mathcad Document",
    "MCDX": "Mathcad Prime Document",
    "MCF": "Watchtower Library Font File",
    "MCFI": "Maya Initial Fluid Cache File",
    "MCFP": "Maya Fluid Cache Playback File",
    "MCL": "Windows Media Center Link File",
    "MCO": "Live Messenger Winks File",
    "MCP": "CodeWarrior Project",
    "MCPACK": "Minecraft Resource Pack File",
    "MCR": "3ds Max Macroscript File",
    "MCRP": "MobyExplorer Encrypted File",
    "MCS": "Mathcad Image",
    "MCSERVER": "Minecraft Server File",
    "MCSP": "My Craft Studio Project File",
    "MCSX": "My Craft Studio Professional File",
    "MCW": "MacWrite II Document",
    "MCWORLD": "Minecraft World Backup File",
    "MCX": "MICRO CADAM-X/6000 Model Data File",
    "MCZ": "Compressed Poser Material File",
    "MD": "MDCD Compressed Archive",
    "MD0": "Alcohol Disk Image Segment 1",
    "MD1": "GEAR CD/DVD Disc Image",
    "MD2": "Quake 2 Player Model",
    "MD3": "Quake 3 3D Model",
    "MD5": "MD5 Checksum File",
    "MD5.TXT": "Message Digest 5 Hash File",
    "MD5ANIM": "id Tech 4 Model Animation File",
    "MD5CAMERA": "id Tech 4 Model Camera File",
    "MD5MESH": "id Tech 4 3D Mesh File",
    "MDA": "Access Add-in",
    "MDB": "Microsoft Access Database",
    "MDBACKUP": "iPhone Data Backup File",
    "MDBHTML": "Microsoft Access Database HTML File",
    "MDC": "Multi Dimension Cube File",
    "MDD": "Point Oven Deformation Data File",
    "MDDATA": "iPhone Backup File",
    "MDE": "Compiled Access Add-in File",
    "MDF": "Media Disc Image File",
    "MDI": "Microsoft Document Imaging File",
    "MDIMPORTER": "Metadata Importer",
    "MDINFO": "iPhone Backup Information File",
    "MDJ": "StarUML Model File",
    "MDL": "MathWorks Simulink Model",
    "MDM": "HLM Multivariate Data Matrix File",
    "MDMP": "Windows Minidump",
    "MDN": "Blank Access Database Template",
    "MDP": "FireAlpaca Image",
    "MDR": "ModPlug Compressed Module",
    "MDS": "TestComplete Project File",
    "MDSX": "MEGA Saved Session",
    "MDT": "GeoMedia Access Database Template",
    "MDW": "Access Workgroup File",
    "MDX": "Multiple Index File",
    "MDZIP": "MagicDraw Project Archive",
    "ME": "Readme Text File",
    "MEB": "PRO100 3D Interior Catalog Element",
    "MED": "Amiga MED Sound File",
    "MEF": "Mamiya RAW Image",
    "MEL": "Maya Embedded Language File",
    "MELL": "Mellel Word Processing File",
    "MELLEL": "Mellel Word Processing Document",
    "MEM": "Macro Editor Macro",
    "MENC": "Windows Mobile Encrypted File",
    "MENU": "Quake 3 Engine Menu File",
    "MEO": "MEO Encrypted Archive",
    "MER": "RSView Development Runtime File",
    "MERLINLICENSE": "Merlin License File",
    "MESH": "Godot Engine 3D Mesh File",
    "MET": "eMule Resource File",
    "META": "RealPlayer Metafile",
    "METADATA_NEVER_INDEX": "Spotlight Never Index File",
    "MEX": "Macro Express File",
    "MF": "METAFONT File",
    "MFA": "Multimedia Fusion Development File",
    "MFD": "Music Finder Database",
    "MFIL": "Blizzard Software Update File",
    "MFO": "Perl ModInfo Descriptor File",
    "MFP": "MediaFACE Project File",
    "MFS": "MetFS Encrypted File System",
    "MFT": "MediaFACE Project Template",
    "MFW": "Mamiya Camera Raw File",
    "MFX": "Multimedia Fusion Extension",
    "MGA": "Manga Document",
    "MGC": "Microsoft Clip Organizer Media Catalog",
    "MGCB": "Equation Illustrator Project File",
    "MGDATABASE": "MacGourmet Deluxe Database File",
    "MGF": "Materials and Geometry Format",
    "MGK": "ImageMagick Configuration File",
    "MGL": "Age of Empires 2 Replay File",
    "MGM": "MGMaps File",
    "MGMF": "MindGenius Map File",
    "MGMT": "MindGenius 2-3 Template",
    "MGMX": "MindGenius XML Map File",
    "MGO": "MacGourmet Recipe File",
    "MGS": "MGCSoft Vector Shapes File",
    "MGT": "Musicnotes Guitar Guru Song File",
    "MGTX": "MindGenius XML Template File",
    "MGV": "Yamaha MegaVoice File",
    "MGX": "Age of Empires 2 Expansion Replay File",
    "MHS": "Xilinx XPS Hardware Specification File",
    "MHT": "MHTML Web Archive",
    "MHTML": "MIME HTML File",
    "MI4": "Audio Player Firmware File",
    "MIC": "Image Composer File",
    "MID": "MIDI File",
    "MIDI": "MIDI File",
    "MIF": "FrameMaker Interchange Format File",
    "MIFF": "Magick Image File",
    "MIG": "Windows Migration Backup File",
    "MII": "Wii Virtual Avatar File",
    "MILK": "MilkDrop Winamp Plugin Preset",
    "MIM": "Multi-Purpose Internet Mail Message File",
    "MIME": "Multi-Purpose Internet Mail Extension",
    "MIN": "Mint Source File",
    "MINESWEEPERSAVE-MS": "Minesweeper Saved Game",
    "MINIGSF": "Game Boy Advance Song File",
    "MINIPSF": "Miniature PlayStation Sound Format File",
    "MINIPSF2": "Miniature PlayStation Sound Format File",
    "MINISO": "Mini Image Destination File",
    "MINIUSF": "Nintendo 64 Song File",
    "MINT": "Linux Mint Installer File",
    "MIO": "MioEngine Application File",
    "MIP": "Multiple Image Print File",
    "MIR": "Mini-Image Ripper Disc Image",
    "MIS": "Saved Game Mission File",
    "MIX": "3ds Max Motion Mixer File",
    "MJ2": "Motion JPEG 2000 Video Clip",
    "MJD": "Adobe Acrobat MIME Encoded Job Definition File",
    "MJDOC": "MacJournal Document",
    "MJK": "Question File",
    "MJP": "MJPEG Video File",
    "MJPEG": "Motion JPEG Video File",
    "MJPG": "Motion JPEG Video File",
    "MJS": "Node.js ES Module File",
    "MK": "Makefile",
    "MK3D": "Matroska 3D Video File",
    "MKA": "Matroska Audio File",
    "MKV": "Matroska Video File",
    "ML": "ML Source Code File",
    "MLC": "Microsoft Language Interface Pack",
    "MLK": "MasterCook Look File",
    "MLL": "Maya Plugin",
    "MLS": "Milestones Simplicity File",
    "MLX": "MATLAB Live Script",
    "MM": "NeXtMidas Macro File",
    "MMAP": "MindManager Map File",
    "MMAT": "MindManager Map Template",
    "MMC": "Microsoft Media Catalog",
    "MMDC": "MediaMonkey Device Configuration File",
    "MME": "Multi-Purpose Internet Mail",
    "MMF": "Meal-Master Recipe File",
    "MMG": "Model Master 3 Axis Flat File",
    "MMIP": "MediaMonkey Installation Package",
    "MML": "FrameMaker Maker Markup Language File",
    "MMLP": "Music Macro Language Project",
    "MMM": "Music Maker Arrangement File",
    "MMO": "Memory Map Overlay File",
    "MMP": "MindManager Mind Map",
    "MMPZ": "LMMS Project File",
    "MMV": "MicroMV Video File",
    "MMZ": "MiraMon Compressed Map File",
    "MNC": "My Notes Center Notebook",
    "MNG": "Multiple Network Graphic",
    "MNH": "Master Navigator Header File",
    "MNL": "AutoCAD Menu LISP File",
    "MNM": "Character Studio Marker Name File",
    "MNO": "Macromedia Design Note",
    "MNR": "AutoCAD Menu Resource File",
    "MNS": "AutoCAD Interface Settings File",
    "MNT": "FoxPro Menu Memo",
    "MNU": "AutoCAD Interface Layout File",
    "MNV": "PlayStation Movie File",
    "MNX": "FoxPro Menu",
    "MO": "Machine Object File",
    "MO3": "MO3 Audio File",
    "MOB": "MOBTV Video File",
    "MOBI": "Mobipocket eBook",
    "MOBILECONFIG": "Apple Mobile Configuration File",
    "MOBILEPROVISION": "Xcode Mobile Provisioning Profile",
    "MOBIRISE": "Mobirise Project File",
    "MOD": "Amiga Music Module File",
    "MODD": "Sony Video Analysis File",
    "MODE": "Coda Syntax Mode File",
    "MODEL": "CATIA 3D Model FIle",
    "MODFEM": "Femap Model",
    "MODULE": "Drupal Module File",
    "MOEF": "Apple Motion Effect Project Template",
    "MOF": "Managed Object Format File",
    "MOFF": "Sony Video Data File",
    "MOGG": "Multitrack Ogg File",
    "MOHO": "Moho Animation Project",
    "MOI": "MOI Video File",
    "MOM": "Managed Object Model",
    "MONTAGE": "Montage Screenplay File",
    "MOOV": "Apple QuickTime Movie",
    "MOS": "Leaf Camera RAW File",
    "MOSAIC": "MacOSaiX Mosaic File",
    "MOT": "LightWave Motion File",
    "MOTI": "Apple Motion Title Project Template",
    "MOTN": "Apple Motion Generator Project Template",
    "MOTR": "Apple Motion Transition Project Template",
    "MOU": "WinMount Compressed File",
    "MOV": "Apple QuickTime Movie",
    "MOVIE": "QuickTime Movie File",
    "MOX": "ExtendSim Simulation Software Model",
    "MOZ": "Mozilla Cache File",
    "MP": "Maya PLE Project File",
    "MP10": "Multisim 10 Project File",
    "MP11": "Multisim 11 Project File",
    "MP12": "Multisim 12 Project",
    "MP13": "Multisim 13 Project",
    "MP14": "Multisim 14 Project",
    "MP2": "MPEG Layer II Compressed Audio File",
    "MP21": "MPEG-21 Multimedia File",
    "MP2M": "Max Payne 2 Mod File",
    "MP2S": "Max Payne 2 Saved Game",
    "MP2V": "MPEG-2 Video File",
    "MP3": "MP3 Audio File",
    "MP4": "MPEG-4 Video File",
    "MP4.INFOVID": "Parrot AR Drone and Gyro Flyer Video",
    "MP4V": "MPEG-4 Video",
    "MP7": "Multisim 7 Project File",
    "MP8": "Multisim 8 Project",
    "MP9": "Multisim 9 Project File",
    "MPA": "MPEG-2 Audio File",
    "MPB": "MyPhoneExplorer Backup File",
    "MPC": "Musepack Compressed Audio File",
    "MPCPL": "Media Player Classic Playlist",
    "MPD": "Microsoft Project Database",
    "MPDCONF": "Music Player Daemon File",
    "MPDP": "MixPad Project File",
    "MPE": "MPEG Movie File",
    "MPEG": "MPEG Movie",
    "MPEG1": "MPEG-1 Video File",
    "MPEG2": "MPEG-2 Video File",
    "MPEG4": "MPEG-4 File",
    "MPF": "MainActor Project File",
    "MPG": "MPEG Video File",
    "MPG2": "MPEG-2 Video File",
    "MPG4": "MPEG-4 Video File",
    "MPGA": "MPEG-1 Layer 3 Audio File",
    "MPGINDEX": "Adobe MPEG Index File",
    "MPH": "Photostory Deluxe Project",
    "MPJ": "messiahStudio Project File",
    "MPK": "ArcGIS Map Package",
    "MPKG": "Meta Package File",
    "MPKT": "MOPEKS Trial File",
    "MPL": "AVCHD Playlist File",
    "MPLS": "Blu-ray Movie Playlist File",
    "MPM": "Max Payne Modfication File",
    "MPO": "Multi Picture Object File",
    "MPP": "Microsoft Project File",
    "MPQ": "Blizzard Mo'PaQ File",
    "MPR": "FoxPro Generated Menu Program",
    "MPROJ": "Mine-imator Project",
    "MPS": "Pocket Streets Map File",
    "MPSUB": "MPlayer Subtitles File",
    "MPT": "Microsoft Project Template",
    "MPU": "MPEG Layer 3 Audio File",
    "MPV": "MPEG Elementary Stream Video File",
    "MPV2": "MPEG-2 Video Stream",
    "MPX": "Microsoft Project Exchange File",
    "MQO": "Metasequoia Document",
    "MQV": "Sony Movie Format File",
    "MRB": "Multiple Resolution Bitmap File",
    "MRC": "mIRC Script File",
    "MRG": "Now Contact Merge Template",
    "MRIMG": "Macrium Reflect Disk Image",
    "MRK": "DPOF Auto Print Order File",
    "MRML": "3D Slicer Scene Description File",
    "MRP": "Mythroad Platform File",
    "MRS": "GunZ Game Data File",
    "MRT": "Stimulsoft Report File",
    "MRW": "Minolta Raw Image File",
    "MRXS": "MIRAX Virtual Slide File",
    "MS": "3ds Max Script File",
    "MS11": "Multisim 11 Circuit Design File",
    "MS12": "Multisim 12 Circuit Design File",
    "MS13": "Multisim 13 Circuit Design File",
    "MS14": "Multisim 14 Circuit Design File",
    "MS3D": "MilkShape 3D Model",
    "MS7": "Multisim 7 Circuit Design File",
    "MS9": "Multisim 9 Circuit Design File",
    "MSC": "Microsoft Management Console Snap-in Control File",
    "MSCX": "MuseScore Music Score File",
    "MSCZ": "MuseScore Compressed Score File",
    "MSD": "Map Service Definition File",
    "MSDVD": "Windows DVD Maker Project File",
    "MSE": "MediaShow Slideshow Project File",
    "MSF": "Mail Summary File",
    "MSG": "Outlook Mail Message",
    "MSH": "Visual Communicator Project File",
    "MSHA": "Microsoft Help Asset File",
    "MSHC": "Microsoft Help Container File ",
    "MSHI": "Microsoft Help Index File",
    "MSI": "Windows Installer Package",
    "MSIM": "mSecure Password Manager Backup File",
    "MSIX": "MSIX Installer Package",
    "MSK": "Paint Shop Pro Mask File",
    "MSKN": "MediaMonkey Skin File",
    "MSL": "Magick Scripting Language File",
    "MSM": "Multisim Circuit Design File",
    "MSMPL_BANK": "Korg microSAMPLER Bank Data File",
    "MSN": "Host Blocking File",
    "MSO": "Inline E-mail Attachment",
    "MSP": "Microsoft Paint Bitmap Image",
    "MSPX": "Microsoft ASP.NET Web Page",
    "MSRCINCIDENT": "Windows Remote Assistance Invitation File",
    "MSS": "Microprocessor Software Specification File",
    "MSSTYLE": "Windows XP Unsigned Style",
    "MSSTYLES": "Windows XP Style",
    "MST": "Windows Installer Setup Transform File",
    "MSU": "Windows Vista Update Package",
    "MSV": "Memory Stick Voice File",
    "MSW": "Painter Color Mixer Swatches File",
    "MSWMM": "Windows Movie Maker Project",
    "MT2": "MadTracker 2 Module",
    "MT2S": "MPEG-2 Transport Stream File",
    "MTA": "Samsung AllShare Metadata File",
    "MTC": "Make the Cut! Project",
    "MTD": "Musicnotes Digital Sheet Music File",
    "MTE": "MadTracker 2 Envelope",
    "MTF": "Multi Tracker File",
    "MTH": "Derive Math File",
    "MTHD": "MOPEKS Method File",
    "MTI": "MadTracker Instrument",
    "MTL": "OBJ Material File",
    "MTM": "MultiTracker Module",
    "MTO": "FastCAM MTO Text File",
    "MTP": "MadTracker 2 Pattern",
    "MTS": "MadTracker 2 Sample File",
    "MTV": "MTV Video Format File",
    "MTW": "Minitab Worksheet File",
    "MTX": "MetaStream Scene File",
    "MTZ": "Compressed MetaStream Scene File",
    "MU": "Kerbal Space Program Mesh File",
    "MUD": "Mudbox 3D Scene File",
    "MUI": "Myriad User Instrument File",
    "MUI_CCCD5AE0": "Hid User Library",
    "MUL": "Ultima Online Multi File",
    "MUM": "Windows Vista Update Package",
    "MUS": "Finale Notation File ",
    "MUSE": "Adobe Muse Website Project",
    "MUSX": "Finale Notation File ",
    "MUX": "Trackmania Music File",
    "MV": "MivaScript File",
    "MVB": "Multimedia Viewer Book Source File",
    "MVC": "Movie Collector Catalog",
    "MVD": "Movie Edit Pro Movie File",
    "MVDX": "MindView Windows Document",
    "MVE": "Infinity Engine Movie File",
    "MVEX": "Muvee autoProducer 6 Project File",
    "MVG": "Magick Vector Graphics File",
    "MVI": "AutoCAD Movie Command File",
    "MVP": "MAGIX Video Project File",
    "MVR": "IBM HotMedia Multimedia File",
    "MVS": "Microchip Verification Specification File",
    "MVTX": "MindView Template",
    "MVY": "Video easy Project File",
    "MV_": "Movie Edit Pro Movie Backup File",
    "MW": "MacWrite Text Document",
    "MWB": "MySQL Workbench Document",
    "MWD": "Mariner Write Document",
    "MWF": "MapGuide Author Map Window File",
    "MWL": "XMS Print Layout File",
    "MWLIC": "MoneyWell License File",
    "MWP": "Lotus Word Pro SmartMaster File",
    "MWS": "Maple Classic Worksheet",
    "MWX": "MapGuide Author Map Window XML File",
    "MX3": "Mixcraft 3 Audio Project",
    "MX4": "Mixcraft 4 Audio Project",
    "MX5": "Mixcraft 5 Audio Project",
    "MX5TEMPLATE": "Mixcraft 5 Audio Project Template",
    "MXADDON": "Maxthon Add-On File",
    "MXD": "ArcGIS Map Document",
    "MXE": "Macro Express Playable Macro",
    "MXF": "Material Exchange Format File",
    "MXI": "Maxwell Image",
    "MXL": "Compressed MusicXML File",
    "MXM": "Maxwell Material File",
    "MXMF": "Mobile XMF Ringtone File",
    "MXML": "Flex MXML Component",
    "MXN": "Miinoto Exchangeable Note File",
    "MXP": "Adobe Extension Package",
    "MXS": "Maxwell Studio Scene File",
    "MXSKIN": "Maxthon Skin File",
    "MXT": "ArcGIS Map Template",
    "MXV": "MAGIX Video File",
    "MYAPP": "Visual Studio Application XML File",
    "MYCOLORS": "Stardock MyColors Theme File",
    "MYD": "MySQL Database Data File",
    "MYDOCS": "Send To My Documents",
    "MYI": "MySQL MyISAM Index File",
    "MYL": "MyLogo Maker Image",
    "MYNOTESBACKUP": "Keep My Notes Backup",
    "MYR": "Myriad Music File",
    "MYS": "Vineyard Captured Video File",
    "MZP": "MAXScript Zip Package",
    "MZZ": "Microsoft .NET Download Package",
    "N": "Neko Bytecode File",
    "N-GAGE": "N-Gage Application",
    "N2": "Nitrous Minecraft GLSL Shader File",
    "N3D": "Nuclear 3D File",
    "N3PMESH": "Knight Online 3D Mesh File",
    "N3R": "Panasonic Security System Video File",
    "N64": "Nintendo 64 Emulator ROM File",
    "NA2": "Netscape Address Book File",
    "NAP": "NAP Metafile",
    "NAR": "Nexon game archive",
    "NARC": "Nintendo DS Archive File",
    "NARRATIVE": "Narrator Document",
    "NAV2": "WinAVI Temporary Navigation File",
    "NB": "Nota Bene File",
    "NB0": "Device Boot Loader Image",
    "NB7": "NovaBACKUP Output File",
    "NBA": "Nero BackItUp Archive",
    "NBAK": "Neat Backup File",
    "NBC": "Next Byte Codes Source Code File",
    "NBD": "NovaBACKUP File",
    "NBF": "Nokia Backup File",
    "NBH": "ROM Update Utility Image File",
    "NBI": "Nero BackItUp Information File",
    "NBK": "NovaBACKUP Job File",
    "NBM": "NetBeans Module",
    "NBP": "Mathematica Player Notebook File",
    "NBS": "Minecraft Note Block Studio File",
    "NBU": "Nokia Phone Backup File",
    "NC": "Mastercam Numerical Control File",
    "NC1": "Mastercam Numerical Control File",
    "NCA": "Nintendo Content Archive",
    "NCB": "Visual C++ IntelliSense Database",
    "NCD": "Nero CoverDesigner File",
    "NCF": "No Cache File",
    "NCFG": "ArcGIS Explorer Configuration File",
    "NCL": "NirCmd Script File",
    "NCO": "Nero BackItUp File",
    "NCOR": "Adobe Encore Project File",
    "NCORX": "Adobe Encore Project",
    "NCR": "NCR Image",
    "NCSS": "NCSS Dataset File",
    "NCT": "Nero CoverDesigner Template",
    "NCW": "Native Compressed Wave File",
    "NCX": "EPUB Navigation Control XML File",
    "ND": "QuickBooks Network Data File",
    "NDA": "Nero Backup File",
    "NDC": "Personal Communications Settings File",
    "NDF": "SQL Server Secondary Database File",
    "NDIF": "Apple New Disk Image Format File",
    "NDK": "Lotus Notes Design Elements File",
    "NDL": "Lotus Notes Doclink File",
    "NDOC": "Naver Word ",
    "NDS": "Nintendo DS Game ROM",
    "NDX": "dBASE Index File",
    "NED": "OMNeT++ Network Description File",
    "NEF": "Nikon Electronic Format RAW Image",
    "NEKO": "Neko Source Code File",
    "NEO": "NeoChrome Bitmap Image",
    "NES": "Nintendo (NES) ROM File",
    "NET": "netViz Project File",
    "NETWORKCONNECT": "Apple Network Connect Document",
    "NEU": "Pro/ENGINEER Neutral File",
    "NEX": "Navigator Extension",
    "NEXE": "Chrome Native Client Executable",
    "NFB": "Nokia Phone Backup File",
    "NFC": "Nokia Phone Backup Copy File",
    "NFF": "Neutral File Format",
    "NFI": "Dreambox Disc Image",
    "NFM": "Delphi .NET Form File",
    "NFO": "Warez Information File",
    "NFS": "Network File System Temporary File",
    "NFTR": "Nintendo DS Font Type File",
    "NFV": "Netflix Video File",
    "NGAGE": "N-Gage Game File",
    "NGC": "Xilinx Generated Netlist File",
    "NGD": "Xilinx Netlist File",
    "NGLOSS": "Nisus Writer Glossary",
    "NGP": "NeoGeo Pocket ROM",
    "NGRR": "Guitar Rig Preset",
    "NGT": "Noni GPSPlot Track File",
    "NIB": "Interface Builder User Interface File",
    "NICK": "Outlook 2000 Nickname File",
    "NIF": "Gamebryo Model File",
    "NITF": "National Imagery Transmission Format File",
    "NJB": "Nikon Photo Index File",
    "NJI": "Nero Job Information File ",
    "NJX": "NJStar Document",
    "NK": "NUKE Script",
    "NK2": "Outlook 2002 Nickname File",
    "NKB": "Kontakt Audio Bank",
    "NKC": "Kontakt Library Data File",
    "NKI": "KONTAKT Instrument File",
    "NKM": "Kontakt Multi Instrument File",
    "NKP": "Kontakt Presets File",
    "NKS": "Kontakt Monolith Container",
    "NKX": "Kontakt Monolith Container File",
    "NL2SCRIPT": "NoLimits 2 Script File",
    "NLM": "Nokia Logo File",
    "NLS": "Microsoft National Language Support File",
    "NLTRACK": "NoLimits Roller Coaster Track File",
    "NM": "Space Engine Nebula Model File",
    "NM2": "Navitel Map File",
    "NM3": "Navitel 5 Map File",
    "NMAP": "NaviComputer Map File",
    "NMBTEMPLATE": "Numbers Spreadsheet Template",
    "NMC": "ArcGIS Explorer Map Content File",
    "NMF": "ArcGIS Explorer Map File",
    "NML": "Traktor Collection File",
    "NMSV": "Native Instruments Massive Sound File",
    "NN": "Nero CD File List",
    "NNT": "Eudora Address Book File",
    "NOD": "NetObjects Fusion File",
    "NOL": "Nokia Operator Logo File",
    "NOMEDIA": "Android No Media File",
    "NOT": "Notation File",
    "NOTE": "Notability Note File",
    "NOTEBOOK": "SMART Notebook File",
    "NOTES": "Memento Notes File",
    "NOW": "Readme File",
    "NOY": "NOY Backup File",
    "NP": "Portfolio NetPublish File",
    "NP4": "NetPoint 4 Schedule File",
    "NPA": "Steins;Gate Archive",
    "NPF": "NTI Partition File",
    "NPFX": "Norton Internet Security Firewall Settings File",
    "NPK": "MikroTik Software Package",
    "NPL": "Nokia Playlist File",
    "NPP": "Art Explosion Publisher Pro Document",
    "NPS": "Natron Node Presets File",
    "NPT": "Portfolio NetPublish Template",
    "NQC": "Not Quite C Source Code File",
    "NRA": "Nero Audio Compilation",
    "NRBAK": "NeatReceipts Backup File",
    "NRG": "Nero CD/DVD Image File",
    "NRI": "Nero ISO CD Compilation File",
    "NRL": "Autonomy Interwoven Link File",
    "NRMLIB": "Neat Cabinet File",
    "NRO": "Nintendo Switch Executable File",
    "NRS": "NovaBACKUP Restore Script",
    "NRT": "Nokia Ringtone",
    "NRW": "Nikon Raw Image File",
    "NS1": "Nestopia Save State",
    "NS2": "Lotus Notes 2 Database",
    "NS3": "Lotus Notes 3 Database",
    "NS4": "Lotus Notes 4 Database",
    "NSA": "Nullsoft Streaming Audio File",
    "NSBCA": "Nintendo DS Model Animation File",
    "NSBMD": "Nintendo DS Model File",
    "NSBTA": "Nintendo DS Texture Animation File",
    "NSBTX": "Nintendo DS Model Texture File",
    "NSF": "Lotus Notes Database",
    "NSH": "NSIS Header File",
    "NSI": "NSIS Script",
    "NSS": "Magentic Screensaver File",
    "NSV": "Nullsoft Streaming Video File",
    "NSX": "AppStudio Project",
    "NT": "Windows NT Startup File",
    "NTF": "MediaFACE II CD Label File",
    "NTFS": "NTFS Partition File",
    "NTH": "Nokia Series 40 Theme File",
    "NTN": "NOTION Song File",
    "NTP": "Natron Project File",
    "NTRK": "Pacific FIghters Online Track File",
    "NUD": "Now Up-To-Date Calendar File",
    "NULL": "Null Ransomware Encrypted File",
    "NUMBERS": "Numbers Spreadsheet File",
    "NUMBERS-TEF": "Numbers iCloud Document",
    "NUP": "Smart Security Update File",
    "NUPKG": "NuGet Package",
    "NUSPEC": "NuGet Specification File",
    "NUT": "NUT Video File",
    "NUV": "NuppelVideo File",
    "NV": "NewViews Database File",
    "NV2": "NewViews 2 Database File",
    "NVA": "NVA Document",
    "NVC": "NeroVision Express Project File",
    "NVF": "Creative Labs NVF Audio File",
    "NVI": "NVIDIA Driver File",
    "NVP": "NVivo for Windows Project",
    "NVV": "NVIDIA Vertex Shader File",
    "NW": "Node-Webkit App Package",
    "NWBAK": "NeatWorks Backup File",
    "NWC": "NoteWorthy Composer File",
    "NWCTXT": "NoteWorthy Composer Text File",
    "NWD": "Navisworks Document",
    "NWDB": "Neat Database File",
    "NWF": "Navisworks File Set",
    "NWM": "Nisus Macro",
    "NWP": "Now Contact WP Document",
    "NWV": "Dragon NaturallySpeaking User Archive",
    "NXC": "Not eXactly C Source Code File",
    "NXG": "eSite Builder NXG Web Page",
    "NXL": "Nextlabs Encrypted Data File",
    "NY": "Audacity Nyquist Plug-in",
    "NYF": "myBase Database File",
    "NZ": "NanoZip Compressed File",
    "NZB": "NewzBin Usenet Index File",
    "O": "Compiled Object File",
    "OAM": "Adobe Edge Animate Widget File",
    "OAR": "OpenSimulator Archive",
    "OB!": "Orbit Downloader Incomplete Download",
    "OBF": "OsmAnd Offline Map File",
    "OBI": "Outlook RSS Subscription File",
    "OBJ": "Wavefront 3D Object File",
    "OBK": "Backup File",
    "OBML": "Opera Mini Saved Web Page",
    "OBML15": "Opera Mini Saved Web Page",
    "OBML16": "Opera Mini Saved Web Page",
    "OBP": "Bryce Object File",
    "OBT": "Openbox Theme File",
    "OBW": "Superior Drummer Sounds File",
    "OBZ": "Compressed 3D Object File",
    "OC3": "openCanvas 3 Event File",
    "OC4": "openCanvas 4 Event File",
    "OC5": "openCanvas 5 Event File",
    "OCA": "Custom Control Library Type File",
    "OCD": "OCAD Map File",
    "OCI": "openCanvas Image",
    "OCR": "FAXGrapper Fax Text File",
    "OCT": "Radiance Octree File",
    "OCTEST": "Xcode Objective-C Unit Test Bundle",
    "OCX": "ActiveX Control",
    "ODB": "OpenDocument Database",
    "ODC": "Office Data Connection File",
    "ODEX": "Optimized Dalvik Executable",
    "ODF": "OpenDocument Formula",
    "ODG": "OpenDocument Graphic File",
    "ODI": "OpenDocument Image",
    "ODIF": "Open Document Interchange Format",
    "ODIN": "Locky Ransomware Encrypted File",
    "ODL": "Object Description Language File",
    "ODM": "OpenDocument Master Document",
    "ODO": "Online Operating System Write Document",
    "ODP": "OpenDocument Presentation",
    "ODS": "OpenDocument Spreadsheet",
    "ODT": "OpenDocument Text Document",
    "ODTTF": "Obfuscated OpenType Font",
    "ODX": "BizTalk Server Orchestration File",
    "OEACCOUNT": "Windows Mail Account File",
    "OEB": "Open eBook File",
    "OEBZIP": "Zipped Open eBook File",
    "OEM": "OEM Setup File",
    "OEX": "Opera Extension",
    "OFC": "Open Financial Connectivity File",
    "OFF": "Object File Format",
    "OFFICEUI": "Microsoft Office UI Customization File",
    "OFL": "Ots File List",
    "OFR": "OptimFROG Audio File",
    "OFT": "Outlook File Template",
    "OFX": "Open Financial Exchange File",
    "OGA": "Ogg Vorbis Audio File",
    "OGF": "S.T.A.L.K.E.R. Model File",
    "OGG": "Ogg Vorbis Audio File",
    "OGM": "Ogg Media File",
    "OGNC": "Dynamic Web Page",
    "OGV": "Ogg Video File",
    "OGW": "Origin Workbook File",
    "OGWU": "Origin Unicode Workbook File",
    "OGX": "Ogg Vorbis Multiplexed Media File",
    "OIV": "OpenIV Mod Package File",
    "OKT": "Oktalyzer Module",
    "OL": "Valve Hammer Object Layout File",
    "OLA": "Online Access File",
    "OLB": "OrCAD Symbol Library File",
    "OLD": "Backup File",
    "OLP": "Office Live Package",
    "OMA": "Sony OpenMG Music File",
    "OMF": "Open Media Framework File",
    "OMG": "OpenMG Audio File",
    "OMO": "OMake Object File",
    "OMOD": "Oblivion Mod Archive",
    "OMP": "Office Manager Document Archive",
    "OMS": "HP Printer Substrate Presets Package File",
    "OMX": "OtsAV Media Library Information File",
    "OND": "Lotus Notes Encapsulated Memo File",
    "ONE": "OneNote Document",
    "ONEPKG": "Microsoft OneNote Package File",
    "ONETOC2": "Microsoft OneNote Table of Contents File",
    "OO3": "OmniOutliner 3 File",
    "OO3TEMPLATE": "OmniOutliner Template",
    "OPD": "OmniPage Document",
    "OPDOWNLOAD": "Opera Partially Downloaded File",
    "OPEICO": "Opeico Text File",
    "OPENBSD": "OpenBSD Readme File",
    "OPF": "Open Packaging Format File",
    "OPJ": "OrCAD Project File",
    "OPJU": "Origin Unicode Project",
    "OPK": "GCW Zero Open Package",
    "OPLC": "Nokia Operator Logo File",
    "OPML": "Outline Processor Markup Language File",
    "OPS": "Office Profile Settings File",
    "OPT": "Opterecenja File",
    "OPUS": "Opus Audio File",
    "OPX": "OrgPlus Org Chart",
    "OQY": "Excel OLAP Query File",
    "ORA": "OpenRaster Image File",
    "ORB": "Original eBook Reader File",
    "ORE": "Ore Executable File",
    "ORF": "Olympus RAW File",
    "ORI": "Original File",
    "ORIG": "Original File",
    "ORT": "Rich Text Editor Document",
    "ORV": "Oracom Video File",
    "ORX": "RadiantOne VDS Database Schema",
    "OSAX": "AppleScript Scripting Addition",
    "OSB": "OpenStreetMap Binary Map File",
    "OSC": "OpenStreetMap Change File",
    "OSDX": "Search Connector Description File",
    "OSK": "Osu! Skin File",
    "OSM": "OpenStreetMap Map File",
    "OSP": "OpenShot Project File",
    "OSR": "Osu! Replay File",
    "OSS": "Microsoft Outlook Saved Search File",
    "OST": "Outlook Offline Data File",
    "OSX": "PowerPC Executable File",
    "OSZ": "Osu! Beatmap File",
    "OTA": "OTA Bitmap Image",
    "OTB": "Nokia Over The Air Bitmap Image",
    "OTC": "OpenDocument Chart Template",
    "OTF": "OpenType Font",
    "OTG": "OpenDocument Graphic Template",
    "OTH": "OpenDocument HTML Template",
    "OTI": "OpenDocument Image Template",
    "OTLN": "Opal Outline File",
    "OTM": "Outlook Macro File",
    "OTP": "OpenDocument Presentation Template",
    "OTPU": "Origin Unicode Graph Template",
    "OTRKEY": "OnlineTvRecorder Encoded Video File",
    "OTS": "OtsAV Album File",
    "OTT": "OpenDocument Document Template",
    "OTZ": "OpenLP Theme File",
    "OUT": "Output File",
    "OV2": "TomTom Points of Interest Database",
    "OVA": "Open Virtual Appliance",
    "OVE": "Overture Musical Score",
    "OVF": "Open Virtualization File",
    "OVH": "OMSI Vehicle Configuration File",
    "OVP": "The Overlay Maker Package File",
    "OVPN": "OpenVPN Configuration File",
    "OVR": "The Overlay Maker Overlay File",
    "OVW": "Logic Pro Overview File",
    "OWC": "OutWit Catch Database",
    "OWL": "OWL Source Code File",
    "OXPS": "OpenXPS File",
    "OXT": "Apache OpenOffice Extension",
    "OYX": "Approach Alternate Database Index",
    "OZ": "Opera Job Management Compressed File",
    "OZB": "MU Online Image File",
    "OZJ": "MU Online Image File",
    "OZT": "MU Online Image File",
    "P": "LightWave Plug-in",
    "P01": "Parchive Recovery Volume",
    "P10": "Certificate Request File",
    "P12": "Personal Information Exchange File",
    "P19": "Parchive Recovery Volume",
    "P21": "Express STEP Data Model File",
    "P2G": "Power2Go Project File",
    "P2I": "Power2Go Disc Image",
    "P2M": "PhotoWorks Appearance File",
    "P2P": "FolderShare Placeholder File",
    "P2Z": "Compressed Poser Pose File",
    "P3D": "Peak3D 3D Graphics File",
    "P3L": "Adobe Photoshop Light Preset File",
    "P3M": "Adobe Photoshop Material Preset File",
    "P3R": "Adobe Photoshop Render Settings Preset File",
    "P3T": "PlayStation 3 Theme File",
    "P4D": "Pix4D Project",
    "P5D": "Planner 5D Project",
    "P64": "64-bit Windows IDA Plugin Module",
    "P65": "PageMaker 6.5 Document",
    "P7": "PKCS #7 Digital Certificate File",
    "P7B": "PKCS #7 Certificate File",
    "P7C": "PKCS #7 Certificate File",
    "P7M": "Digitally Encrypted Message",
    "P7R": "Certificate Request Response File",
    "P7S": "Digitally Signed Email Message",
    "P7Z": "S/MIME Compressed Email Message",
    "P96": "Win96 Database File",
    "P97": "Win97 Database File",
    "PA": "Print Artist Project",
    "PAC": "SBStudio II Song File",
    "PACK": "Pack200 Packed Jar File",
    "PACK.GZ": "Pack200 Compressed Archive",
    "PACKAGE": "Electronic Arts Game Package File",
    "PAD": "ACT! Database Pointer File",
    "PAE": "PowerArchiver Encrypted Archive",
    "PAF": "Personal Ancestral File",
    "PAF.EXE": "PortableApps.com Program File",
    "PAGE": "HybridJava Web Page",
    "PAGES": "Pages Document",
    "PAGES-TEF": "Pages iCloud Document",
    "PAK": "Video Game Package",
    "PAL": "Dr. Halo Color Palette File",
    "PAMP": "Poweramp Album Art File",
    "PAN": "Panorama Database File",
    "PANDO": "Pando File",
    "PANDORA": "Pandora Android App Executable",
    "PANIC": "Kernel Panic File",
    "PANO": "Camera Panoramic Picture",
    "PAP": "PanoramaStudio Project File",
    "PAPA": "Game Save Backup File",
    "PAPERS": "Painter Paper Texture File",
    "PAQ": "Hewlett-Packard Software Restore File",
    "PAQ6": "PAQ6 Data Archive",
    "PAQ7": "PAQ7 Data Archive",
    "PAQ8": "PAQ8 Data Archive",
    "PAQ8F": "PAQ8F Compressed Archive",
    "PAQ8L": "PAQ8L Data Archive",
    "PAQ8P": "PAQ8P Data Archive",
    "PAR": "Dedicated Micros DVR Recording",
    "PAR2": "Parchive 2 Index File",
    "PART": "Partially Downloaded File",
    "PARTIAL": "Internet Explorer Partially Downloaded File",
    "PARTIMG": "Partimage File",
    "PAS": "Pascal Source File",
    "PAT": "3D Patch File",
    "PATCH": "Patch File",
    "PAX": "PAX Archive",
    "PB": "PureBasic Source File",
    "PBA": "OpenOffice.org Basic Protected Module File",
    "PBB": "AT&T Phonebook File",
    "PBD": "EaseUS Todo Backup File",
    "PBF": "Pinnacle Sample Bank",
    "PBG": "Pixel Bender Graph File",
    "PBI": "PC BSD Installer Package",
    "PBJ": "Pixel Bender Bytecode File",
    "PBK": "Pixel Bender Kernel File",
    "PBM": "Portable Bitmap Image",
    "PBN": "Portable Bridge Notation File",
    "PBP": "PSP Firmware Update File",
    "PBX5SCRIPT": "Personal Backup Script",
    "PBXBTREE": "Xcode Auto-Complete File",
    "PBXPROJ": "Xcode Project Data File",
    "PBXSCRIPT": "Personal Backup Script",
    "PBXUSER": "Xcode Project User Data File",
    "PC1": "Degas Elite Low Res Image File",
    "PC2": "Degas Elite Medium Res Image File",
    "PC3": "Degas Elite High Res Image File",
    "PC6": "PowerCADD 6 Drawing File",
    "PC7": "PowerCADD 7 Drawing File",
    "PCA": "Perfect Clarity Audio File",
    "PCAPNG": "Pcap-NG Packet Capture File",
    "PCAST": "iTunes Podcast File",
    "PCB": "Printed Circuit Board Design File",
    "PCC": "Mass Effect Package",
    "PCD": "Kodak Photo CD Image File",
    "PCF": "PaintCAD Font",
    "PCG": "Korg Instrument Bank File",
    "PCH": "Precompiled Header File",
    "PCK": "Perfect World Data File",
    "PCL": "Printer Command Language Document",
    "PCP": "Windows Installer Patch Creation Properties File",
    "PCR": "PCMark Vantage Benchmark File",
    "PCS": "Microsoft Office ClipArt File",
    "PCSAV": "Mass Effect 2 Saved Game",
    "PCT": "Picture File",
    "PCTL": "Kaspersky Parental Control Settings File",
    "PCV": "MozBackup Profile Backup",
    "PCX": "Paintbrush Bitmap Image File",
    "PD": "FlexiSIGN 5 Plotter Document",
    "PD4": "Windows Live Photo Gallery Information File",
    "PD5": "Windows Live Photo Gallery Information File",
    "PDADJ": "PhotoDirector Preset File",
    "PDAS": "PDAStore Data Store File",
    "PDB": "Program Database",
    "PDC": "Lizard Safeguard Secure PDF File",
    "PDD": "Adobe PhotoDeluxe Image",
    "PDE": "ProntoDoc for Excel Document Template",
    "PDER": "ProntoDoc for Excel Conventional Document",
    "PDEX": "Orient Computer Encrypted Data File",
    "PDF": "Portable Document Format File",
    "PDF-1": "Renamed PDF File",
    "PDFXML": "Adobe PDFXML Document",
    "PDG": "Print Shop Deluxe Design File",
    "PDH": "ProntoDoc for Word Browser Display Document Template",
    "PDI": "InstantCopy Disc Image",
    "PDM": "ProntoDoc for Word Mobile Display Document Template",
    "PDN": "paint.net Image File",
    "PDP": "Adobe Portable Document Format File",
    "PDPCMD": "Pdplayer Command File",
    "PDPCOMP": "Pdplayer Composition File",
    "PDR": "ProntoDoc for Word Recovered Document",
    "PDS": "Planetary Data System File",
    "PDW": "ProntoDoc for Word Conventional Document Template",
    "PDWR": "ProntoDoc for Word Conventional Document",
    "PDX": "Adobe Acrobat Index File",
    "PDZ": "ProntoDoc for Word Structured Text Document Template",
    "PE4": "Photo Explorer Thumbnail Archive",
    "PEA": "PEA File Archive",
    "PEAK": "Steinberg Peak File",
    "PEF": "PEF Braille Book File",
    "PEGN": "Peggle Nights Replay File",
    "PEK": "Adobe Peak Waveform File",
    "PEKEY": "PhysicsEditor License Key File",
    "PEM": "Privacy Enhanced Mail Certificate",
    "PEN": "Logitech io2 Drawing",
    "PERFMONCFG": "Performance Monitor Configuration File",
    "PES": "Brother Embroidery Format",
    "PET": "Puppy Linux Install Package",
    "PEX": "West Publisher Portable Exhibit File",
    "PF": "Private File",
    "PFA": "Printer Font ASCII File",
    "PFB": "Printer Font Binary File",
    "PFC": "AOL Personal File Cabinet",
    "PFD": "Micrografx Optima! File",
    "PFF": "Formatta Portable Form File",
    "PFI": "PhotoFiltre Studio Image",
    "PFILE": "Rights Management Protected File",
    "PFL": "PDFill Project File",
    "PFM": "Printer Font Metrics File",
    "PFO": "Private Folder",
    "PFR": "Paint Shop Pro Picture Frame File",
    "PFV": "PhotoFiltre Studio Vectorial Path",
    "PFX": "First Choice Word Processing Document",
    "PGAL": "Photo! 3D Album Gallery",
    "PGD": "PGP Disk Image",
    "PGF": "Progressive Graphics File",
    "PGI": "Video Recording File",
    "PGM": "Portable Gray Map Image",
    "PGN": "Portable Game Notation File",
    "PGP": "AutoCAD Program Parameters File",
    "PGS": "PageStream Document",
    "PGX": "Hopedot VOS Data File",
    "PH": "Perl Header File",
    "PHAR": "PHP Archive",
    "PHB": "Motorola Phone Book File",
    "PHJ": "PhCNC Project File",
    "PHL": "Kindle Popular Highlights File",
    "PHM": "Pro Home Manager Data File",
    "PHN": "Algodoo Phun Phunlet",
    "PHO": "MBROLA Phonetic Data File",
    "PHOTOSHOW": "Roxio PhotoShow Project",
    "PHOTOSLIBRARY": "Photos Library",
    "PHP": "PHP Source Code File",
    "PHP2": "PHP 2 Web Page",
    "PHP3": "PHP 3 Web Page",
    "PHP4": "PHP 4 Web Page",
    "PHP5": "PHP 5 Web Page",
    "PHTM": "PHP-Based Web Page",
    "PHTML": "PHP Web Page",
    "PHY": "PhyMod Physical Modeling Data",
    "PI1": "Degas Low Resolution Image File",
    "PI2": "Portrait Innovations Photo",
    "PI3": "Degas High Resolution Image File",
    "PI4": "DEGAS Image",
    "PI5": "DEGAS Bitmap Image",
    "PI6": "DEGAS Bitmap Image File",
    "PIC": "Generic Picture File",
    "PICNC": "Houdini 3D Compositing Image",
    "PICT": "Picture File",
    "PICTCLIPPING": "Picture Clipping File",
    "PID": "Creative Driver File",
    "PIE": "GlovePIE Controller Script",
    "PIF": "Program Information File",
    "PIGM": "Packaged Indigo Renderer Material File",
    "PIGS": "Packaged Indigo Renderer Scene File",
    "PIKA": "Pika Software Builder Project File",
    "PIM": "Pro Tools Controller Plug-in Mappings File",
    "PIN": "MNS Projection Information File",
    "PIO": "Pro Tools I/O Settings File",
    "PIP": "Office Personalized Settings File",
    "PIPD": "PIPE-FLO Demo Project File",
    "PIPE": "PIPE-FLO Project File",
    "PISKEL": "Piskel Sprite",
    "PIT": "Samsung Phone Firmware File",
    "PIV": "Pivot Stickfigure Animation",
    "PIX": "BRL-CAD Raw Image File",
    "PIXADEX": "Pixadex Icon",
    "PIXELA": "Pixela Project",
    "PIZ": "Zipped File",
    "PJ": "Project64 Saved State File",
    "PJ2": "xPlan Document",
    "PJM": "xPlan Model",
    "PJPEG": "Progressive JPEG Image",
    "PJPG": "Progressive JPEG Image",
    "PJS": "Phoenix Subtitles File",
    "PJX": "FoxPro Project",
    "PK": "Audition Peak File",
    "PK2": "Silkroad Online Game Data File",
    "PK3": "Quake 3 Engine Game Data File",
    "PK4": "Doom 3 Engine Game Data File",
    "PKA": "Packet Tracer Activity File",
    "PKB": "Oracle Package Body File",
    "PKEY": "PowerKey Encrypted File",
    "PKF": "Audition Peak File",
    "PKG": "Mac OS X Installer Package",
    "PKG.TAR.XZ": "Arch Linux Package File",
    "PKGDEF": "Visual Studio Shell File",
    "PKGUNDEF": "Visual Studio Shell File",
    "PKH": "Oracle Package File",
    "PKPASS": "Passbook Pass File",
    "PKS": "Oracle Package Spec File",
    "PKT": "Packet Tracer Network Simulation Model",
    "PKX": "Decrypted 3DS Pok\u00e9mon Save File",
    "PL": "Perl Script",
    "PL0": "3D Home Architect Foundation Floor Plan",
    "PL1": "3D Home Architect Floor Plan",
    "PL2": "3D Home Architect Second Level Floor Plan",
    "PLA": "Sansa Playlist File",
    "PLAIN": "Plain Text File",
    "PLANTUML": "PlantUML File",
    "PLAYER": "Terraria Mobile Player File",
    "PLAYGROUND": "Xcode Playground File",
    "PLAYLIST": "CyberLink PowerDVD Playlist",
    "PLAYMISSION": "MissionPlayer Game File",
    "PLC": "PL/B Source File",
    "PLE": "Messenger Plus! Live Encrypted Log File",
    "PLF": "Papyrus License File",
    "PLG": "Sibelius Plug-in",
    "PLI": "PL/I Source Code File",
    "PLIST": "Mac OS X Property List File",
    "PLN": "Flight Simulator Flight Plan",
    "PLP": "Photo Locker Picture",
    "PLPROJ": "Adobe Prelude Project File",
    "PLR": "Terraria Player File",
    "PLS": "Multimedia Playlist File",
    "PLSC": "Messenger Plus! Live Script File",
    "PLSK": "Messenger Plus! Live Skin Pack",
    "PLT": "AutoCAD Plotter Document",
    "PLUGIN": "Mac OS X Plugin",
    "PLW": "PicoLog Data File",
    "PLX": "Perl Executable File",
    "PLX64": "64-bit Linux IDA Plugin Module",
    "PLY": "Finale Playback File",
    "PM": "Unix XV Graphic File",
    "PM3": "PageMaker 3 Document",
    "PM4": "PageMaker 4 Document",
    "PM5": "PageMaker 5.0 Document",
    "PM6": "PageMaker 6.0 Document",
    "PMC": "Performance Monitor Counter File",
    "PMD": "MikuMikuDance Model File",
    "PMDX": "PlanMaker Spreadsheet",
    "PMF": "PSP Movie File",
    "PMG": "Adobe Photoshop Photomerge Panoramic Composition File",
    "PMJ": "Pegasus Mail Configuration File",
    "PML": "Palm Markup Language File",
    "PMLZ": "Zipped Palm Markup Language File",
    "PMO": "Pegasus Saved Message File",
    "PMP": "AutoCAD Plot Model Parameter File",
    "PMT": "PageMaker Template File",
    "PMV": "Return to Zork Video File",
    "PMVX": "PlanMaker Spreadsheet Template",
    "PMX": "MikuMikuDance Model File",
    "PN": "Powernoodle File (Discontinued)",
    "PNA": "PhatNoise Audio File",
    "PNC": "Panasonic Network Camera Image",
    "PNF": "Precompiled INF File",
    "PNG": "Portable Network Graphic",
    "PNH": "Project ROME Plug-in Archive",
    "PNI": "Popnoggin Image File",
    "PNM": "Portable Any Map Image",
    "PNO": "Windows 8 Piano Song",
    "PNS": "Pelco CCTV Video File",
    "PNT": "MacPaint File",
    "PNTG": "MacPaint Graphic File",
    "PNZ": "Panorama Database Set",
    "PO": "Portable Object",
    "POBI": "Kindle Touch Periodical File",
    "POBJ": "Photo Pos Pro Vector Object File",
    "POD": "OpenProj Project File",
    "POI": "Magellan Maestro Point of Interest File",
    "POL": "Windows Policy File",
    "POLICY": "Java Policy Implementation File",
    "POP": "Samsung Popcon Character File",
    "POT": "Portable Object File",
    "POTM": "PowerPoint Open XML Macro-Enabled Presentation Template",
    "POTX": "PowerPoint Open XML Presentation Template",
    "POV": "POV-Ray Raytracing Format",
    "PP2": "Poser Prop File",
    "PP4": "Picture Publisher Bitmap File",
    "PP5": "Picture Publisher 5 Image File",
    "PPA": "PowerPoint Add-in",
    "PPAM": "PowerPoint 2007 Add-In",
    "PPC": "Adobe Presenter Audio File",
    "PPCX": "Adobe Presenter Presentation Audio File",
    "PPD": "PostScript Printer Description File",
    "PPDF": "Rights Management Protected File",
    "PPF": "Edgecam Pathtrace Part File",
    "PPJ": "Premiere 6 Project File",
    "PPK": "PuTTY Private Key File",
    "PPM": "Portable Pixmap Image File",
    "PPMOD": "Papers Please Mod File",
    "PPP": "Serif PagePlus Document",
    "PPS": "PowerPoint Slide Show",
    "PPSM": "PowerPoint Open XML Macro-Enabled Slide Show",
    "PPSX": "PowerPoint Open XML Slide Show",
    "PPT": "PowerPoint Presentation",
    "PPTHTML": "PowerPoint HTML Presentation",
    "PPTM": "PowerPoint Open XML Macro-Enabled Presentation",
    "PPTMHTML": "Microsoft PowerPoint MIME HTML Presentation",
    "PPTX": "PowerPoint Open XML Presentation",
    "PPX": "Serif PagePlus Template File",
    "PPZ": "Compressed Poser Prop File",
    "PQB": "Pleco Chinese Dictionary Backup File",
    "PQB-BACKUP": "Pleco Chinese Dictionary Backup File",
    "PQHERO": "Puzzle Quest Saved Game",
    "PQI": "PowerQuest Drive Image",
    "PR": "Source Insight Project",
    "PRC": "Mobipocket eBook File",
    "PRDX": "Presentations Document",
    "PREF": "Preferences File",
    "PREFAB": "Unity Prefab File",
    "PREFPANE": "Mac OS X System Preference Pane",
    "PREL": "Premiere Elements Project File",
    "PRF": "Outlook Profile File",
    "PRFPSET": "Premiere Pro Effect Preset File",
    "PRG": "WAVmaker Patch File",
    "PRI": "Qt Project Include File",
    "PRIMITIVES": "World of Tanks 3D Model File",
    "PRIMITIVES_PROCESSED": "World of Tanks 3D Model File",
    "PRINTEREXPORT": "Windows Printer Migration File",
    "PRJ": "Project File",
    "PRK": "Thrillville Park File",
    "PRM": "Re-Volt Model File",
    "PRN": "Printable File",
    "PRO": "ProPresenter Export File",
    "PRO4DVD": "ProPresenter DVD Clips Document",
    "PRO5DVD": "ProPresenter DVD Clips Document",
    "PRO5PLX": "ProPresenter 5 Playlist Bundle",
    "PRO5TEMPLATE": "ProPresenter 5 Template",
    "PROFILE": "Bash Shell Profile",
    "PROFIMAIL": "ProfiMail Settings File",
    "PROP": "Android Build Properties File",
    "PROPDESC": "Property Description",
    "PROPERTIES": "Java Properties File",
    "PROPS": "Visual Studio Project Property File",
    "PROQC": "ProPresenter Quartz Composition",
    "PROTO": "Protocol Buffer File",
    "PROVISIONPROFILE": "Apple Provision Profile",
    "PRPROJ": "Premiere Pro Project",
    "PRS": "Harvard Graphics Presentation",
    "PRT": "Printer Output File",
    "PRTL": "Premiere Pro Title File",
    "PRV": "Vue Preview File",
    "PRW": "Artlantis Shader Preview File",
    "PRX": "Windows Media Profile File",
    "PS": "PostScript File",
    "PS1": "Windows PowerShell Cmdlet File",
    "PS1XML": "Windows PowerShell Display Configuration File",
    "PS2": "Microsoft Search Catalog Index File",
    "PSA": "Unreal Engine Skeletal Animation File",
    "PSAR": "PSP Update File",
    "PSB": "PowerDivX Subtitles File",
    "PSC": "Papyrus Script",
    "PSC1": "Windows PowerShell Console File",
    "PSD": "Adobe Photoshop Document",
    "PSDC": "Adobe Photoshop Cloud Document",
    "PSDX": "Photoshop Touch Document",
    "PSE": "Photoshop Elements Photo Project",
    "PSET": "Adobe InDesign Plug-in Set File",
    "PSF": "Portable Sound File",
    "PSF1": "PlayStation Sound Format File",
    "PSF2": "PlayStation Sound Format File",
    "PSG": "Page Segment File",
    "PSH": "Photodex Slide Show",
    "PSI": "PrimalScript Online Help Shortcut",
    "PSID": "PostScript Image Data File",
    "PSK": "Unreal Engine Skeletal Mesh File",
    "PSM": "Protracker Studio Module",
    "PSM1": "Windows PowerShell Script Module File",
    "PSP": "PaintShop Pro Image File",
    "PSPBRUSH": "PaintShop Pro Brush File",
    "PSPIMAGE": "PaintShop Pro Image",
    "PSPROJ": "The Print Shop Project File",
    "PSR": "Powersoft Report File",
    "PSS": "PlayStation 2 Game Video File",
    "PSSD": "PhotoSuite Slide Show File",
    "PSSG": "EGO Engine Textures File",
    "PST": "Outlook Personal Information Store File",
    "PSU": "PSU Designer Document",
    "PSV": "Pluralsight Video File",
    "PSW": "Pocket Word Document",
    "PSW6": "Password Depot 6 File",
    "PSY": "Psycle Song File",
    "PSZ": "Compressed PostScript File",
    "PTB": "Power Tab File",
    "PTCOP": "PxTone Audio File",
    "PTEX": "Ptex Texture File",
    "PTF": "Scrapbook Flair Template",
    "PTG": "ArtRage Painting",
    "PTH": "4D Path Document",
    "PTK": "Puntotek Embroidery Design File",
    "PTL": "Rational Rose Petal File",
    "PTM": "PolyTracker Module",
    "PTN": "PaperPort Thumbnail File",
    "PTR": "Flash Intro Project File",
    "PTS": "Pro Tools Session",
    "PTT": "Pro Tools Session Template",
    "PTW": "AutoCAD Publish To Web File",
    "PTX": "Pro Tools Session File",
    "PTXT": "Pro Tools Session Template",
    "PTZ": "E-Transcript Bundle File",
    "PU": "PlantUML File",
    "PUB": "Publisher Document",
    "PUBLICATION": "Twixl Publisher Publication",
    "PUP": "PlayStation 3 Update File",
    "PUPPET": "Adobe Character Animator Puppet File",
    "PUZ": "Across Lite Crossword Puzzle",
    "PVA": "PVA Video File",
    "PVC": "Panasonic VM1 Voice File",
    "PVD": "Instalit Script",
    "PVHD": "Paragon Virtual Hard Drive",
    "PVJ": "ProofVision Job Ticket",
    "PVK": "Private Key File",
    "PVM": "Photo Video Manifest File",
    "PVMZ": "Parallels Compressed Virtual Machine",
    "PVR": "Wintal PVR Video File",
    "PVS": "Parallels Desktop Configuration File",
    "PWA": "Password Agent File",
    "PWC": "PictureTaker File",
    "PWD": "Pocket Word Document",
    "PWDP": "Password Pad Document",
    "PWDPL": "Password Pad Lite Document",
    "PWF": "Counter-Strike PODBot Waypoint File",
    "PWI": "Pocket Word Document",
    "PWL": "Windows Password List",
    "PWN": "Pawn Source Code File",
    "PWP": "PhotoWorks Image File",
    "PWR": "PowerWrite Document",
    "PWS": "Print Workshop Image",
    "PWT": "Pocket Word Template",
    "PWV": "Password Vault Archive",
    "PX": "Pixel Image File",
    "PXB": "Pixelmator Brush File",
    "PXD": "Pixlr Layered Image",
    "PXF": "Transit XV Pack Project File",
    "PXG": "Pixelmator Gradient File",
    "PXI": "PlexTools Disc Image",
    "PXICON": "CandyBar Icon",
    "PXL": "Pocket Excel File",
    "PXM": "Pixelmator Image File",
    "PXP": "Counter-Strike PODBot Experience File",
    "PXR": "Pixar Image File",
    "PXV": "Pixbend Media File",
    "PXX": "Keyman Developer Encrypted Customization File",
    "PY": "Python Script",
    "PYC": "Python Compiled File",
    "PYD": "Python Dynamic Module",
    "PYO": "Python Optimized Code",
    "PYW": "Python GUI Source File",
    "PYX": "Pyrex Source Code File",
    "PYXEL": "Pyxel Image Document",
    "PZ": "Panzoid Video Project",
    "PZ2": "Poser Pose File",
    "PZ3": "Poser Scene File",
    "PZA": "PhotoSuite Album File",
    "PZF": "GraphPad Prism Project",
    "PZFX": "GraphPad Prism XML Project",
    "PZP": "PhotoSuite Project File",
    "PZS": "PhotoSuite Slide Show File",
    "PZZ": "Compressed Poser Scene File",
    "Q08": "QuickTax 2008 Tax Return",
    "Q09": "QuickTax 2009 Tax Return",
    "Q1": "Winamp Equalizer Presets File",
    "Q1Q": "LunarCell Photoshop Plug-in",
    "Q2Q": "Flexify Photoshop Plug-in",
    "Q3C": "Quick 3D Cover Project File",
    "Q4Q": "Solar Cell Photoshop Plug-in",
    "Q5R": "Melancholytron Photoshop Plug-in",
    "Q7Q": "India Ink Photoshop Plug-in",
    "Q8R": "Flood Photoshop Plug-in",
    "Q9R": "Glitterato Photoshop Plug-In",
    "Q9S": "Mr. Contrast Photoshop Plug-In",
    "QAR": "QlikView Extension",
    "QAT": "Microsoft Office Quick Access Toolbar File",
    "QB2009": "QuickBooks 2009 File",
    "QB2011": "QuickBooks 2011 File",
    "QB2012": "QuickBooks 2012 File",
    "QB2013": "QuickBooks 2013 File",
    "QB2014": "QuickBooks 2014 File",
    "QB2017": "QuickBooks 2017 for Mac Data File",
    "QBA.TLG": "QBA Transaction Log File",
    "QBB": "QuickBooks Backup File",
    "QBK": "QuickTax Backup File",
    "QBM": "QuickBooks Portable Company File",
    "QBMB": "QuickBooks Backup File",
    "QBMD": "QuickBooks Backup File",
    "QBO": "QuickBooks Online Bank Statement File",
    "QBW": "QuickBooks Data File",
    "QBX": "Blocks Landing Page File",
    "QC": "Half-Life Model Compiler Script",
    "QCC": "Quilt Manager Pattern File",
    "QCOW": "QEMU Copy On Write Disk Image",
    "QCOW2": "QEMU Copy On Write Version 2 Disk Image",
    "QCP": "PureVoice Audio File",
    "QCT": "Memory-Map QuickChart File",
    "QDA": "Quadruple D Archive",
    "QDF": "Quicken Data File",
    "QDL": "QDL Program",
    "QDS": "Windows Directory Query File",
    "QF": "Qompose Web Page Template",
    "QFX": "Quicken Financial Exchange File",
    "QIC": "Windows Backup File",
    "QIF": "Quicken Interchange Format File",
    "QIT": "QIT Trojan Horse File",
    "QKY": "Quirky Kernel",
    "QLGENERATOR": "Quick Look Generator File",
    "QMBL": "LabQuest Document",
    "QMG": "Samsung Theme Graphics File",
    "QMK": "YanCEyDesktop Quickmarks File ",
    "QMTF": "Quicken Mac Transfer File",
    "QPB": "QuickBooks Point of Sale Data File",
    "QPF": "QuickPad Encrypted Document",
    "QPM": "Quick Pallet Maker Input Data",
    "QPR": "FoxPro Generated Query Program",
    "QPT": "QuarkXPress Project Template",
    "QPW": "Quattro Pro Spreadsheet",
    "QPX": "FoxPro Compiled Query Program",
    "QRC": "Qt Resource Collection File",
    "QRM": "Qworum Message File",
    "QRP": "QuickReport File",
    "QRY": "Query File",
    "QSF": "Qualtrics Survey File",
    "QSS": "Qt Style Sheet",
    "QSV": "iQIYI Video File",
    "QT": "Apple QuickTime Movie",
    "QTCH": "QuickTime Cache File",
    "QTI": "QuickTime Image File",
    "QTIF": "QuickTime Image File",
    "QTINDEX": "Adobe QTIndex File",
    "QTL": "QuickTime Link File",
    "QTM": "Apple QuickTime Movie File",
    "QTP": "QuickTime Preferences File",
    "QTR": "QuickTime Extension Resource",
    "QTX": "QuickTime Extension",
    "QTZ": "Quartz Composer File",
    "QUA": "Avira AntiVir Quarantined File",
    "QUALSOFTCODE": "J&ASoft Code Archive File",
    "QUICKEN2015": "Quicken 2015 Data File",
    "QUICKEN2015BACKUP": "Quicken 2015 Backup File",
    "QUICKEN2016BACKUP": "Quicken 2016 Backup File",
    "QUICKEN2017": "Quicken 2017 Data File",
    "QUICKEN2017BACKUP": "Quicken 2017 Backup File",
    "QUICKENBACKUP": "Quicken Essentials for Mac Backup File",
    "QUICKENDATA": "Quicken Essentials for Mac Data File",
    "QVD": "QlikView Data File",
    "QVM": "Quake 3 Virtual Machine File",
    "QVPP": "QlikView Extension Properties Page File",
    "QVT": "QlikView Theme File",
    "QVW": "QlikView Document",
    "QV~": "ViewletBuilder Project Backup File",
    "QWD": "QuakeWorld Demo File",
    "QWQ": "OpenQwaq Auto-Launch File",
    "QXB": "QuarkXPress Book File",
    "QXD": "QuarkXPress Document",
    "QXL": "QuarkXPress Library",
    "QXP": "QuarkXPress Project File",
    "QXT": "QuarkXPress Template",
    "QXW": "Q Light Controller+ Workspace File",
    "R": "Rez Source Code File",
    "R0": "WinRAR Compressed Archive",
    "R00": "WinRAR Compressed Archive",
    "R01": "WinRAR Split Archive Part 1",
    "R02": "WinRAR Split Archive Part 2",
    "R03": "WinRAR Split Archive Part 3",
    "R04": "WinRAR Split Archive Part 4",
    "R1": "WinRAR Multi-Volume Archive Part 1",
    "R1M": "RealOne Streaming Media File",
    "R2": "WinRAR Multi-Volume Archive Part 2",
    "R21": "WinRAR Split Archive Part 21",
    "R30": "WinRAR Split Archive Part 30",
    "R3D": "REDCODE Video File",
    "RA": "RealAudio File",
    "RAD": "Radar ViewPoint Radar Data",
    "RADIUMKEY2": "Radium 2 License File",
    "RADQ": "Need for Madness Game Archive",
    "RAF": "Fuji RAW Image File",
    "RAL": "WinRail Track Design File",
    "RAM": "Real Audio Metadata File",
    "RAP": "Raptor Flowchart File",
    "RAR": "WinRAR Compressed Archive",
    "RAS": "Sun Raster Graphic",
    "RASKINLICENSE": "Raskin License File",
    "RASKINPLACE": "Raskin Place Layout File",
    "RAT": "PICS Rating File",
    "RATDVD": "RatDVD Disk Image",
    "RAV": "Rave Reports Project File",
    "RAVI": "Radiometric Video File",
    "RAW": "Raw Audio Data",
    "RAX": "Real Music Store Audio File",
    "RAY": "Rayshade Image",
    "RB": "Ruby Source Code",
    "RB4": "Resume Builder 4 File",
    "RBC": "Rembo-C Script",
    "RBF": "Redatam Binary File",
    "RBK": "Windows 95 Registry Backup File",
    "RBP": "Real Studio Project File",
    "RBS": "Rebirth Song File",
    "RBT": "LEGO MINDSTORMS NXT Program",
    "RBW": "Ruby Script",
    "RBX": "Rembo-C Compiled Script",
    "RBXL": "ROBLOX Location File",
    "RBXM": "ROBLOX Model",
    "RBXMX": "ROBLOX Model",
    "RBZ": "SketchUp Plugin",
    "RC": "Resource Script",
    "RC1": "Samsung Mobile Device Firmware File",
    "RC2": "Samsung Mobile Device Firmware File",
    "RCD": "pcAnywhere Recorded Session File",
    "RCF": "SonicWALL VPN Configuration File",
    "RCG": "Recog Character Recognition Set",
    "RCL": "Recolored Project File",
    "RCO": "PlayStation Portable Resource File",
    "RCPROJECT": "iMovie '08 Project",
    "RCREC": "LogMeIn Remote Control Session Recording",
    "RCS": "RandomControl Scene File",
    "RCT": "Visual Studio Resource Template",
    "RCTD": "RabbitCT Dataset",
    "RCU": "RealWorld Layered Cursor Image",
    "RCUT": "Webinaria Recording Cut",
    "RCV": "RoofCon Viewer Project File",
    "RCY": "ReCycle 1.x Document",
    "RDB": "N64 ROM Database",
    "RDC": "IDRISI Raster Documentation File",
    "RDF": "Report Definition File",
    "RDI": "Rohos Disk Image File",
    "RDL": "MicroStation Redline File",
    "RDLC": "Visual Studio Client Report Definition File",
    "RDO": "Xerox Rawster Document Object File",
    "RDP": "Remote Desktop Configuration File",
    "RDS": "Ray Dream Studio Scene File",
    "RDW": "Real-DRAW Project File",
    "README": "Readme File",
    "REC": "Topfield PVR Recording",
    "RED": "CADViewer Redline Markup File",
    "REF": "IDRISI Raster Image Reference File",
    "REFRESH": "Visual Studio Refresh File",
    "REG": "Registry File",
    "REGLNK": "Registry Editor Shortcut File",
    "REGTRANS-MS": "Registry Transaction Log File",
    "RELOC": "Windows EXE Relocation Section File",
    "RELS": "Open Office XML Relationships File",
    "REM": "BlackBerry Encrypted Data File",
    "REP": "Grand Theft Auto Replay File",
    "REQ": "SSL Certificate Request File",
    "RES": "C++ Complied Resource Script",
    "RESJSON": "Windows JavaScript Resources File",
    "RESMONCFG": "Resource Monitor Configuration File",
    "RESOURCES": "Visual Studio Resource File",
    "RESW": "Windows Resources File",
    "RESX": ".NET Managed Resources File",
    "REV": "LiveCode Plugin",
    "REX": "ReCycle Loop File",
    "REXX": "Rexx Source File",
    "REZ": "Lithtech Game Engine Resource File",
    "RFA": "Revit Family File",
    "RFB": "RoboForm Bookmark File",
    "RFC": "RoboForm Contact File",
    "RFD": "Recogniform Form Designer File",
    "RFL": "Reason ReFill Sound Bank",
    "RFLW": "Edge Reflow Data File",
    "RFM": "rFactor Modification File",
    "RFN": "RoboForm Safenote File",
    "RFO": "RoboForm Option File",
    "RFP": "RoboForm Passcard File",
    "RFQ": "RoboForm SearchCard File",
    "RFT": "Revisable Form Text Document",
    "RFU": "Remote Firmware Update",
    "RFW": "Rockchip Firmware File",
    "RGB": "RGB Bitmap",
    "RGBA": "RGB Bitmap",
    "RGD": "Raft Saved Game File",
    "RGF": "LEGO MINDSTORMS EV3 Robot Graphics File",
    "RGMB": "RootsMagic Backup File",
    "RGN": "Garmin Regional Map File",
    "RGO": "RepliGo File",
    "RGRP": "Pro Tools Region Group File",
    "RGS": "Registry Script",
    "RGSS3A": "RPG Maker VX Ace RGSS Encrypted Archive",
    "RGSSAD": "RPG Maker VX RGSS Encrypted Archive",
    "RHP": "Rhino Plug-in",
    "RHTML": "Ruby HTML Web Page",
    "RIC": "NXT Image File",
    "RIF": "Painter Raster Image File",
    "RIFF": "Painter Raster Image",
    "RIG": "Antibody Model Rig File",
    "RIP": "Hit'n'Mix Audio Mashup File",
    "RIS": "Research Information Systems Citation File",
    "RISE": "RISE Editor Model File",
    "RIX": "ColoRIX Image",
    "RJS": "Ruby Javascript File",
    "RK": "WinRK File Archive",
    "RKT": "Racket Source Code File",
    "RLE": "Run Length Encoded Bitmap",
    "RLF": "ArcGIS Report Layout File",
    "RLI": "RealWorld Graphics Layered Image",
    "RLL": "Microsoft Resource Library",
    "RM": "RealMedia File",
    "RMBAK": "Registry Mechanic Backup File",
    "RMD": "RED Metadata File",
    "RMF": "Adobe Rights Management Document",
    "RMH": "Rights-Managed HTML Document",
    "RMI": "RMID MIDI File",
    "RMJ": "Real Media Jukebox Audio File",
    "RML": "Redline Markup Language File",
    "RMP": "RealPlayer Metadata Package File",
    "RMR": "ResumeMaker File",
    "RMS": "Secure Real Media File",
    "RMSKIN": "Rainmeter Skin File",
    "RMT": "Router Firmware File",
    "RMV": "Radical Entertainment Video File",
    "RMVB": "RealMedia Variable Bit Rate File",
    "RMX": "RealJukebox Format",
    "RNC": "RNC ProPack Archive",
    "RND": "PGP Random Seed File",
    "RNG": "Nokia Composer Ringtone",
    "RNQ": "Renque Model File",
    "RNS": "Reason Song File",
    "ROADTRIP": "Road Trip Planner File",
    "ROCK": "Rockbox Plug-in",
    "ROD": "Actuate Report Object Design File",
    "RODL": "RemObjects Definition Language File",
    "RODX": "Ancestry Genealogical Database File",
    "RODZ": "Ancestry Genealogical Database File",
    "ROL": "Ad Lib Synthesized Instrument",
    "ROM": "N64 Game ROM File",
    "ROQ": "Id Software Game Video",
    "ROT": "Homeworld 2 Graphics File",
    "ROU": "Gerber Route File",
    "ROV": "Report Object Variable",
    "ROX": "Roxio Project File",
    "RP": "Axure RP Project File",
    "RP9": "RetroPlatform Disk Image Archive",
    "RPC": "Rich Page Content Document",
    "RPD": "RIB Project Database File",
    "RPF": "Rich Pixel Format File",
    "RPGPROJECT": "RPG Maker MV Project",
    "RPI": "Render Plug-in",
    "RPJ": "Real Pac Batch Job File",
    "RPK": "RadLight Media Player Skin",
    "RPL": "Toribash Replay File",
    "RPLIB": "Axure RP Widget Library File",
    "RPLN": "InDesign Required Plug-in File",
    "RPM": "Red Hat Package Manager File",
    "RPMSG": "Outlook Restricted Permission Message",
    "RPP": "REAPER Project File",
    "RPROJ": "R Project",
    "RPS": "3ds Max Render Preset Settings",
    "RPT": "Generic Report",
    "RPTR": "RafflePrinter Document",
    "RPX": "Report XML File",
    "RPY": "Touhou Project Replay File",
    "RRA": "vRigger Rigging Gear File",
    "RRD": "Reduced Resolution Dataset File",
    "RRI": "RealWorld Image",
    "RRR": "Registry Mechanic Backup File",
    "RS": "Sun Raster Graphic",
    "RSA": "RSA Certificate File",
    "RSB": "Red Storm Bitmap File",
    "RSC": "Symbian Application Compiled Resource File",
    "RSD": "RealSQLDatabase File",
    "RSDF": "RapidShare Download File",
    "RSG": "RaySupreme Graph",
    "RSM": "WinWay Resume Deluxe Resume File",
    "RSN": "Reason Project File",
    "RSO": "NXT Brick Audio File",
    "RSR": "Poser Model Preview File",
    "RSRC": "Macintosh Resource File",
    "RSS": "Rich Site Summary",
    "RST": "reStructuredText File",
    "RSX": "RED Metadata XML File",
    "RT": "RealText Streaming Text File",
    "RTA": "TrueRTA Project File",
    "RTC": "Live Meeting Connection File",
    "RTD": "RagTime Document",
    "RTE": "Revit Project Template",
    "RTF": "Rich Text Format File",
    "RTFD": "Rich Text Format Directory File",
    "RTI": "Real Tracker Instrument",
    "RTL": "Raster Transfer Language File",
    "RTM": "LabVIEW Run-Time Menu File",
    "RTS": "Real Tracker Sample",
    "RTTEX": "Robinson Technologies Texture File",
    "RTX": "Rich Text Document",
    "RUF": "Samsung DVD and Blu-ray Player Firmware File",
    "RUL": "InstallShield Rules File",
    "RULESET": "Visual Studio Code Analysis Rule Set File",
    "RUM": "Bink Video Subtitle File",
    "RUN": "Runscanner Scan File",
    "RV": "RealVideo File",
    "RVDATA": "RPG Maker VX Data File",
    "RVDATA2": "RPG Maker VX Ace Data File",
    "RVF": "RichView Format File",
    "RVG": "RVG X-ray Image",
    "RVID": "Snapz Pro X Recorded Video File",
    "RVL": "muvee Reveal X Project File",
    "RVP": "Sharp Blu-ray Player Firmware File",
    "RVPROJ": "RPG Maker VX Project File",
    "RVPROJ2": "RPG Maker VX Ace Project File",
    "RVT": "Revit Project File",
    "RVX": "Real Protected Video File",
    "RW2": "Panasonic RAW Image",
    "RW3": "RapidWeaver 3 Site File",
    "RWL": "Leica RAW Image",
    "RWLIBRARY": "Paperless Receipt Library",
    "RWP": "RapidWeaver Package",
    "RWPLUGIN": "RapidWeaver Plugin",
    "RWSTYLE": "RapidWeaver Style File",
    "RWSW": "RapidWeaver Site File",
    "RWT": "ReadWriteThink Printing Press Draft",
    "RWTHEME": "RapidWeaver Theme",
    "RWZ": "Rawzor Compressed Image",
    "RX2": "REX2 Audio File",
    "RXC": "Roxio Certificate File",
    "RXDATA": "RMXP Data File",
    "RXE": "Lego Mindstorms NXT Executable Program",
    "RZ": "Rzip Compressed File",
    "RZB": "Red Zion Book File",
    "RZK": "File Crypt Password File",
    "RZN": "Red Zion Notes File",
    "RZS": "Red Zion Security File",
    "RZX": "File Crypt Encrypted File",
    "S": "Microsoft Train Simulator Shape File",
    "S00": "ZipSplitter Part 1 File",
    "S01": "ZipSplitter Part 2 File",
    "S02": "ZipSplitter Part 3 File",
    "S09": "ZipSplitter Part 10 File",
    "S19": "Motorola S19 File Record",
    "S2A": "SEAL2 Application",
    "S2ML": "StarCraft 2 Map Localization File",
    "S2MV": "StarCraft 2 Map Preview File",
    "S2Z": "Heroes of Newerth Game Data File",
    "S3G": "MakerBot 3D Print File",
    "S3I": "Scream Tracker 3 Instrument",
    "S3M": "ScreamTracker 3 Module",
    "S3Z": "Compressed Scream Tracker 3 Module",
    "S7Z": "Mac OS X 7-Zip File",
    "SA9": "Hue and Cry Photoshop Plug-in",
    "SAB": "ACIS SAB Model File",
    "SAD": "Black & White Audio File",
    "SAF": "SafeText File",
    "SAFARIEXTZ": "Apple Safari Extension Package",
    "SAFE": "SIGLock Encrypted File ",
    "SAFENOTEBACKUP": "Safe Note Backup File",
    "SAFETEXT": "SafeText File",
    "SAI": "PaintTool SAI Image",
    "SAM": "Ami Pro Document",
    "SAMI": "Grand Theft Auto San Andres Mod Installer File",
    "SAN": "Smush Animation File",
    "SAP": "Atari SAP Music File",
    "SAR": "Saracen Paint Image",
    "SAS": "SAS Program File",
    "SAS7BDAT": "SAS Data Set File",
    "SASS": "Syntactically Awesome StyleSheets File",
    "SAT": "ACIS SAT 3D Model File",
    "SAV": "Saved Game",
    "SAVE": "Nano Temporary Save File",
    "SAVEDDECK": "Nokia Saved Web Page",
    "SAVEDSEARCH": "Spotlight Saved Search",
    "SAVER": "Mac OS X Screen Saver",
    "SB": "Slax Bundle",
    "SB2": "Scratch 2.0 Project File",
    "SB3": "Scratch 3.0 Project File",
    "SBB": "Office Accounting Company Backup File",
    "SBC": "Office Accounting Company Shortcut File",
    "SBF": "Superbase Database File",
    "SBG": "SBaGen Binaural Beat File",
    "SBI": "Sound Blaster Instrument",
    "SBK": "E-MU SoundFont Sound Bank",
    "SBN": "ESRI Spatial Binary File",
    "SBP": "Sketchbook Express iCloud Image",
    "SBPROJ": "OpenGL Shader Builder Project",
    "SBS": "SPSS Script",
    "SBSAR": "Substance Archive",
    "SBT": "SBT Subtitle File",
    "SBU": "Samsung Backup File",
    "SBV": "Superbase Form Definition File",
    "SBX": "GLBasic Shoebox File",
    "SBZ": "ShowBiz Project File",
    "SC": "SuperCollider Source Code File",
    "SC2": "Sample Cell II Instrument Definition",
    "SC2ARCHIVE": "Blizzard StarCraft 2 Archive File",
    "SC2ASSETS": "Blizzard StarCraft 2 Assets File",
    "SC2BANK": "StarCraft 2 Bank File",
    "SC2DATA": "Blizzard StarCraft 2 Data File",
    "SC2LOCALE": "Blizzard StarCraft 2 Localization File",
    "SC2MA": "StarCraft 2 Map Data File",
    "SC2MAP": "Blizzard StarCraft 2 Map File",
    "SC2MOD": "Blizzard StarCraft 2 Modification File",
    "SC2REPLAY": "Blizzard StarCraft 2 Replay File",
    "SC2SAVE": "Blizzard StarCraft 2 Saved Game",
    "SC4": "SimCity 4 Saved File",
    "SC45": "SuperCard Project File",
    "SC4DESC": "SimCity 4 Description File",
    "SC4LOT": "SimCity 4 Lot File",
    "SC4MODEL": "SimCity 4 Model File",
    "SCA": "Norton AntiVirus Scan File",
    "SCACFG": "SuperCard Application Configuration File",
    "SCAD": "OpenSCAD Script",
    "SCAP": "EFI Firmware File",
    "SCAR": "SCAR Script",
    "SCB": "Scala Published Script",
    "SCC": "Scenarist Closed Caption File",
    "SCD": "TurboTax Tax Schedule List",
    "SCDOC": "SpaceClaim Document",
    "SCF": "Windows Explorer Command",
    "SCG": "ColoRIX Image File",
    "SCH": "gEDA Schematic File",
    "SCHEMAS": "GConf Schema Definition File",
    "SCHEMATIC": "MCEdit Schematic File",
    "SCI": "ColoRIX Graphics Image",
    "SCM": "Schema File",
    "SCN": "Pinnacle Studio Scene File",
    "SCO": "TotalRecovery Backup Image",
    "SCP": "ColoRIX Bitmap Graphic File",
    "SCPCFG": "SuperCard Project Configuration File",
    "SCPRESETS": "Snap Converter Presets File",
    "SCPT": "AppleScript Script File",
    "SCPTD": "AppleScript Script Bundle",
    "SCR": "Script File",
    "SCREENFLOW": "ScreenFlow Document",
    "SCRIBE": "VideoScribe Project",
    "SCRIPT": "Generic Script File",
    "SCRIPTSUITE": "AppleScript Script Suite File",
    "SCRIPTTERMINOLOGY": "AppleScript Script Terminology File",
    "SCRIV": "Scrivener Document",
    "SCRIVX": "Scrivener XML Document",
    "SCS": "SimCity Societies Saved Game File",
    "SCS11": "Show Cue System Cue File",
    "SCSS": "Sass Cascading Style Sheet",
    "SCT": "FoxPro Form Memo",
    "SCU": "ColoRIX Bitmap Image",
    "SCUT4": "Easy Cut Studio Project",
    "SCV": "ScanVec CASmate Sign File",
    "SCW": "Movie Magic Screenwriter Document",
    "SCWORLD": "Survivalcraft World File",
    "SCX": "FoxPro Form",
    "SD": "Sound Designer Audio File",
    "SD2": "Sound Designer II File",
    "SD2F": "Sound Designer 2 File",
    "SD7": "Spring Content Package",
    "SDA": "StarOffice Drawing",
    "SDAT": "Nintendo DS Sound Data File",
    "SDB": "SAP2000 Model File",
    "SDC": "Apache OpenOffice Calc Spreadsheet",
    "SDEF": "AppleScript Dictionary Document",
    "SDF": "Standard Data File",
    "SDG": "Strater Project File",
    "SDI": "Windows System Deployment Image",
    "SDM": "StarOffice Mail Message",
    "SDN": "Shareware Distributors Network File",
    "SDO": "Signed Document",
    "SDOC": "Satra Khmer Document",
    "SDP": "Session Description Protocol File",
    "SDR": "SmartDraw Drawing",
    "SDS": "OpenOffice.org Chart",
    "SDSK": "SafeHouse Private Storage Volume",
    "SDT": "Electronic Arts Sound Data File",
    "SDTID": "SecurID Soft Token File",
    "SDV": "Studio DV Project File",
    "SDW": "StarOffice Writer Text Document",
    "SDX": "Kivuto Secure Download Manager File",
    "SDZ": "Spring Content Package",
    "SE": "Shuttle Document",
    "SEA": "Self-Extracting Archive",
    "SEAM": "Seam Framework Java Servlet File",
    "SEARCH-MS": "Windows Saved Search File",
    "SEARCHCONNECTOR-MS": "Windows Search Connector File",
    "SEB": "Safe Exam Browser Configuration File",
    "SEC": "Samsung Security Video File",
    "SED": "IExpress Self Extraction Directive File",
    "SEDPRJ": "Slideshow Studio Elements Project",
    "SEED": "Linux Preseed File",
    "SEESTYLE": "Coda Style Sheet File",
    "SEF": "Encryptafile Signature File",
    "SEGY": "SEG-Y Data File",
    "SEN": "SenTest Data File",
    "SEO": "SEO Note File",
    "SEP": "Separated Image File",
    "SEPLUGIN": "AppleScript Editor Plug-in",
    "SEQ": "PowerTracks Pro Audio Project File",
    "SER": "Astronomical Capture Video File",
    "SERVER": "MySQL Server Script",
    "SERVICE": "Systemd Service Unit File",
    "SES": "Audition Session File",
    "SESSION": "Mozilla Firefox Session File",
    "SESX": "Adobe Audition Session File",
    "SET": "Settings File",
    "SETTINGCONTENT-MS": "Windows Settings File",
    "SETTINGS": "Visual Studio Settings File",
    "SEW": "Home Embroidery Format",
    "SF2": "SoundFont 2 Sound Bank",
    "SFAP0": "Sound Forge Pro Audio Proxy File",
    "SFAR": "Mass Effect 3 DLC File",
    "SFC": "Motic Microscope Image",
    "SFCACHE": "ReadyBoost Cache File",
    "SFD": "Sofdec Dreamcast Movie",
    "SFERA": "Sfera 360\u00b0 File",
    "SFF": "Structured Fax File",
    "SFG": "Synfig Studio Compressed Project",
    "SFI": "SafeFolder Encrypted File",
    "SFK": "Sound Forge Pro Audio Peak File",
    "SFL": "Sound Forge Pro Sound Data File",
    "SFO": "PSP Game Parameters File",
    "SFP": "Soft Font Printer File",
    "SFPACK": "Packed SoundFont File",
    "SFS": "SFX Sample File",
    "SFT": "Microsoft App-V Sequencer File",
    "SFV": "Simple File Verification File",
    "SFVIDCAP": "Sonic Foundry Video Capture File",
    "SFW": "Seattle FilmWorks Image",
    "SFX": "Windows Self-Extracting Archive",
    "SFZ": "SFZ Sample Definition File",
    "SG0": "Humongous Entertainment Game Save File",
    "SGA": "Relic Entertainment Game Archive",
    "SGB": "Dawn of War Map File",
    "SGD": "GeneSnap Image File",
    "SGF": "Smart Game Format File",
    "SGI": "Silicon Graphics Image File",
    "SGM": "SGML File",
    "SGML": "Standard Generalized Markup Language File",
    "SGN": "Signet Bureau DRM File",
    "SGP": "MP3 Audio Mixer Sound Group Project",
    "SGPBPRJ": "Baltie Project",
    "SGT": "SPSS Chart Template",
    "SGY": "SEG-Y Data File",
    "SGZ": "SigzaLock Encrypted File ",
    "SH": "Bash Shell Script",
    "SH3D": "Sweet Home 3D Design File",
    "SH3F": "Sweet Home 3D Model Library",
    "SHA1": "SHA-1 Hash File",
    "SHA512": "SHA 512 Hash File",
    "SHAR": "Unix Shar Archive",
    "SHB": "Windows Document Shortcut",
    "SHD": "Windows Print Job Shadow File",
    "SHG": "Segmented Hyper-Graphic",
    "SHK": "ShrinkIt Archive",
    "SHN": "Shorten Compressed Audio File",
    "SHORTCUT": "Asutype Shortcut",
    "SHP": "Shapes File",
    "SHR": "Unix Shell Archive File",
    "SHS": "Microsoft Scrap File",
    "SHSH": "iPhone/iPod Touch SHSH Blob File",
    "SHT": "HTML File with Server Side Includes",
    "SHTM": "HTML Server Side Include File",
    "SHTML": "Server Side Include HTML File",
    "SHV": "Husqvarna Viking Embroidery File",
    "SHW": "Corel Presentation",
    "SHX": "AutoCAD Compiled Shape File",
    "SHY": "ShyFile Encrypted File",
    "SI": "Softimage Image File",
    "SIA": "Sia Metadata File",
    "SIB": "Sibelius Score",
    "SID": "MrSID Image",
    "SIDB": "iTunes Authorization Data File",
    "SIDD": "iTunes Authorization Data File",
    "SIDN": "iTunes Authorization Data File",
    "SIF": "Windows Setup Information File",
    "SIFZ": "Synfig Studio Compressed Project",
    "SIG": "Signature File",
    "SIGNATURE": "e-Filing Digital Signature File",
    "SII": "18 Wheels of Steel: Haulin' Truck Definition File",
    "SIM": "Aurora Image",
    "SIMG": "Synclavier Disk Image File",
    "SIMP": "Software Ideas Modeler Project",
    "SIMS2PACK": "Downloaded Sims 2 Package File",
    "SIMS3": "The Sims 3 Game Save File",
    "SIMS3PACK": "The Sims 3 Package File",
    "SIN": "Sony Xperia Firmware File",
    "SIS": "arivis ImageCore File",
    "SIS.DM": "Ovi Store DRM-Protected Application",
    "SISX": "Symbian OS Installation File",
    "SISX.DM": "Nokia Ovi Store DRM-Protected Application",
    "SIT": "StuffIt Archive",
    "SITE": "GoLive Website Project File",
    "SITEMAP": "ASP.NET Site Map File",
    "SITES": "iWeb Site Design Project",
    "SITES2": "iWeb Site Design Project",
    "SITX": "StuffIt X Archive",
    "SIV": "Silicon Imaging Video File",
    "SJD": "Scrapbook Factory Journal File",
    "SJPG": "Sealed JPG File",
    "SK1": "sK1 Vector Graphic File",
    "SK2": "ChemSketch Drawing",
    "SKB": "SketchUp Backup Document",
    "SKBA": "SketchBook Pro Animation File",
    "SKCARD": "Starfish Sidekick Card File",
    "SKETCH": "Sketch Drawing",
    "SKETCHPAD": "Sketchpad Drawing File",
    "SKF": "AutoSketch Drawing",
    "SKI": "Motorola Phone Skin File",
    "SKIN": "ASP.NET Skin File",
    "SKINDEX": "Mail Index File",
    "SKITCH": "Skitch Image",
    "SKL": "Maya Skeleton File",
    "SKM": "SketchUp Materials File",
    "SKN": "Symbian OS Skin File",
    "SKP": "SketchUp Document",
    "SKR": "PGP Private Keyring",
    "SKYPECHATSTYLE": "Chat Style File",
    "SKYPEEMOTICONSET": "Skype Emoticon Set File",
    "SKZ": "SuperKaramba Theme",
    "SL": "Software License File",
    "SLA": "Scribus Document",
    "SLA.GZ": "Scribus Compressed Document",
    "SLB": "AutoCAD Slide Library",
    "SLD": "AutoCAD Slide File",
    "SLDASM": "SolidWorks Assembly File",
    "SLDDRT": "SolidWorks Sheet File",
    "SLDDRW": "SolidWorks Drawing File",
    "SLDPRT": "SolidWorks Part File",
    "SLE": "Sisulizer Package File",
    "SLF": "Symantec License File",
    "SLI": "OMSI Spline Configuration File",
    "SLK": "Symbolic Link File",
    "SLN": "Visual Studio Solution File",
    "SLOGO": "StarLogo Project File",
    "SLP": "Sisulizer Project File",
    "SLT": "Mozilla User Profile Folder",
    "SLTNG": "StarLogo TNG Project File",
    "SLUPKG-MS": "XrML Digital License Package",
    "SLX": "MathWorks Simulink Model File",
    "SM": "Space Engine 3D Mesh File",
    "SMA": "SmartMusic Accompaniment File",
    "SMALI": "Android Smali Assembly Language File",
    "SMC": "Super Nintendo Game ROM",
    "SMD": "Valve Studiomdl Data File",
    "SME": "SmartEncryptor Encrypted File",
    "SMF": "StarMath Formula File",
    "SMG": "SolidWorks Composer File",
    "SMI": "SMIL Presentation",
    "SMIL": "SMIL Presentation File",
    "SMK": "Smacker Compressed Movie File",
    "SML": "SMIL Slideshow Presentation",
    "SMM": "Ami Pro Macro",
    "SMMX": "SimpleMind Mind Map File",
    "SMP": "SmartMusic Performance File",
    "SMPF": "Sprite Monkey Project",
    "SMPX": "SmartMusic Accompaniment File",
    "SMRAILROADSSAVEDGAME": "Sid Meier's Railroads! Saved Game",
    "SMRD": "Adobe InDesign Filter File",
    "SMS": "Exported SMS Text Message",
    "SMT": "Samsung Theme File",
    "SMV": "VideoLink Mail Video File",
    "SMWT": "Adobe InDesign Filter",
    "SMZIP": "StepMania Package",
    "SN1": "Drive Snapshot First Differential Backup",
    "SN2": "Drive Snapshot Second Differential Backup",
    "SNA": "Drive Snapshot Primary Backup File",
    "SNAG": "SnagIt Capture File",
    "SNAGITSTAMPS": "Snagit Stamp Archive",
    "SNAGPROJ": "Snagit Project File",
    "SNAGSTYLES": "Snagit Style Archive",
    "SNAPFIRESHOW": "Corel SnapfireShow File",
    "SNAPPY": "Snappy Compressed File",
    "SNB": "Shanda Bambook eBook",
    "SND": "Sound File",
    "SNF": "Starry Night Pro Document",
    "SNG": "MIDI Song File",
    "SNGX": "ChordWizard Song",
    "SNIPPET": "Visual Studio IntelliSense Code Snippet",
    "SNK": "Strong Name Key File",
    "SNM": "Netscape Mail Index",
    "SNP": "Access Report Snapshot",
    "SNS": "SNS Video Game Audio File",
    "SNT": "Sticky Notes File",
    "SNX": "PISnoop Workspace File",
    "SO": "Shared Library",
    "SO-ABI": "Cocoa AbiWord Plug-in",
    "SO.0": "Unix Shared Library File",
    "SOB": "OpenOffice.org Impress Bimap Styles File",
    "SOEPSX": "Player Studio Viewer Item File",
    "SOL": "Flash Local Shared Object File",
    "SONG": "AudioSauna Song File",
    "SOPT": "Synclavier Optical Disk Image File",
    "SOU": "SBStudio II Sound File",
    "SP": "SignPlot Traffic Sign File",
    "SP3": "NGS SP3 File",
    "SPA": "MikuMikuDance Sphere Mapping File",
    "SPARC": "Skype Plugin Archive",
    "SPARKLE": "Sparkle Website Project",
    "SPARSEBUNDLE": "Mac OS X Sparse Bundle",
    "SPARSEIMAGE": "Mac OS X Sparse Image",
    "SPB": "Flight Simulator Mission File",
    "SPC": "Spectrum 512 Compressed Image",
    "SPD": "SPSS Custom Dialog File",
    "SPDF": "Sealed PDF File",
    "SPE": "WinSpec CCD Capture File",
    "SPEC": "RPM Specification File",
    "SPF": "Slingplayer Favorites File",
    "SPFX": "Squeeze Presets File",
    "SPG": "TCP Optimizer Backup File",
    "SPH": "NIST SPHERE Audio File",
    "SPI": "ShadowProtect Incremental Backup File",
    "SPIFF": "Still Picture Interchange File Format",
    "SPJ": "Microsoft ICE Panorama Project",
    "SPK": "Synology Package",
    "SPL": "FutureSplash Animation",
    "SPL7": "sPlan 7 Schematic Diagram File",
    "SPLANE": "Simple Planes Plane File",
    "SPM": "Salt Package Manager Formula Package",
    "SPP": "Serif PhotoPlus Picture File",
    "SPPACK": "SPPack Sound Sample",
    "SPQ": "SPSS Database Query File",
    "SPR": "Half-Life Sprite File",
    "SPRG": "Synclavier Program File",
    "SPRITE": "Scratch Sprite File",
    "SPRITE2": "Scratch 2.0 Sprite File",
    "SPS": "SPSS Program File",
    "SPT": "SpeedTree Tree Data File",
    "SPU": "Spectrum 512 Image",
    "SPUB": "Disc Cover File",
    "SPV": "SPSS Output Document",
    "SPX": "System Profiler XML Report",
    "SQ": "Sysquake Program",
    "SQB": "SQL Backup SQL Server Backup File",
    "SQD": "SQ Data File",
    "SQF": "ArmA Script File",
    "SQFS": "Squash FS Bootable File",
    "SQL": "Structured Query Language Data File",
    "SQLITE": "SQLite Database File",
    "SQLITE3": "SQLite 3 Database File",
    "SQLITEDB": "SQLite Database",
    "SQLPROJ": "Visual Studio SQL Server Project",
    "SQM": "Operation Flashpoint Mission File",
    "SQR": "SQL Program File",
    "SQX": "SQX Archive",
    "SQZ": "Squeeze Project File",
    "SR": "Sun Raster Image File",
    "SR0": "SecuROM Analysis File",
    "SR2": "Sony RAW Image",
    "SRC": "Source Code",
    "SRC.RPM": "Red Hat Package Manager Source File",
    "SREP": "SuperREP Compressed File",
    "SRF": "LightWave Surface File",
    "SRM": "Super Nintendo ROM Save File",
    "SRR": "ReScene Metadata File",
    "SRS": "Outlook Send/Receive Settings File",
    "SRT": "SubRip Subtitle File",
    "SRW": "Samsung RAW Image",
    "SS": "SilverStripe Source Code File",
    "SSA": "Sub Station Alpha Subtitle File",
    "SSC": "StepMania Song File",
    "SSD": "WindowBlinds Skin File List",
    "SSEQ": "Nintendo DS Sound Sequence File",
    "SSF": "Structured Subtitle Format File",
    "SSI": "Adobe Dreamweaver Server Side Include File",
    "SSK": "SmartSketch 95 Document",
    "SSL": "Sunlight ScanLibrary File",
    "SSL2": "Sunlight ScanLibrary 2 File",
    "SSLF": "HLSW Shared Server List File",
    "SSM": "Sound Clip Archive",
    "SSND": "Synclavier Sound File",
    "SSP": "Scala Server Page",
    "SSS": "WindowBlinds Substyle File",
    "SST": "Serialized Certificate Store File",
    "SSW": "Sony Ericsson Firmware File",
    "ST": "Atari ST Disk Image",
    "STA": "ABAQUS Status File",
    "STAP": "Soundtrack Pro Audio Project File",
    "STARTUPINFO": "E-Prime 2.0 Startup Info File",
    "STB": "AutoCAD Plot Style Table File",
    "STC": "Shade to Manga Studio File",
    "STD": "Apache OpenOffice Drawing Template",
    "STE": "Samsung IPOLIS Image File",
    "STENCYL": "Stencyl Game File",
    "STEP": "STEP 3D Model",
    "STEX": "Godot Engine StreamTexture File",
    "STG": "ActiveSync Backup File",
    "STH": "Lotus Domino Stash File",
    "STL": "Spruce Technologies Subtitle File",
    "STM": "Exchange Streaming Media File",
    "STMB": "Synclavier Timbre File",
    "STML": "SSI HTML File",
    "STN": "Genuine Fractals Image",
    "STO": "PRO100 3D Interior Design Project",
    "STORY": "Storyist Document",
    "STORYBOARD": "Interface Builder Storyboard Document",
    "STORYISTTHEME": "Storyist Application Theme File",
    "STORYMILL": "StoryMill Project File",
    "STP": "Analysis Studio Project Information File",
    "STPROJ": "iAd Producer Project",
    "STR": "PlayStation Video Stream",
    "STRINGS": "Text Strings File",
    "STRM": "STRM Audio Stream File",
    "STT": "Streets & Trips Map Template",
    "STUDIO": "Silhouette Studio Document",
    "STUDIO3": "Silhouette Studio Version 3 Document",
    "STW": "StarOffice Document Template",
    "STX": "Scream Tracker Music Interface Kit File",
    "STXT": "Sealed Text File",
    "STY": "LaTeX Style",
    "STYK": "Stykz Stick Figure",
    "STYKZ": "Stykz Animation",
    "STYLE": "ArcGIS Style Manager File",
    "SUB": "Subtitle File",
    "SUBLIME-PACKAGE": "Sublime Text Package File",
    "SUBLIME-PROJECT": "Sublime Text Project File",
    "SUBLIME-SNIPPET": "Sublime Text Snippet File",
    "SUBLIME-WORKSPACE": "Sublime Text Workspace File",
    "SUCK": "SiteSucker Website File",
    "SUD": "Sudoku Puzzle File",
    "SUF": "Ccrypt Encrypted File",
    "SUGAR": "Espresso Plug-in",
    "SUIT": "Macintosh Font Suitcase",
    "SUM": "Garmin Checksum File",
    "SUMO": "Sumo Paint Image",
    "SUN": "Sun Raster Graphic File",
    "SUNIFF": "Sun TAAC Image",
    "SUO": "Visual Studio Solution User Options File",
    "SUP": "Subtitle Bitmap File",
    "SV$": "AutoCAD Automated Backup File",
    "SV2I": "Symantec System Index File",
    "SV5": "BigJig Saved Puzzle",
    "SVA": "Manga Browser Comic File",
    "SVC": "WCF Web Service File",
    "SVD": "Roland Patch File",
    "SVF": "Serial Vector Format File",
    "SVG": "Scalable Vector Graphics File",
    "SVGZ": "Compressed SVG File",
    "SVI": "Samsung Video File",
    "SVM": "StarView Metafile",
    "SVN-BASE": "Subversion Base File",
    "SVN-WORK": "Subversion Cache File",
    "SVP": "Subsurface Viewer Project",
    "SVR": "Compressed Virtual World",
    "SVS": "Game Boy Advance Saved State File",
    "SVX": "8SVX Sound File",
    "SW2": "Softwrap License File",
    "SWA": "Shockwave Audio",
    "SWC": "Super Nintendo Wild Card ROM File",
    "SWD": "Flash Debug File",
    "SWF": "Shockwave Flash Movie",
    "SWI": "SWiSH Project File",
    "SWIFT": "Swift Source Code File",
    "SWITCH": "Switch Package",
    "SWJ": "SolidWorks Journal File",
    "SWK": "StudyWorks Save File",
    "SWM": "Split Windows Imaging Format File",
    "SWP": "Swap File",
    "SWT": "Flash Generator Template",
    "SWZ": "Adobe Flash Player Cache File",
    "SXC": "StarOffice Calc Spreadsheet",
    "SXD": "StarOffice Drawing",
    "SXG": "Apache OpenOffice Master Document",
    "SXLS": "Sealed Excel Spreadsheet",
    "SXM": "StarMath Formula",
    "SXML": "Sealed XML File",
    "SXT": "Propellerhead Reason NN-XT Patch File",
    "SXW": "StarOffice Writer Document",
    "SYH": "Synchomatic Instrument",
    "SYM": "gEDA Symbol File",
    "SYN": "SimSynth Document",
    "SYNW-PROJ": "SynWrite Project",
    "SYS": "Windows System File",
    "SYW": "Yamaha SY99/SY85 Audio File",
    "SYX": "MIDI System Exclusive Message",
    "SY_": "Compressed SYS File",
    "SZ": "Winamp Classic Skin Download",
    "SZA": "HiCAD Drawing File",
    "T": "Turing Source Code File",
    "T$M": "AVG Internet Security Temporary File",
    "T05": "TaxCut 2005 Tax Return",
    "T06": "TaxCut 2006 Tax Return",
    "T07": "TaxCut 2007 Tax Return",
    "T08": "TaxCut 2008 Tax Return",
    "T09": "At Home 2009 Tax Return",
    "T10": "At Home 2010 Tax Return",
    "T11": "At Home 2011 Tax Return",
    "T12": "At Home 2012 Tax Return",
    "T13": "H&R Block 2013 Tax Return",
    "T16": "H&R Block 2016 Tax Return",
    "T18": "H&R Block 2018 Tax Return",
    "T2B": "CyBook Thumbnail Image",
    "T2D": "TouchDraw Document",
    "T3001": "TARGET 3001! Circuit Design Project File",
    "T3D": "Unreal Engine 3D Object File",
    "T3X": "TYPO3 Compressed Extension",
    "T64": "Commodore 64 Tape Image File",
    "T65": "PageMaker Template File",
    "TA": "Sony Firmware File",
    "TA8": "TaxAct 2018 Tax Return File",
    "TAAC": "Sun TAAC Image File",
    "TAB": "Guitar Tablature File",
    "TAK": "Tom's Lossless Audio Kompressor File",
    "TAO": "Track at Once CD/DVD Image",
    "TAP": "Commodore 64 Cassette Tape Image",
    "TAR": "Consolidated Unix File Archive",
    "TAR.BZ2": "Compressed Tarball File",
    "TAR.GZ": "Compressed Tarball File",
    "TAR.GZ2": "Misnamed BZ2 Tarball",
    "TAR.LZ": "Lzip Compressed Tarball",
    "TAR.LZMA": "LZMA Compressed Tarball",
    "TAR.MD5": "Android System File",
    "TAR.XZ": "XZ Compressed Tar Archive",
    "TAR.Z": "Zipped Tarball File",
    "TARGA": "Targa Graphic",
    "TARGETS": "MSBuild Targets File",
    "TAX2009": "TurboTax 2009 Tax Return",
    "TAX2010": "TurboTax 2010 Tax Return",
    "TAX2011": "TurboTax 2011 Tax Return",
    "TAX2013": "TurboTax 2013 Tax Return",
    "TAX2015": "TurboTax 2015 Tax Return",
    "TAX2016": "TurboTax 2016 Tax Return",
    "TAX2017": "TurboTax 2017 Tax Return",
    "TAX2018": "TurboTax 2018 Tax Return",
    "TAX2019": "TurboTax 2019 Tax Return",
    "TAZ": "Tar Zipped File",
    "TB": "Tabbery Tab File",
    "TB0": "Adobe Photoshop Thumbnail Cache File",
    "TBK": "ToolBook File",
    "TBL": "StarCraft Information Table",
    "TBM": "Toribash Mod File",
    "TBN": "Kodi Thumbnail Image",
    "TBP": "Tekla BIMsight Project",
    "TBS": "TuneUp Utilities Boot Screen",
    "TBZ": "Bzip Compressed Tar Archive",
    "TBZ2": "Tar BZip 2 Compressed File",
    "TC": "TrueCrypt Volume",
    "TC2": "TurboCAD 2D Mac Drawing",
    "TC3": "TurboCAD 2D/3D Mac Drawing",
    "TCC": "TimeCalc Classic Data File",
    "TCD": "TurboCAD Mac Deluxe Drawing",
    "TCL": "Tcl Script",
    "TCM": "TurboCAD Mac Drawing",
    "TCN": "Techne Model File",
    "TCP": "Tally Compiled Program File",
    "TCR": "Psion Series 3 eBook File",
    "TCT": "TurboCAD Drawing Template",
    "TCW": "TurboCAD Drawing File",
    "TCX": "Training Center XML File",
    "TD": "Thunder Incomplete Download File",
    "TD0": "Akai Teledisk Sound Library",
    "TDA3MT": "DivX Author Template File",
    "TDB": "Android Thumbnail Cache",
    "TDDD": "3D Data Description File",
    "TDF": "Guide Text Definition File",
    "TDL": "Tab Delineated Format File",
    "TDM": "LabVIEW Binary Measurement File",
    "TDS": "Adobe LiveCyle Designer Template",
    "TDT": "THOR Data Tree File",
    "TDX": "D-TEG CCTV Video Information File",
    "TDZ": "Drobo Firmware File",
    "TE": "Textease CT Database File",
    "TE3": "WinTrack Object File",
    "TEACHER": "SMART Response Teacher Database File",
    "TEC": "TECkit Compiled Mapping File",
    "TED": "Alamo Map File",
    "TEF": "TablEdit Tablature",
    "TEMP": "Temporary (Temp) File",
    "TEMPLATE": "Apple Pages Template",
    "TEMX": "Cemetery Registry Database File",
    "TERMINAL": "Terminal Settings File",
    "TESTRUNCONFIG": "Visual Studio Test Run Configuration File",
    "TESTSETTINGS": "Visual Studio Test Settings File",
    "TET": "Textease CT Template",
    "TEX": "LaTeX Source Document",
    "TEXT": "Plain Text File",
    "TEXTCLIPPING": "Mac OS X Text Clipping File",
    "TEXTFACTORY": "BBEdit Text Factory",
    "TEXTURE": "Diesel Engine Game Texture File",
    "TFA": "TreeSoft CashFlow Analysis Data File",
    "TFC": "Unreal Engine 3 Texture File Cache",
    "TFIL": "Blizzard Software Update File",
    "TFM": "TeX Font Metric File",
    "TFRD": "Tape Image Format Requirements Document",
    "TFW": "World File for TIFF",
    "TG": "TuxGuitar Document",
    "TG4": "Tiled Group 4 Raster Image File",
    "TGA": "Targa Graphic",
    "TGO": "Terragen Object File",
    "TGP": "Terragen Plugin",
    "TGZ": "Gzipped Tar File",
    "TH": "Therion Data File",
    "THA": "Windows Thai Noise-Words List File",
    "THE": "Microsoft Plus! Theme File",
    "THEATER": "iMovie Theater File",
    "THEME": "Microsoft Plus! Desktop Theme",
    "THEMEPACK": "Windows 7 Theme Pack",
    "THING": "MakerBot Thing File",
    "THL": "Total 3D Home Design File",
    "THM": "Thumbnail Image File",
    "THMX": "Office 2007 Theme File",
    "THP": "TurboTax Text String",
    "THUMB": "JAlbum Thumbnail File",
    "THUMBNAILS": "Android Thumbnails Folder",
    "TIAPP": "TiTanium App",
    "TIB": "Acronis True Image File",
    "TIBKP": "Titanium Backup File",
    "TID": "AVCHD Thumbnail File",
    "TIF": "Tagged Image File",
    "TIFF": "Tagged Image File Format",
    "TIG": "TI Connect Backup File",
    "TIGER": "Tomb Raider Game Data Archive",
    "TIM": "The Incredible Machine Level",
    "TIMER": "Systemd Unit Configuration File",
    "TIMESTAMP": "Geodatabase Timestamp File",
    "TIP": "TuneUp Utilities Icon Package",
    "TIS": "True Image Script",
    "TIVO": "TiVo Video File",
    "TIX": "DivX Video Download Activation File",
    "TJP": "Tiled JPEG File",
    "TK": "Tk Script",
    "TK3": "TK3 Multimedia eBook",
    "TKFL": "TKLinks Saver Favorite Links File",
    "TKO": "AMX Software Module File",
    "TLB": "VAX Text Library",
    "TLC": "The Logo Creator File",
    "TLD": "Tag Library Descriptor File",
    "TLG": "QuickBooks Transaction Log File",
    "TLH": "Typelib Generated C/C++ Header File",
    "TLI": "Typelib Generated C/C++ Inline File",
    "TLO": "SPSS TableLooks File",
    "TLS": "TuneUp Utilities Logon Screen",
    "TLZ": "Tar LZMA Compressed File",
    "TLZMA": "LZMA Compressed Tar Archive",
    "TM": "TeXmacs Document",
    "TM2": "PlayStation 2 Graphic",
    "TMB": "Timbuktu Pro Connection Document",
    "TMBUNDLE": "TextMate Bundle File",
    "TMD": "TextMaker Document",
    "TMDX": "TextMaker Document",
    "TME": "Bryce Time File",
    "TMLANGUAGE": "TextMate Language Grammar File",
    "TMO": "3DCG Animation and Pose File",
    "TMP": "Temporary File",
    "TMPROJ": "TextMate Project File",
    "TMR": "Free Countdown Timer Backup File",
    "TMS": "Telemate Script",
    "TMTHEME": "TextMate Theme File",
    "TMV": "TextMaker Template",
    "TMVT": "TimeMap Template",
    "TMVX": "TextMaker Document Template",
    "TMX": "Translation Memory Exchange File",
    "TN": "LG Phone Image",
    "TN1": "Tiny Low Resolution Image",
    "TN2": "Tiny Medium Resolution Image",
    "TN3": "Tiny High Resolution Image",
    "TNE": "Manga Studio Tone File",
    "TNEF": "Transport Neutral Encapsulation Format",
    "TNS": "TI-Nspire Document",
    "TNSP": "TI-Nspire PublishView Document",
    "TNY": "Atari Tiny Image",
    "TOAST": "Toast Disc Image",
    "TOC": "PSP Audio File",
    "TOD": "JVC Everio Video Capture File",
    "TOP": "TopSolid Design Document",
    "TOPC": "TopicCrunch Project File",
    "TOPPRJ": "TopSolid Project File",
    "TOPVIW": "TopSolid'Viewer Document",
    "TOR": "Star Wars: The Old Republic Asset File",
    "TORRENT": "BitTorrent File",
    "TOTALSLAYOUT": "Totals Invoice Layout File",
    "TP": "Beyond TV Transport Stream File",
    "TP0": "Mascom PVR Video File",
    "TP3": "Harvard Graphics DOS Template File",
    "TPARK": "ThemePark Project File",
    "TPB": "GROMACS Binary Input File",
    "TPC": "Topic Connection Placeholder",
    "TPD": "Cyberlink TOD Video File",
    "TPF": "Transit NXT Pack Translation File",
    "TPI": "TrueVision Bitmap Image",
    "TPKEY": "TexturePacker License Key File",
    "TPL": "Canvas Template",
    "TPM": "Trusted Platform Module Password File",
    "TPR": "TMPGEnc Project File",
    "TPS": "Bryce Tree Shape File",
    "TPU": "Turbo Pascal Unit",
    "TPX": "DeLorme Topo Project File",
    "TPZ": "Kindle Topaz eBook File",
    "TR": "TomeRaider 2 eBook File",
    "TR3": "TomeRaider eBook File",
    "TRA": "WinTrack Railroad Track File",
    "TRACE": "VMware ThinApp Trace Log File",
    "TRAK": "Traktor Content Pack File",
    "TRASHES": "macOS USB Flash Drive Trash Folder",
    "TRC": "Oracle Trace File",
    "TRD": "TrID Definitions Package",
    "TREC": "TechSmith Recording File",
    "TRELBY": "Trelby File",
    "TRI": "FaceGen Polygonal Model File",
    "TRIF": "Tiled Raster Interchange Format",
    "TRK": "CompeGPS Land Track File",
    "TRM": "Oracle Trace Map File",
    "TRN": "SQL Server Transaction Log Backup File",
    "TRP": "HD Video Transport Stream",
    "TRS": "Rosetta Stone Language Data File",
    "TRUCK": "Rigs of Rods Truck Definition File",
    "TRX": "PASSOLO Translation List File",
    "TRX_DLL": "Windows Startup File",
    "TS": "Video Transport Stream File",
    "TS1": "VirtualBus Texture Description File",
    "TSC": "TINA Design File",
    "TSCPROJ": "TechSmith Camtasia Project File",
    "TSF": "Strater Template File",
    "TSI": "Traktor Settings File",
    "TSK": "Pocket PC Skin",
    "TSM": "TwinCAT System Manager Configuration File",
    "TSP": "Digital TV DVR Recording",
    "TSR": "TIFF Simple Rare File",
    "TST": "TestPoint Test File",
    "TSTREAM": "SwarmPlayer Streaming Torrent",
    "TSV": "Tab Separated Values File",
    "TSZ": "Trillian Skin File",
    "TT": "Visual Studio Text Template",
    "TT10": "TurboTax Canada 2010 Tax Return",
    "TT12": "TurboTax Canada 2012 Tax Return",
    "TT13": "TurboTax Canada 2013 Tax Return",
    "TT18": "TurboTax Canada 2018 Tax Return",
    "TTA": "True Audio File",
    "TTARCH": "Telltale Games Archive",
    "TTBK": "Canadian TurboTax 2010 Backup File",
    "TTC": "TrueType Font Collection",
    "TTE": "Private Character Editor File",
    "TTF": "TrueType Font",
    "TTK": "Catalyst Translation Toolkit",
    "TTKGP": "TatukGIS Project File",
    "TTS": "ToolBook Translation System File",
    "TTX": "Trados TagEditor File",
    "TTXT": "MPEG-4 Timed Text Subtitles File",
    "TU": "Turing Source File",
    "TUB": "PaintShop Pro Picture Tube",
    "TUR": "Turing Program Source File",
    "TVC": "Turbo View & Convert Batch Presets File",
    "TVJ": "TrueView Job Ticket",
    "TVLAYER": "mimoLive TV Layer",
    "TVM": "TV3D Model",
    "TVPI": "TitanTV Television Listing File",
    "TVRECORDING": "BoinxTV TV recording",
    "TVS": "TeamViewer Video Session File",
    "TVSHOW": "mimoLive Show",
    "TVTEMPLATE": "mimoLive Template",
    "TVVI": "TitanTV Television Listing File",
    "TWB": "Tableau Workbook File",
    "TWC": "TTWin Configuration File",
    "TWH": "Task Wheel Project File",
    "TWIG": "Twig Template",
    "TWT": "Carmageddon 2 Data File",
    "TXD": "Game Texture Dictionary",
    "TXF": "Tax Exchange Format",
    "TXT": "Plain Text File",
    "TXW": "Yamaha TX16W Audio File",
    "TXZ": "XZ Compressed Tar Archive",
    "TX_": "Compressed Text File",
    "TYPEIT4ME": "TypeIt4Me Clippings File",
    "TZ": "Zipped Tar Archive",
    "TZST": "Zstandard Compressed Tar File",
    "TZX": "ZX Spectrum Tape Image File",
    "U": "AU Audio File",
    "U10": "UFile 2010 Tax Return",
    "U3D": "Universal 3D File",
    "U3I": "U3 Application Information File",
    "U3P": "U3 Smart Application",
    "U8": "Mario Kart Wii Archive",
    "UASSET": "Unreal Asset File",
    "UAX": "Unreal Audio Package",
    "UC": "UnrealScript Class",
    "UC2": "UltraCompressor 2 Archive",
    "UCCAPILOG": "Microsoft UCC API Log File",
    "UCE": "Windows UCE System File",
    "UCF": "WebEx Media File",
    "UCI": "UFS Explorer Backup File",
    "UCT": "UC Browser Theme File",
    "UDB": "Dynamics AX User Database File",
    "UDCX": "Universal Data Connection File",
    "UDF": "Excel User Defined Function",
    "UDK": "Unreal Engine Map File",
    "UDL": "Microsoft Universal Data Link File",
    "UEA": "Protector Suite QL Encrypted Archive",
    "UFO": "Ulead File Object",
    "UFR": "Ultra Fractal File",
    "UFS": "FreeBSD Unix File System File",
    "UFS.UZIP": "Compressed Unix File System File",
    "UGA": "Ulead GIF Animator File",
    "UGOIRA": "Ugoira Animated Image File",
    "UHA": "UHarc Compressed Archive",
    "UHTML": "UC Browser Saved Webpage",
    "UI": "User Interface File",
    "UIBAK": "UltraISO Backup Disk Image",
    "UIF": "Universal Image Format Disc Image",
    "UIS": "WindowBlinds User Interface Specification",
    "UKX": "Unreal Animation Package",
    "ULD": "Unified Luminaire Data File",
    "ULF": "Universal List File",
    "ULS": "NetMeeting User Location Service File",
    "ULT": "UltraTracker Module",
    "ULZ": "USBlyzer Data Capture File",
    "UMD": "Splinter Cell Blacklist Game Data File",
    "UML": "UML Data Object Model",
    "UMOD": "Unreal Tournament Module File",
    "UMS": "Rune 3D Mesh File",
    "UMX": "Unreal Music Package",
    "UNAUTH": "SiteMinder Unauthorized Message File",
    "UNF": "UNIF ROM File",
    "UNI": "MikMod UniMOD Module",
    "UNITY": "Unity Scene File",
    "UNITY3D": "Unity Web Player Archive",
    "UNITYPROJ": "Unity 3D Project",
    "UNKNOWN": "Unknown File Type",
    "UNL": "Garmin Unlock File",
    "UNR": "Unreal Level Map",
    "UNT": "AutoCAD Unit Definition File",
    "UNX": "Unix Text File",
    "UOF": "Uniform Office Document",
    "UOS": "Uniform Office Spreadsheet",
    "UOT": "Uniform Office Document",
    "UPD": "Program Update Information",
    "UPF": "Panono Unstitched Panorama Format",
    "UPG": "Upgrade File",
    "UPK": "Unreal Engine 3 Package",
    "UPOI": "iGO Points of Interest File",
    "UPS": "UPS Patch File",
    "UPX": "Ultimate Packer for eXecutables File",
    "URL": "Internet Shortcut",
    "URT": "Utah Raster Toolkit File",
    "USA": "Unreal Saved Game File",
    "USERPROFILE": "Norton AntiVirus User Profile File",
    "USERTILE-MS": "Windows 8 User Tile File",
    "USF": "Nintendo 64 Music File",
    "USFLIB": "Nintendo 64 Song Library",
    "USM": "USM Game Video File",
    "USR": "SmartMusic Custom File",
    "UST": "UTAU Sequence Text File",
    "USX": "Unreal Static Meshes",
    "UT2": "Unreal Tournament Map",
    "UT2MOD": "Unreal Tournament 2003/2004 Module File",
    "UT3": "Unreal Tournament 3 Map File",
    "UT4MOD": "Unreal Tournament 2004 Module",
    "UTC": "Bioware Creature File",
    "UTF8": "Unicode UTF8-Encoded Text Document",
    "UTX": "Unreal Texture Package",
    "UTXT": "Unicode Text File",
    "UTZ": "UIQ Theme Package",
    "UU": "Uuencoded File",
    "UUD": "UUDecoded File",
    "UUE": "Uuencoded File",
    "UVX": "Unreal Tournament 2003 Saved Game",
    "UW": "Unsigned Word Audio File",
    "UWF": "UltraTracker Wave File",
    "UWL": "User Word List File",
    "UXF": "UML eXchange Format",
    "UXX": "Unreal Tournament Cache",
    "UZIP": "FreeBSD Compressed Disk Image",
    "V": "Subsampled Raw YUV Image",
    "V11.SUO": "Visual Studio 2012 Solution User Options File",
    "V12": "All The Right Type Database File",
    "V12.SUO": "Visual Studio 2013 Solution User Options File",
    "V264": "v264 IPROBOT3 Video File",
    "V2I": "Norton Ghost Virtual Volume Image",
    "V3D": "Visual3D.NET Data File",
    "V3O": "Emergency 3 and 4 Model File",
    "V3V": "Vector Art 3D Model File",
    "V64": "Nintendo 64 ROM Dump",
    "VAC": "MikuMikuDance Accessory Settings File",
    "VAG": "PlayStation Compressed Sound File",
    "VAP": "Dialogic Indexed Voice Audio File ",
    "VAPORCD": "Norum Vapor CD",
    "VB": "Visual Basic Project Item File",
    "VBC": "VodBurner Crude Video File",
    "VBD": "Visual Basic ActiveX Document",
    "VBE": "VBScript Encoded Script File",
    "VBG": "Visual Basic Project Group File",
    "VBHTML": "ASP.NET Razor Web Page",
    "VBK": "VitalSource eBook",
    "VBM": "Veeam Backup Metadata File",
    "VBOX": "Oracle VM VirtualBox Settings File",
    "VBOX-EXTPACK": "Oracle VM VirtualBox Extension Pack",
    "VBOX-PREV": "Oracle VM VirtualBox Settings Backup File",
    "VBP": "Visual Basic Project File",
    "VBPROJ": "Visual Studio Visual Basic Project",
    "VBR": "GIMP Parametric Brush File",
    "VBS": "VBScript File",
    "VBSCRIPT": "Visual Basic Script",
    "VBT": "Spyware Doctor Temporary Scan File",
    "VBX": "Visual Basic Custom Control",
    "VBX6SETTINGS": "VirusBarrier X6 Settings File",
    "VBZ": "Visual Basic Project Template",
    "VC": "Verge Code File",
    "VC1": "VC-1 Video File",
    "VC3": "VSampler Soundbank File",
    "VC4": "Virtual CD Disc Image",
    "VC6": "Virtual CD 6 CD Image",
    "VC8": "Virtual CD 8 Disc Image",
    "VCD": "Virtual CD",
    "VCE": "Visual CertExam Exam File",
    "VCF": "vCard File",
    "VCM": "Vice City Mod Manager File",
    "VCO": "Virtual CD Collection File",
    "VCOMPS": "V-Comp Setup File",
    "VCP": "eMbedded Visual C++ Project File",
    "VCPF": "VideoConvert Project File",
    "VCPREF": "Norton Antivirus Preferences File",
    "VCPROJ": "Visual C++ Project File",
    "VCR": "ATI Video Card Recording",
    "VCS": "vCalendar Event File",
    "VCT": "Visual Class Library Memo",
    "VCV": "ViewCave Video File",
    "VCX": "Virtual Disc Definition File",
    "VCXPROJ": "Visual C++ Project",
    "VDA": "Targa Bitmap Image File",
    "VDATA": "Vaulty Vault File",
    "VDB": "Symantec Virus Database File",
    "VDC": "IDRISI Vector Documentation File",
    "VDF": "AntiVir Virus Definitions File",
    "VDI": "VirtualBox Virtual Disk Image",
    "VDJ": "VirtualDJ Audio Sample File",
    "VDM": "VDM Specification File",
    "VDO": "VDOLive Media File",
    "VDP": "Visual Studio Deployment Project",
    "VDPROJ": "Visual Studio Setup and Deployment Project",
    "VDR": "VirtualDub Signpost File",
    "VDW": "Visio Web Drawing",
    "VDX": "Visio Drawing XML File",
    "VEC": "CX-Designer Shape File",
    "VEG": "VEGAS Video Project",
    "VEM": "Meta Media Video E-Mail File",
    "VEP": "AVS Video Editor Project File",
    "VERT": "Vertex Shader File",
    "VET": "Lectra Cutter's Must File",
    "VEXE": "Virus Executable File",
    "VF": "VEGAS Movie Studio Project File",
    "VFB": "FontLab Studio Font File",
    "VFC": "VentaFax Cover Page File",
    "VFD": "Virtual Floppy Disk",
    "VFF": "Sun TAAC Graphic File",
    "VFS": "Animated Slide File",
    "VFS0": "Metro 2033 Sound File",
    "VFT": "VideoStudio Filter File",
    "VFW": "Video for Windows",
    "VFZ": "Creative Webcam Video Effects File",
    "VGA": "VGA Display Driver",
    "VGC": "ViziGen Code Generation Template",
    "VGD": "Generic CADD VGA Driver",
    "VGM": "Video Game Music File",
    "VGZ": "Video Game Music Compressed File",
    "VHD": "Virtual PC Virtual Hard Disk",
    "VHDX": "Windows 8 Virtual Hard Drive File",
    "VI": "LabVIEW Virtual Instrument File",
    "VIC": "VICAR Image",
    "VICAR": "VICAR Image File",
    "VID": "Generic Video File",
    "VIDEO": "aTube Catcher Video File",
    "VIEWLET": "Qarbon Viewlet",
    "VIFF": "Visualization Image File Format",
    "VIIVO": "Viivo Encrypted File",
    "VIM": "Vim Settings File",
    "VIMRC": "Vim Runtime Configuration File",
    "VIP": "MAGIX Samplitude Music Studio Project",
    "VIR": "Virus-Infected File",
    "VIS": "Visual Importer Script",
    "VISUAL": "World of Tanks 3D Model Surface File",
    "VISUAL_PROCESSED": "World of Tanks 3D Model Surface File",
    "VIV": "VivoActive Video File",
    "VIVO": "VivoActive Video File",
    "VIX": "Lightworks Video Index File",
    "VLAB": "VisionLab Studio Project File",
    "VLC": "VLC Playlist",
    "VLP": "LiveSite Project",
    "VLT": "VLC Media Player Skin File",
    "VLW": "Processing Font File",
    "VLX": "Compiled AutoLISP File",
    "VM": "Velocity Template",
    "VMC": "Windows Virtual Machine Configuration File",
    "VMCX": "Virtual Machine Shell Information File",
    "VMCZ": "Hyper-V Compressed Virtual Machine",
    "VMD": "Covox Raw Sample",
    "VMDK": "Virtual Machine Disk File",
    "VMDK-CONVERTTMP": "VMWare Fusion Temporary File",
    "VMF": "Vocaltec Media File",
    "VMF_AUTOSAVE": "Valve Hammer Editor Autosave File",
    "VMG": "Nokia Text Message",
    "VMHF": "VMware Hot Fix File",
    "VMHR": "VMware Hot Fix Request File",
    "VML": "Vector Markup Language File",
    "VMLF": "VAIO Video File",
    "VMLT": "VAIO Video File",
    "VMO": "Siemens Voice Memo File",
    "VMPL": "VMware Policy File",
    "VMT": "Valve Material File",
    "VMTM": "VMware Team Data File",
    "VMV": "VisualBoyAdvance Recording",
    "VMWAREVM": "VMware Fusion Virtual Machine",
    "VMX": "VMware Configuration File",
    "VMXF": "VMware Team Member File",
    "VNA": "JVC JLIP Image",
    "VNC": "VNC Configuration File",
    "VNCLOC": "Screen Sharing VNC Internet Location",
    "VND": "Type3 Design File",
    "VNF": "Vision Numeric Font",
    "VNT": "Mobile Phone vNote File",
    "VOB": "DVD Video Object File",
    "VOC": "Creative Labs Audio File",
    "VOCA": "PhotoVOCA Communication Board File",
    "VOK": "PocketVok Vocabulary File",
    "VOL": "Video Game Archive",
    "VOLARCHIVE": "CopyCatX Volume Archive",
    "VOR": "StarOffice Template",
    "VOX": "Dialogic Voice Audio File",
    "VOXAL": "Voxal Project File",
    "VP": "Vertex Program File",
    "VP3": "On2 Streaming Video File",
    "VP6": "TrueMotion VP6 Video File",
    "VP7": "TrueMotion VP7 Video File",
    "VPA": "VPchat Chat Gestures File",
    "VPC6": "Virtual Machine Package",
    "VPC7": "Virtual Machine Package",
    "VPCBACKUP": "Windows Virtual PC Backup File",
    "VPD": "MikuMikuDance Vocaloid Pose Data File",
    "VPE": "Photoshop Vanishing Point Export File",
    "VPH": "VirtualPhotographer Custom Settings",
    "VPJ": "VideoPad Video Editor Project File",
    "VPK": "Valve Pak",
    "VPL": "Karaoke Player Playlist",
    "VPM": "Garmin Voice File",
    "VPR": "VOCALOID5 Project File",
    "VPS": "Virtual CD Copy Template",
    "VPW": "VoxPro Wave File",
    "VQC": "Virtual CD Quick Copy File",
    "VQF": "TwinVQ Audio File",
    "VR": "VR Studio Project File",
    "VRB": "Veeam Incremental Backup File",
    "VRD": "Visio Report Definition File",
    "VRF": "Ventrilo Audio Recording",
    "VRIMG": "V-Ray Image File",
    "VRL": "VRML Virtual World",
    "VRML": "VRML File",
    "VRO": "DVD Video Recording Format",
    "VRPHOTO": "VR Photo Image",
    "VRT": "Virtual World",
    "VS": "Vertex Shader File",
    "VS4": "AVTECH CCTV Video Surveillance File",
    "VSD": "Visio Drawing File",
    "VSDISCO": "DISCO Dynamic Discovery Document",
    "VSDM": "Visio Macro-Enabled Drawing",
    "VSDX": "Visio Drawing",
    "VSE": "AVTECH CCTV Video",
    "VSH": "VideoStudio HTML5 Project File",
    "VSI": "Visual Studio Content Installer File",
    "VSIX": "Visual Studio Extension",
    "VSL": "Visio Add-on",
    "VSMACROS": "Visual Studio Binary Macro Project",
    "VSMDI": "Visual Studio Test Metadata File",
    "VSMPROJ": "Visual Studio Text Macro Project",
    "VSO": "Compiled Vertex Shader File",
    "VSP": "VideoStudio Project File",
    "VSPROPS": "Visual Studio Project Property File",
    "VSPS": "Visual Studio Serialized Performance Report",
    "VSPSCC": "Visual Studio Project Source Control File",
    "VSPX": "Visual Studio Performance Report Data File",
    "VSQ": "VOCALOID2 Project File",
    "VSQX": "VOCALOID3 Project File",
    "VSS": "Visio Stencil File",
    "VSSETTINGS": "Visual Studio Settings File",
    "VSSSCC": "Visual Studio Solution Source Control File",
    "VST": "Targa Bitmap Image",
    "VST3": "VST 3 Audio Plugin",
    "VSTM": "Visio Macro-Enabled Drawing Template",
    "VSTPRESET": "VST Preset File",
    "VSTX": "Visio Drawing Template",
    "VSX": "Visio Stencil XML File",
    "VSZ": "Visual Studio Wizard File",
    "VTF": "Valve Texture File",
    "VTM": "Visual Tool Markup Language Document",
    "VTML": "Visual Tool Markup Language File",
    "VTPR": "Studio Store Visualizer Project",
    "VTT": "Web Video Text Tracks File",
    "VTV": "Adobe Dreamweaver Validator Configuration File",
    "VTX": "Visio Template XML File",
    "VUE": "Vue Scene File",
    "VVD": "Vivid 3D Scanner Element File",
    "VVV": "Virtual Volumes View Catalog",
    "VW": "Volkswriter Text File",
    "VWX": "Vectorworks Design File",
    "VXD": "Virtual Device Driver",
    "VXML": "VoiceXML File",
    "VXP": "Mobile Application File",
    "VX_": "Compressed Virtual Device Driver File",
    "VYF": "Samsung Digital Voice Recorder File",
    "W": "OpenEdge Architect Source Code File",
    "W01": "Yamaha SY Series Wave File",
    "W32": "WinCAPs Subtitle File",
    "W3D": "Adobe Shockwave 3D File",
    "W3G": "Warcraft 3 Replay File",
    "W3M": "Warcraft 3 Map File",
    "W3N": "Warcraft 3 Expansion Campaign Map File",
    "W3X": "Warcraft 3 Expansion Map FIle",
    "W3Z": "Warcraft 3 Saved Game File",
    "W64": "Sony Wave64 Audio File",
    "WA": "Windows Addon Archive",
    "WAB": "Windows Address Book",
    "WAD": "Doom WAD File",
    "WAFF": "Internet Explorer for Mac Web Archive",
    "WAGAME": "Worms Armageddon Game Recording",
    "WAL": "Quake 2 Texture File",
    "WALLET": "Wallet Ransomware",
    "WALLETX": "Enpass Data File",
    "WAM": "Worms Armageddon Mission File",
    "WAR": "Java Web Archive",
    "WARC": "Web Archive",
    "WASTICKERS": "Sticker Maker Sticker Pack File",
    "WAV": "WAVE Audio File",
    "WAVE": "WAVE Sound File",
    "WAX": "Windows Media Audio Redirect",
    "WB0": "Webshots Picture File",
    "WB1": "Webshots Picture File",
    "WB2": "Corel Quattro Pro File",
    "WB3": "Corel Quattro Pro 7 and 8 File",
    "WBA": "WindowBlinds Compressed Skin",
    "WBB": "WinBackup Archive",
    "WBC": "Webshots Collection File",
    "WBCAT": "Windows Backup Catalog File",
    "WBD": "Webshots Picture File",
    "WBI": "Compact ISO File",
    "WBK": "WordPerfect Workbook",
    "WBM": "Wireless Bitmap Image",
    "WBMP": "Wireless Bitmap Image File",
    "WBP": "Webshots Collection File",
    "WBS": "WebBlender Project File",
    "WBT": "Toribash Help File",
    "WBXML": "WAP Binary XML File",
    "WBZ": "Webshots Download Picture File",
    "WC": "Valve Hammer Configuration File",
    "WCM": "WordPerfect Macro",
    "WCP": "WinDVD Creator Project File",
    "WCRY": "WannaCry Virus Encrypted File",
    "WCX": "RemoteApp and Desktop Connections Configuration File",
    "WCZ": "Chameleon Clock Wallpaper File",
    "WDB": "Microsoft Works Database",
    "WDF": "Workshare Compare DeltaFile",
    "WDGT": "Opera Widget",
    "WDGTPROJ": "Dashcode Widget Project",
    "WDL": "World Definition Language Script",
    "WDP": "Windows Media Photo File",
    "WDSEML": "Thunderbird Searchable Email File",
    "WDW": "WinDev Window File",
    "WDZ": "WDZip Compressed Archive",
    "WEA": "Ecotect Weather File",
    "WEB": "Xara Web Document",
    "WEBARCHIVE": "Safari Web Archive",
    "WEBARCHIVEXML": "Android Web Browser Archive",
    "WEBBOOKMARK": "Safari Web Bookmark File",
    "WEBDOC": "Box.net Web Document",
    "WEBHISTORY": "Safari Web History File",
    "WEBLOC": "macOS Website Location",
    "WEBM": "WebM Video File",
    "WEBP": "WebP Image",
    "WEBPNP": "Web Point and Print File",
    "WEBSITE": "Internet Explorer Pinned Site Shortcut",
    "WEBTEMPLATE": "iWeb Template ",
    "WEBTHEME": "iWeb Theme Template ",
    "WEBZ": "WEBZ Compressed eBook File",
    "WEM": "Wwise Encoded Media File",
    "WER": "Windows Error Report",
    "WERD": "Werd Ransomware Encrypted File",
    "WFB": "WaveFront Sound Bank",
    "WFC": "Windows Wireless Network Settings File ",
    "WFD": "WaveFront Drum Kit File",
    "WFM": "Pro Tools Wave Cache File",
    "WFP": "WaveFront Program File",
    "WFSP": "Wondershare Fantashow Project",
    "WFT": "GTA 4 Car Model File",
    "WGI": "Wildgame Innovations Video File",
    "WGP": "Web Gallery Project",
    "WGT": "XNBC Synaptic Weights File",
    "WGZ": "S60 Web Runtime Widget Package",
    "WHIRLD": "Unity Whirld Package",
    "WHL": "Python Wheel Package",
    "WHTT": "HTTrack Website Copier File",
    "WI": "Wavelet Image",
    "WIC": "J Wavelet Image",
    "WIDGET": "Microsoft Windows Mobile Widget",
    "WIE": "WordPress Widget Export File",
    "WIF": "Weaving Interchange Format File",
    "WII": "Scrambled Wii Disc Image",
    "WIL": "WinImage Disk Image List",
    "WIM": "Windows Imaging Format File",
    "WIN": "Windows Backup File",
    "WINCLONE": "Winclone Image",
    "WINDOWSLIVECONTACT": "Windows Live Contacts File",
    "WIQ": "Visual Studio Work Item Query File",
    "WIXLIB": "WiX Library File",
    "WIXMSP": "WiX XML Patch File",
    "WIXMST": "WiX Transform File",
    "WIXOBJ": "WiX Object File",
    "WIXOUT": "WiX XML Output File",
    "WIXPDB": "WiX Debug File",
    "WIXPROJ": "WiX Project File",
    "WIZ": "Microsoft Wizard File",
    "WJE": "WinJournal Entry",
    "WJF": "WinZip Job File",
    "WJR": "ReGet Deluxe Data File",
    "WKI": "Lotus 2 Worksheet",
    "WKQ": "Quattro Pro for DOS Spreadsheet File",
    "WKS": "Works Spreadsheet",
    "WKU": "Lotus 1-2-3 Spreadsheet",
    "WL6": "Wolfenstein 3D Data File",
    "WLB": "WinList Protocol Bundle",
    "WLD": "Terraria World File",
    "WLL": "Microsoft Word Add-in",
    "WLMP": "Windows Live Movie Maker Project File",
    "WLP": "Worldlabel.com Label Designer File",
    "WLS": "R-Link Update File",
    "WLU": "Jaff Ransomware Encrypted File",
    "WLVS": "Windows Movie Maker Video Settings File",
    "WLX": "MapSource Web Link File",
    "WLZ": "Winamp Language Pack",
    "WM": "Windows Media File",
    "WMA": "Windows Media Audio File",
    "WMD": "Windows Media Download Package",
    "WMDB": "Windows Media Database File",
    "WME": "Windows Media Encoder Session File",
    "WMF": "Windows Metafile",
    "WMGA": "Web Manga Document",
    "WML": "Wireless Markup Language File",
    "WMMP": "Windows Movie Maker Project File",
    "WMO": "World of Warcraft World Map Object",
    "WMP": "Windows Media Photo File",
    "WMS": "Windows Media Skin",
    "WMT": "WinMount Virtual Disk File",
    "WMV": "Windows Media Video File",
    "WMX": "Windows Media Redirector File",
    "WMZ": "Compressed Windows Metafile",
    "WN": "WriteNow Text Document",
    "WNCRY": "Wana Decrypt0r 2.0 Encrypted File",
    "WNK": "Wink Presentation",
    "WNRY": "WannaCry Virus Encrypted File",
    "WOA": "WebObjects Application",
    "WOFF": "Web Open Font Format File",
    "WOFF2": "Web Open Font Format 2.0 File",
    "WOLF": "Wolf RPG Editor Game Data Archive",
    "WOR": "MapInfo Workspace File",
    "WORDLIST": "Desktop Poet Word List File",
    "WORK": "Bibble Work Queue File",
    "WORKFLOW": "Automator Workflow",
    "WORKSPACE": "Code::Blocks Workspace File",
    "WORLD": "WorldPainter File",
    "WOT": "WebEx Recording File",
    "WOTREPLAY": "World of Tanks Replay File",
    "WOW": "Grave Composer Music Module",
    "WOWSL": "WOW Slider",
    "WOWSREPLAY": "World of Warships Replay File",
    "WOZ": "Apple II Disk Image",
    "WP": "WordPerfect Document",
    "WP3": "Microsoft Photo Story Project File",
    "WP4": "WordPerfect 4 Document",
    "WP5": "WordPerfect 5 Document",
    "WP6": "WordPerfect 6 Document",
    "WP7": "WordPerfect 7 Document",
    "WPA": "ACT! Word Processing Document",
    "WPB": "openCanvas 1.1 Image",
    "WPC": "WordPad Converter File",
    "WPD": "WordPerfect Document",
    "WPE": "openCanvas 1.1 Event File",
    "WPG": "WordPerfect Graphic File",
    "WPH": "Phoenix BIOS File",
    "WPI": "Inkling Sketch Binary File",
    "WPK": "Nero Wave Editor File",
    "WPL": "DEC WPS Plus Text Document",
    "WPM": "WordPerfect Macro File",
    "WPP": "WavePad Project File",
    "WPROJ": "Wwise Project File",
    "WPS": "Microsoft Works Word Processor Document",
    "WPT": "WordPerfect Template",
    "WPW": "WP Works Word Processor File",
    "WPX": "WebPlus Project Template",
    "WQ1": "Quattro Pro for DOS Spreadsheet File",
    "WQ2": "Quattro Pro for DOS Spreadsheet File",
    "WR1": "Lotus Symphony Worksheet File",
    "WRF": "WebEx Recording",
    "WRI": "Microsoft Write Document",
    "WRK": "Cakewalk Music Project",
    "WRL": "VRML World",
    "WRP": "Geomagic 3D Wrap File",
    "WRTS": "Wrts File",
    "WRYPT": "Panwrypter Depleted Storage Volume File",
    "WRZ": "Compressed VRML World File",
    "WS": "Windows Script",
    "WSC": "Windows Script Component",
    "WSD": "WordStar Document",
    "WSDL": "Web Services Description Language File",
    "WSF": "Windows Script File",
    "WSH": "Windows Script Host Settings",
    "WSP": "SharePoint Solution Package",
    "WSPAK": "WebsitePanel Backup File",
    "WSVE": "Wondershare Filmora for Mac Project File",
    "WSZ": "Winamp Classic Skin",
    "WTB": "Win-Test Binary Log File",
    "WTC": "Logitech Webcam File",
    "WTD": "Grand Theft Auto IV Textures File",
    "WTF": "World of Warcraft Text File",
    "WTPL": "WireTap Studio Library",
    "WTPT": "WireTap Studio Packaged Track",
    "WTT": "Write! Document",
    "WTV": "Windows Recorded TV Show File",
    "WTX": "Text Document",
    "WU8": "Wiimm U8 Mario Kart Wii Archive",
    "WUD": "Wii U Disk Image File",
    "WUS": "WUTG Tagged Audio File",
    "WUT": "WUTG Tag File",
    "WUX": "Compressed Wii U Disk Image File",
    "WV": "WavPack Audio File",
    "WVC": "WavPack Correction File",
    "WVE": "WaveEditor Project File",
    "WVL": "Wavelet Image",
    "WVM": "Google Play Video File",
    "WVX": "Windows Media Video Redirector",
    "WWD": "Works Wizard File",
    "WWF": "World Wide Fund Non-Printable Document",
    "WWU": "Wwise Work Unit",
    "WX": "Wanam Xposed Backup File",
    "WXI": "WiX Include File",
    "WXL": "WiX Localization File",
    "WXP": "Wax 2.0 Project",
    "WXS": "WiX Source File",
    "WZ": "MapleStory Game Data File",
    "WZCONFIG": "WinZip Configuration File",
    "WZMUL": "WinZip Registration File",
    "X": "DirectX Model File",
    "X32": "Adobe Xtra File",
    "X3D": "Xara3D Project",
    "X3F": "SIGMA X3F Camera RAW File",
    "X3G": "3D Print File",
    "X64": "Commodore 64 Disk Image",
    "X86": "Linux Executable File",
    "XA": "The Sims Audio File",
    "XADD": "Expression Web Add-in",
    "XAF": "3ds Max XML Animation File",
    "XAML": "XAML File",
    "XAMLX": "Visual Studio Workflow Service File",
    "XAP": "Silverlight Application Package",
    "XAPK": "Compressed Android Package File",
    "XAR": "Xara Xtreme Drawing",
    "XBA": "OpenOffice.org Basic Module File",
    "XBAP": "XAML Browser Application File",
    "XBDOC": "Xiosis Scribe Document",
    "XBE": "Xbox Executable File",
    "XBEL": "XBEL Bookmarks File",
    "XBK": "XenServer Backup File",
    "XBL": "Extensible Binding Language File",
    "XBM": "X11 Bitmap Graphic",
    "XBPLATE": "Xiosis Scribe Template",
    "XCAPPDATA": "Xcode App Data File",
    "XCARCHIVE": "Xcode Archive",
    "XCCONFIG": "Xcode Configuration Settings File",
    "XCDATAMODELD": "Xcode Core Data Model File",
    "XCF": "GIMP Image File",
    "XCI": "NX Card Image File",
    "XCODEPLUGIN": "Xcode Plug-in",
    "XCODEPROJ": "Xcode Project",
    "XCPLUGIN": "Xcode Plug-in",
    "XCSNAPSHOTS": "Xcode Snapshot",
    "XCU": "OpenOffice.org Configuration File",
    "XCWORKSPACE": "Xcode Workspace File",
    "XDB": "Symantec Virus Database File",
    "XDI": "WinArchiver Extended Disc Image File",
    "XDL": "XML Schema File",
    "XDNA": "DNA Strider Sequence File",
    "XDR": "XML-Data Reduced File",
    "XDS": "DS Game Maker Project File",
    "XDW": "Fuji Xerox DocuWorks File",
    "XEF": "WinAce Encrypted File",
    "XEJ": "Expression Encoder Job File",
    "XEL": "Expression Encoder Live Encoding File",
    "XEM": "PowerDesigner Model definition File",
    "XEN": "Guitar Hero III Data File",
    "XENSEARCH": "XenCenter Saved Search File",
    "XESC": "Expression Encoder Screen Capture File",
    "XEX": "Xbox 360 Executable File",
    "XEZ": "eManager Template Package",
    "XFB": "Xserve RAID Firmware Binary File",
    "XFD": "XFD File",
    "XFDF": "Adobe Acrobat XFDF File",
    "XFDL": "XFDL File",
    "XFL": "Animate Movie Archive",
    "XFN": "Ventura Printer Font",
    "XFS": "eRacer Sound File",
    "XFT": "Adobe Form Designer 5.0 File",
    "XHT": "XHTML File",
    "XHTM": "Extensible Hypertext Markup Language Document",
    "XHTML": "Extensible Hypertext Markup Language File",
    "XIB": "Interface Builder File",
    "XIF": "ScanSoft Pagis File",
    "XIP": "macOS Signed Archive",
    "XISE": "Xilinx ISE Project File",
    "XL": "Excel Spreadsheet",
    "XLA": "Excel Add-In File",
    "XLAM": "Excel Open XML Macro-Enabled Add-In",
    "XLB": "Excel Toolbars File",
    "XLC": "Excel Chart",
    "XLD": "Excel Database File",
    "XLF": "XLIFF Document",
    "XLK": "Excel Backup File",
    "XLL": "Excel Add-In File",
    "XLM": "Excel Macro",
    "XLMV": "Xunlei Movie File",
    "XLNK": "XML Shortcut File",
    "XLR": "Works Spreadsheet",
    "XLS": "Excel Spreadsheet",
    "XLSB": "Excel Binary Spreadsheet",
    "XLSHTML": "Microsoft Excel HTML Spreadsheet",
    "XLSM": "Excel Open XML Macro-Enabled Spreadsheet",
    "XLSMHTML": "Microsoft Excel MIME HTML Spreadsheet",
    "XLSX": "Microsoft Excel Open XML Spreadsheet",
    "XLT": "Excel Template",
    "XLTHTML": "Microsoft Excel HTML Spreadsheet Template",
    "XLTM": "Excel Open XML Macro-Enabled Spreadsheet Template",
    "XLTX": "Excel Open XML Spreadsheet Template",
    "XLV": "Excel Visual Basic Module",
    "XLW": "Excel Workspace File",
    "XM": "Fasttracker 2 Extended Module",
    "XMB": "Age of Empires Game Data File",
    "XMCD": "Mathcad Worksheet File",
    "XMCDZ": "Mathcad Compressed Worksheet File",
    "XMD": "Bitdefender Plugin File",
    "XMDX": "ExamSoft Answer File",
    "XMF": "Extensible Music File",
    "XML": "XML File",
    "XMLFF": "XML Flat File",
    "XMLPER": "LeCroy Binary Waveform File",
    "XMM": "3ds Max XML Animation Map File",
    "XMMAP": "MindManager XML Map File",
    "XMP": "Extensible Metadata Platform File",
    "XMS": "Music Studio Project",
    "XMT": "XMind Template",
    "XMU": "Expressive Music Container File",
    "XMV": "Xbox Media Video File",
    "XNB": "XNA Game Studio Binary Package",
    "XNC": "Exchange NC File",
    "XNK": "Exchange Shortcut",
    "XNT": "QuarkXPress Extension File",
    "XOF": "Reality Lab 3D Image File",
    "XOJO_BINARY_PROJECT": "Xojo Binary Project File",
    "XOJO_MENU": "Xojo Menu File",
    "XOJO_PROJECT": "Xojo Project File",
    "XOJO_XML_PROJECT": "Xojo XML Project File",
    "XOL": "Swiss Map Overlay",
    "XOM": "Worms 3D Object File",
    "XOML": "Windows Workflow File",
    "XP3": "KiriKiri Package File",
    "XPADDERCONTROLLER": "Xpadder Controller Profile",
    "XPD": "PlayStation Store PSP License File",
    "XPG": "Autoplay Media Studio Exported Page",
    "XPI": "Cross-platform Installer Package",
    "XPJ": "RoboHelp HTML Project File",
    "XPK": "WWE RAW Model File",
    "XPL": "LcdStudio Playlist File",
    "XPM": "X11 Pixmap Graphic",
    "XPP": "X++ Source Code File",
    "XPR": "Pro/ENGINEER Part Instance Accelerator File",
    "XPS": "XML Paper Specification File",
    "XPT": "SAS Transport File",
    "XQ": "XQuery File",
    "XQL": "XML Query Language File",
    "XQM": "XQuery Module",
    "XQT": "SuperCalc Macro File",
    "XQUERY": "XQuery Source Code File",
    "XRDML": "XRDML Data File",
    "XRF": "Cal3D XML Materials File",
    "XRM-MS": "Microsoft Security Certificate",
    "XRNS": "Renoise Song File",
    "XRP": "RationalPlan Project File",
    "XS": "Age of Empires 3 Map AI Generator",
    "XSD": "XML Schema Definition",
    "XSF": "Cal3D XML Skeleton File",
    "XSI": "Softimage XSI 3D Image",
    "XSIADDON": "Softimage Add-on File",
    "XSL": "XML Style Sheet",
    "XSLIC": "XenServer License File",
    "XSLT": "XSL Transformation File",
    "XSN": "InfoPath Form Template File",
    "XSP": "Kodi Smart Playlist File",
    "XSPF": "XSPF Playlist File",
    "XSS": "XML Style Sheet",
    "XST": "WebSphere Query Template",
    "XT": "Xdebug Trace File",
    "XTBL": "XTBL Ransomware Encrypted File",
    "XTODVD": "ConvertXtoDVD Project File",
    "XTP": "InfoPath Template Part File",
    "XTREME": "Winstep Xtreme Theme Pack",
    "XUI": "Xbox 360 User Interface File",
    "XUL": "XML User Interface Language File",
    "XUR": "Xbox 360 Binary User Interface File",
    "XV0": "Lattice XVL Structure File",
    "XV3": "Lattice XVL Geometry File",
    "XVA": "XenServer Virtual Appliance File",
    "XVD": "Xbox Virtual Disk",
    "XVID": "Xvid-Encoded Video File",
    "XVM": "VMware Console Configuration File",
    "XWD": "X Windows Dump Image",
    "XWF": "OmniPage Workflow File",
    "XWP": "XMLwriter Project",
    "XWS": "Xara Web Designer Graphic",
    "XX": "XXEncoded File",
    "XXE": "XXEncoded File",
    "XXX": "Extractor Ransomware Encrypted File",
    "XY": "XYWrite Document",
    "XY3": "XYWrite III Document",
    "XYP": "XYWrite Plus Document",
    "XYS": "XYplorer Script File",
    "XYW": "XYWrite for Windows Document",
    "XZ": "XZ Compressed Archive",
    "XZFX": "ZipLogix ZipForm File",
    "XZM": "Porteus Module",
    "X_B": "Parasolid Model Part File",
    "X_T": "Parasolid Model Part File",
    "Y": "Subsampled Raw YUV Image",
    "Y4M": "YUV4MPEG2 Video File",
    "YAL": "Arts & Letters Clipart Library",
    "YAML": "YAML Document",
    "YAODL": "PowerFlip 3D Image File",
    "YBD": "YobiDrive Link File",
    "YBK": "YanCEyWare eBook",
    "YCM": "Yugioh Card Maker File",
    "YDC": "Yu-Gi-Oh! Card Deck File",
    "YDK": "Yu-Gi-Oh! Deck File",
    "YDL": "PowerFlip YAODL 3D Image File",
    "YDR": "YouiDraw Drawing Project",
    "YENC": "yEnc File",
    "YKCOL": "Locky Ransomware Encrypted File",
    "YML": "YAML Document",
    "YMP": "YaST Metapackage File",
    "YNC": "yEnc Encoded File",
    "YOG": "Outerra Captured Video File",
    "YOOKOO": "Yookoo Player Playlist File",
    "YPR": "BYOB Project File",
    "YPS": "Yahoo! Messenger Data File",
    "YRCBCK": "YRC Backup Archive",
    "YSP": "BYOB Sprite File",
    "YTF": "Google Picasa Font Cache",
    "YUV": "YUV Encoded Image File",
    "YZ": "YAC Compressed File",
    "YZ1": "Yamazaki ZIPPER File",
    "Z": "Unix Compressed File",
    "Z01": "First Split Zip File",
    "Z02": "Second Split Zip File",
    "Z03": "Third Split Zip File",
    "Z04": "Fourth Split Zip File",
    "Z1": "ZoneAlarm Renamed VB File",
    "Z2F": "Zoo Tycoon 2 Object File",
    "Z3": "Z-machine Z-code Version 3 File",
    "Z3D": "ZModeler 3D File",
    "Z4": "Z-machine Z-code Version 4 File",
    "Z5": "Z-machine Z-code Version 5 File",
    "Z64": "Nintendo 64 Game ROM",
    "Z80": "TI-83 and 84 Plus Calculator File",
    "ZABW": "Compressed AbiWord Document File",
    "ZAP": "ZoneAlarm Pro Data File",
    "ZBFX": "zebNet Backup File Extended",
    "ZBLORB": "Z-machine Package Game File",
    "ZDC": "CD Catalog Expert Database File",
    "ZDL": "Avery DesignPro Label File",
    "ZDP": "Avery DesignPro Label File",
    "ZDS": "DesignPro Label File",
    "ZEG": "ZeroG Subtitles File",
    "ZEPTO": "Zepto Virus File",
    "ZFO": "XSL-FO Online Form",
    "ZFSENDTOTARGET": "Compressed Folder",
    "ZFX": "ZipForm File",
    "ZGM": "Zenographics Image File",
    "ZHTML": "Secure IE Zipped HTML File",
    "ZI": "Renamed Zip File",
    "ZIF": "Zooming Image Format File",
    "ZIP": "Zipped File",
    "ZIPX": "Extended Zip File",
    "ZIX": "WinZix Compressed File",
    "ZI_": "Renamed Zip File",
    "ZL": "Zlib Compressed File",
    "ZL9": "ZoneAlarm Quarantined EXE File",
    "ZLB": "Form\u2022Z Symbol Library File",
    "ZM1": "ZSNES Movie #1 File",
    "ZM2": "ZSNES Movie #2 File",
    "ZM3": "ZSNES Movie #3 File",
    "ZM9": "ZoneAlarm MailSafe Renamed Zip File",
    "ZMAP": "Zombies Ate My Neighbors Map File",
    "ZMC": "ZoneAlarm Quarantine File",
    "ZML": "Zooming Markup Language File",
    "ZMV": "ZSNES Movie File",
    "ZNO": "Zinio Electronic Magazine File",
    "ZON": "OmniPage Zone Template File",
    "ZONE.IDENTIFIER": "Windows Zone Identifier File",
    "ZOO": "Zoo Compressed File",
    "ZPA": "Vielklang Audio Metadata File",
    "ZPF": "Form\u2022Z Preferences File",
    "ZPI": "PDF Converter Index File",
    "ZPL": "Zune Playlist",
    "ZPS": "Zebra Portable Safe File",
    "ZRTF": "Nisus Compressed Rich Text File",
    "ZS0": "ZSNES Slot 0 Saved State File",
    "ZS1": "ZSNES Slot 1 Saved State File",
    "ZS2": "ZSNES Slot 2 Saved State File",
    "ZS3": "ZSNES Slot 3 Saved State File",
    "ZS4": "ZSNES Slot 4 Saved State File",
    "ZS5": "ZSNES Slot 5 Saved State File",
    "ZS6": "ZSNES Slot 6 Saved State File",
    "ZS7": "ZSNES Slot 7 Saved State File",
    "ZS8": "ZSNES Slot 8 Saved State File",
    "ZS9": "ZSNES Slot 9 Saved State File",
    "ZSPLIT": "Archiver Compressed Split File",
    "ZST": "ZSNES Save File",
    "ZT": "Mental Ray Image Depth File",
    "ZTD": "Zoo Tycoon Data Archive",
    "ZTF": "DVD Label Template File",
    "ZTMP": "Steam Compressed Game Resource File",
    "ZTR": "DVD Label Template Media File",
    "ZUL": "ZK User Interface File",
    "ZVD": "ZyXEL Voice File",
    "ZVI": "Zeiss Vision Image",
    "ZVPL": "Visual Paradigm License File",
    "ZVZ": "Possible Virus File",
    "ZW": "Chinese Text File",
    "ZXP": "Extension Manager Package",
    "ZZ": "Zzip Compressed Archive",
    "ZZZ": "CCleaner Securely Deleted File",
    "ZZZZZ": "Ransomware Encrypted File",
    "^^^": "Pervasive.SQL Database File",
    "_DOC": "Renamed Microsoft Word Document",
    "_DOCX": "Renamed Microsoft Word Open XML Document",
    "_EML": "Windows Live Mail Email File",
    "_NWS": "Windows Live Mail Newsgroup Copy File",
    "_SYS.LFO": "Adware File",
    "_XLS": "Renamed Microsoft Excel Spreadsheet",
    "_XLSX": "Renamed Microsoft Excel Open XML Spreadsheet",
    "__A": "File Splitter & Joiner Encrypted File",
    "__B": "File Splitter & Joiner Encrypted Archive File",
    "~CW": "Circuit Wizard Backup File"
}